@@ -125,17 +125,6 @@ gchar *libutils_create_temporary_rep( gchar *SrcTmp, gchar *NewRepTmp )
 	gchar	*Path = NULL;
 	gint	NumPath = 0;
 
-	/*
-	if (NewRepTmp != NULL) {
-		Path = g_strdup_printf ("%s/%s", SrcTmp, NewRepTmp);
-		if (FALSE == libutils_test_dir_exist (Path)) {
-			if( TRUE == OptionsCommandLine.BoolVerboseMode )
-				g_print ("CREATE TEMPORARY REP:\n\t%s\n", Path);
-			g_mkdir_with_parents (Path, 0700);
-		}
-	}
-	return ((gchar *)Path);
-	*/
 	// FIXED
 	// Mon, 20 Jan 2014 16:33:36 +0100
 	// Plusieurs instances de XCFA peuvent être activées sans collision pour les conversions et extractions
@@ -553,60 +542,6 @@ gchar *libutils_get_name_without_ext( gchar *p_PathNameFile )
 	return( (gchar *)NewName );
 }
 //
-// RETOURNE LE NOMBRE DE PROCESSUS ACTIF POUR: p_NameFile
-// EX:
-//	if( libutils_getNbProcess( "xcfa" ) > 1 )
-//	if( libutils_getNbProcess( "tm" ) > 1 )
-//
-gint libutils_getNbProcess( gchar *p_NameFile )
-{
-	size_t 		SizeFile;
-	gchar		*Buffer = NULL;
-	FILE		*fp = NULL;
-	gchar		**LarrbufLine = NULL;
-	gchar		**LarrbufWord = NULL;
-	gint		Cpt = 0;
-	gchar		*CommandLine = NULL;
-	gchar		*PathNameFile = NULL;
-
-	if( TRUE == libutils_find_file( "pidof" ) ) {
-
-		PathNameFile = g_strdup_printf( "/tmp/process_%s", p_NameFile );
-		CommandLine  = g_strdup_printf( "pidof %s > %s", p_NameFile, PathNameFile );
-		system( CommandLine );
-		g_free( CommandLine );
-		CommandLine = NULL;
-		// g_print( "getpid(void) = %d\n", getpid() );
-
-		if(( SizeFile = libutils_get_size_file( PathNameFile )) > 0 ) {
-			if( NULL != ( fp = fopen( PathNameFile, "r" ))) {
-
-				Buffer = (gchar *)g_malloc0( sizeof(gchar) * ( SizeFile +10 ));
-				SizeFile = fread( Buffer, SizeFile, 1, fp );
-				fclose( fp );
-
-				LarrbufLine = g_strsplit( Buffer, "\n", 0 );
-				g_free( Buffer );
-				Buffer = NULL;
-
-				LarrbufWord = g_strsplit( LarrbufLine[ 0 ], " ", 0 );
-				for( Cpt = 0; LarrbufWord[ Cpt ]; Cpt++ );
-
-				g_strfreev( LarrbufWord );
-				LarrbufWord = NULL;
-				g_strfreev( LarrbufLine );
-				LarrbufLine = NULL;
-			}
-		}
-		g_unlink( PathNameFile );
-		g_free( PathNameFile );
-		PathNameFile = NULL;
-
-	}
-
-	return( Cpt );
-}
-//
 //
 gchar *libutils_string_toupper( gchar *p_str )
 {
