@@ -1,9 +1,9 @@
  /*
  *  file      : alsa_audio.h
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -41,39 +41,39 @@
 #include <alsa/asoundlib.h>
 
 typedef struct {
-	snd_pcm_t	*playback_handle;			// Handle
-	guint		bytesPerFrame;				// 8, 16, 24, 32, 64 ...
-	guint		channels;				// 1, 2, 4 ...
-	gint		SampleRate;				// Frequence: 44100 ...
-	gint		TotalChunckSize;			// 
-	guchar		*buffer;				// Pointeur de buffer
-	guint		SizeBuffer;				// Taille requise du buffer
-	gint		Sec;					// Duree total en secondes
-	gdouble		Percent;				// Poucentage en retour sur la duree total
-	gdouble		PercentSel;				// Poucentage en retour depuis la selection
+	snd_pcm_t	*playback_handle;							// Handle
+	guint		bytesPerFrame;								// 8, 16, 24, 32, 64 ...
+	guint		channels;									// 1, 2, 4 ...
+	gint		SampleRate;									// Frequence: 44100 ...
+	gint		TotalChunckSize;							// 
+	guchar		*buffer;									// Pointeur de buffer
+	guint		SizeBuffer;									// Taille requise du buffer
+	gint		Sec;										// Duree total en secondes
+	gdouble		Percent;									// Poucentage en retour sur la duree total
+	gdouble		PercentSel;									// Poucentage en retour depuis la selection
 	
-	gdouble		PercentBegin;				// 
-	gdouble		PercentEnd;				// 
+	gdouble		PercentBegin;								// 
+	gdouble		PercentEnd;									// 
 	
-	gboolean	BoolThreadEnd;				// 
-	guint		HandlerTimeout;				// 
+	gboolean	BoolThreadEnd;								// 
+	guint		HandlerTimeout;								// 
 	
-	gboolean	StopPlay;				// 
-	gboolean	PauseAlsa;				// 
-	void		(*FuncSetValueTime) (gdouble p_value);	// 
-	void		(*FuncIconeStop) (void);		// 
+	gboolean	StopPlay;									// 
+	gboolean	PauseAlsa;									// 
+	void		(*FuncSetValueTime) (gdouble p_value);
+	void		(*FuncIconeStop) (void);					// 
 	
-	FILE		*pFile;					// Handler du fichier ouvert
+	FILE		*pFile;										// Handler du fichier ouvert
 } VAR_ALSA;
 
 extern VAR_ALSA VarAlsa;
 
 void     AlsaAudio_close_device (void);
 gboolean AlsaAudio_open_device (const gchar *audio_dev,		// default
-				gint p_bitsPerSample,		// 8, 16, 24, ...
-				gint p_channels,		// 1, 2, 4, ...
-				guint p_samplesPerSec,		// 44100, ...
-				guint *p_bufferSize);		// Taille buffer retournee
+				gint p_bitsPerSample,						// 8, 16, 24, ...
+				gint p_channels,							// 1, 2, 4, ...
+				guint p_samplesPerSec,						// 44100, ...
+				guint *p_bufferSize);						// Taille buffer retournee
 gboolean AlsaAudio_write (gint size);
 
 
