@@ -1,9 +1,9 @@
  /*
  *  file      : alsa_play.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -142,7 +142,7 @@ static gint AlsaPlay_timeout (gpointer data)
 		fclose (VarAlsa.pFile);
 		VarAlsa.pFile = NULL;
 		AlsaAudio_close_device ();
-		gtk_timeout_remove (VarAlsa.HandlerTimeout);
+		g_source_remove (VarAlsa.HandlerTimeout);
 
 		if (NULL != VarAlsa.FuncSetValueTime) (*VarAlsa.FuncSetValueTime) (VarAlsa.PercentSel);
 		if (NULL != VarAlsa.FuncIconeStop)    (*VarAlsa.FuncIconeStop) ();
@@ -217,11 +217,11 @@ void AlsaPlay_song (gchar *NameFile, gdouble PBegin, gdouble PEnd, void *p_FuncS
 	
 	// TEST OUVERTURE DEVICE
 	BoolOpenDevice = AlsaAudio_open_device(
-			"default",				// const char *audio_dev,		default
+			"default",							// const char *audio_dev,		default
 			WaveHeader.FMT.BitsPerSample,		// int p_bitsPerSample,			8, 16, 24, ...
-			WaveHeader.FMT.NumChannels,		// int p_channels,			1, 2, 4, ...
-			WaveHeader.FMT.SampleRate,		// unsigned int p_samplesPerSec		44100, ...
-			&VarAlsa.SizeBuffer			// unsigned int *p_bufferSize,		Taille buffer retournee
+			WaveHeader.FMT.NumChannels,			// int p_channels,			1, 2, 4, ...
+			WaveHeader.FMT.SampleRate,			// unsigned int p_samplesPerSec		44100, ...
+			&VarAlsa.SizeBuffer					// unsigned int *p_bufferSize,		Taille buffer retournee
 			);
 	
 	if (BoolOpenDevice == TRUE) {
@@ -236,7 +236,7 @@ void AlsaPlay_song (gchar *NameFile, gdouble PBegin, gdouble PEnd, void *p_FuncS
 			g_print ("\t%s\n", NameFile);
 		pthread_create (&nmr_tid, NULL ,(void *)AlsaPlay_thread, (void *)NULL);
 		PRINT("DEBUT TIMEOUT ALSA");
-		VarAlsa.HandlerTimeout = gtk_timeout_add (100, AlsaPlay_timeout, 0);
+		VarAlsa.HandlerTimeout = g_timeout_add (100, AlsaPlay_timeout, 0);
 	}
 	else {
 		fclose (VarAlsa.pFile);
