@@ -1,9 +1,9 @@
  /*
  *  file      : cd_audio.h
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -46,52 +46,52 @@ typedef enum {
 
 
 typedef struct {
-	GtkWidget		*Adr_checkbutton_log_cdparanoia_mode_expert;	// 
-	GtkComboBox		*Adr_combobox_discid_cd;		// 
-	GtkComboBox		*Adr_combobox_normalise_cd;		// 
-	GtkComboBox		*Adr_Combo_Box;				// 
-	GtkComboBox		*Adr_combobox_serveur;			// 
+	GtkWidget		*Adr_checkbutton_log_cdparanoia_mode_expert;
+	GtkComboBox		*Adr_combobox_discid_cd;			// 
+	GtkComboBox		*Adr_combobox_normalise_cd;			// 
+	GtkComboBox		*Adr_Combo_Box;						// 
+	GtkComboBox		*Adr_combobox_serveur;				// 
 	GtkWidget		*Adr_button_applique_change;		// 
-	GtkWidget		*Adr_Button_Cancel_cddb;		// 
-	GtkWidget		*Adr_Button_Raffraichir;		// 
-	GtkWidget		*Adr_Label_Duree;			// 
-	GtkWidget		*Adr_Label_Titre;			// 
-	GtkWidget		*Adr_Label_Statusbar;			// 
-	GtkButton		*Adr_Button_Destination;		// 
-	GtkWidget		*Adr_Progressbar;			// 
-	GtkWidget		*Adr_scroll;				// 
-	GtkListStore		*Adr_List_Store;			// 
-	GtkTreeModel		*Adr_Tree_Model;			// 
-	GtkTreeSelection	*Adr_Line_Selected;			// 
-	GtkWidget		*Adr_TreeView;				// 
-	GdkPixbuf		*Pixbuf_Coche;				// coche.png
-	GdkPixbuf		*Pixbuf_Coche_exist;			// coche_exist.png
-	GdkPixbuf		*Pixbuf_Selected;			// selected.png
-	GdkPixbuf		*Pixbuf_Selected_exist;			// selected_exist.png
-	GdkPixbuf		*Pixbuf_Selected_expert;		// selected_expert.png
+	GtkWidget		*Adr_Button_Cancel_cddb;			// 
+	GtkWidget		*Adr_Button_Raffraichir;			// 
+	GtkWidget		*Adr_Label_Duree;					// 
+	GtkWidget		*Adr_Label_Titre;					// 
+	GtkWidget		*Adr_Label_Statusbar;				// 
+	GtkButton		*Adr_Button_Destination;			// 
+	GtkWidget		*Adr_Progressbar;					// 
+	GtkWidget		*Adr_scroll;						// 
+	GtkListStore		*Adr_List_Store;				// 
+	GtkTreeModel		*Adr_Tree_Model;				// 
+	GtkTreeSelection	*Adr_Line_Selected;				// 
+	GtkWidget		*Adr_TreeView;						// 
+	GdkPixbuf		*Pixbuf_Coche;						// coche.png
+	GdkPixbuf		*Pixbuf_Coche_exist;				// coche_exist.png
+	GdkPixbuf		*Pixbuf_Selected;					// selected.png
+	GdkPixbuf		*Pixbuf_Selected_exist;				// selected_exist.png
+	GdkPixbuf		*Pixbuf_Selected_expert;			// selected_expert.png
 	GdkPixbuf		*Pixbuf_Selected_expert_exist;		// selected_expert_exist.png
-	GdkPixbuf		*Pixbuf_CdPlay;				// play.png
-	GdkPixbuf		*Pixbuf_CdStop;				// sol.png
-	GdkPixbuf		*Pixbuf_Normalize;			//  normalize1.png
-	GdkPixbuf		*Pixbuf_Normalize_Coche;		//  normalize2.png
-	GdkPixbuf		*Pixbuf_NotInstall;			// not_install.png
-	gboolean		 Bool_create_file_m3u;			// 
-	gchar			*Pathname_m3u;				// 
-	gchar			*Pathname_xspf;				// 
-	GtkWidget		*Adr_Expander;				// 
-	GtkWidget		*Adr_notebook;				// 
-	GtkWidget		*Adr_entry_tag_titre_album;		// 
-	GtkWidget		*Adr_entry_tag_nom_artiste;		// 
-	GtkWidget		*Adr_spinbutton_tag_annee;		// 
+	GdkPixbuf		*Pixbuf_CdPlay;						// play.png
+	GdkPixbuf		*Pixbuf_CdStop;						// sol.png
+	GdkPixbuf		*Pixbuf_Normalize;					//  normalize1.png
+	GdkPixbuf		*Pixbuf_Normalize_Coche;			//  normalize2.png
+	GdkPixbuf		*Pixbuf_NotInstall;					// not_install.png
+	gboolean		 Bool_create_file_m3u;				// 
+	gchar			*Pathname_m3u;						// 
+	gchar			*Pathname_xspf;						// 
+	GtkWidget		*Adr_Expander;						// 
+	GtkWidget		*Adr_notebook;						// 
+	GtkWidget		*Adr_entry_tag_titre_album;			// 
+	GtkWidget		*Adr_entry_tag_nom_artiste;			// 
+	GtkWidget		*Adr_spinbutton_tag_annee;			// 
 	GtkWidget		*Adr_entry_new_titre_cdaudio;		// 
 	GtkWidget		*Adr_entry_tag_titre_chanson;		// 
 	GtkWidget		*Adr_entry_tag_titre_fichier;		// 
-	GtkWidget		*Adr_entry_tag_commentaire;		// 
-	GtkWidget		*Adr_spinbutton_tag_piste;		// 
+	GtkWidget		*Adr_entry_tag_commentaire;			// 
+	GtkWidget		*Adr_spinbutton_tag_piste;			// 
 	GtkWidget		*Adr_entry_stockage_cdaudio;		// 
 	GtkWidget		*Adr_label_stockage_cdaudio;		// 
-	GtkWidget		*Adr_entry_name_file_cue;		// 
-	TYPE_CUE		 TypeCreateCue;				// TYPE_CUE_NONE | TYPE_CUE_CD | TYPE_CUE_FILE
+	GtkWidget		*Adr_entry_name_file_cue;			// 
+	TYPE_CUE		 TypeCreateCue;						// TYPE_CUE_NONE | TYPE_CUE_CD | TYPE_CUE_FILE
 	GtkTreeViewColumn	*Adr_Column_Play;
 	GtkTreeViewColumn	*Adr_Column_Flac;
 	GtkTreeViewColumn	*Adr_Column_Wav;
@@ -115,10 +115,10 @@ typedef struct {
 
 extern VAR_CD var_cd;
 
-typedef enum {								// Pour extraction / conversion */
-	ETAT_CONV_CD_NONE,						// Aucune demande
-	ETAT_CONV_CD_WAITING,						// En attente
-	ETAT_CONV_CD_CONV_OK						// Fait
+typedef enum {											// Pour extraction / conversion */
+	ETAT_CONV_CD_NONE,									// Aucune demande
+	ETAT_CONV_CD_WAITING,								// En attente
+	ETAT_CONV_CD_CONV_OK								// Fait
 } ETAT_CONV_CD;
 
 typedef enum {
@@ -143,8 +143,8 @@ typedef enum {
 
 typedef enum {
 	CD_NORM_PEAK_NONE = 0,
-	CD_NORM_PEAK,							// INDIVIDUEL   ajustement maximal du volume
-	CD_NORM_PEAK_WAITING						// COLLECTIF 	ajustement maximal du volume
+	CD_NORM_PEAK,										// INDIVIDUEL   ajustement maximal du volume
+	CD_NORM_PEAK_WAITING								// COLLECTIF 	ajustement maximal du volume
 } ETAT_NORMALISE_CD;
 
 
@@ -176,74 +176,74 @@ typedef struct {
 
 typedef struct {
 	LIST_CONV		*ListConv;
-	ETAT_PLAY_CD		 EtatPlay;				// 
-	gboolean		 Bool_Delette_Flac;			// Le fichier provisoir doit etre efface
-	gboolean		 Bool_Delette_Wav;			// 
-	gboolean		 Bool_Delette_Mp3;			// 
-	gboolean		 Bool_Delette_Ogg;			// 
-	gboolean		 Bool_Delette_M4a;			// 
-	gboolean		 Bool_Delette_Aac;			// 
-	gboolean		 Bool_Delette_Mpc;			// 
-	gboolean		 Bool_Delette_Ape;			// 
-	gboolean		 Bool_Delette_WavPack;			// 
+	ETAT_PLAY_CD		 EtatPlay;						// 
+	gboolean		 Bool_Delette_Flac;					// Le fichier provisoir doit etre efface
+	gboolean		 Bool_Delette_Wav;					// 
+	gboolean		 Bool_Delette_Mp3;					// 
+	gboolean		 Bool_Delette_Ogg;					// 
+	gboolean		 Bool_Delette_M4a;					// 
+	gboolean		 Bool_Delette_Aac;					// 
+	gboolean		 Bool_Delette_Mpc;					// 
+	gboolean		 Bool_Delette_Ape;					// 
+	gboolean		 Bool_Delette_WavPack;				// 
 	ETAT_SELECTION_CD	 EtatSelection_Flac;			// 
-	ETAT_SELECTION_CD	 EtatSelection_Wav;			// 
-	ETAT_SELECTION_CD	 EtatSelection_Mp3;			// 
-	ETAT_SELECTION_CD	 EtatSelection_Ogg;			// 
-	ETAT_SELECTION_CD	 EtatSelection_M4a;			// 
-	ETAT_SELECTION_CD	 EtatSelection_Aac;			// 
-	ETAT_SELECTION_CD	 EtatSelection_Mpc;			// 
-	ETAT_SELECTION_CD	 EtatSelection_Ape;			// 
+	ETAT_SELECTION_CD	 EtatSelection_Wav;				// 
+	ETAT_SELECTION_CD	 EtatSelection_Mp3;				// 
+	ETAT_SELECTION_CD	 EtatSelection_Ogg;				// 
+	ETAT_SELECTION_CD	 EtatSelection_M4a;				// 
+	ETAT_SELECTION_CD	 EtatSelection_Aac;				// 
+	ETAT_SELECTION_CD	 EtatSelection_Mpc;				// 
+	ETAT_SELECTION_CD	 EtatSelection_Ape;				// 
 	ETAT_SELECTION_CD	 EtatSelection_WavPack;			// 
-	gint			 Num_Track;				// Numero de piste
-	gchar			*Str_Track;				// 
-	gchar			*NameSong;				// Le nom du futur fichier
-	gchar			*Duree;					// La duree d'ecoute
-	ETAT_CONV_CD		 Etat_Flac;				// Pour extraction / conversion
-	ETAT_CONV_CD		 Etat_Wav;				// 
-	ETAT_CONV_CD		 Etat_Mp3;				// 
-	ETAT_CONV_CD		 Etat_Ogg;				// 
-	ETAT_CONV_CD		 Etat_m4a;				// 
-	ETAT_CONV_CD		 Etat_Aac;				// 
-	ETAT_CONV_CD		 Etat_Mpc;				// 
-	ETAT_CONV_CD		 Etat_Ape;				// 
-	ETAT_CONV_CD		 Etat_WavPack;				// 
+	gint			 Num_Track;							// Numero de piste
+	gchar			*Str_Track;							// 
+	gchar			*NameSong;							// Le nom du futur fichier
+	gchar			*Duree;								// La duree d'ecoute
+	ETAT_CONV_CD		 Etat_Flac;						// Pour extraction / conversion
+	ETAT_CONV_CD		 Etat_Wav;						// 
+	ETAT_CONV_CD		 Etat_Mp3;						// 
+	ETAT_CONV_CD		 Etat_Ogg;						// 
+	ETAT_CONV_CD		 Etat_m4a;						// 
+	ETAT_CONV_CD		 Etat_Aac;						// 
+	ETAT_CONV_CD		 Etat_Mpc;						// 
+	ETAT_CONV_CD		 Etat_Ape;						// 
+	ETAT_CONV_CD		 Etat_WavPack;					// 
 	ETAT_CONV_CD		 Etat_Sox;
 	gboolean		 EtatNormalise;
 	ETAT_NORMALISE_CD	 EtatPeak;
-	gchar			*PathName_Dest_Flac;			// Emplacement du fichier
-	gchar			*PathName_Dest_Wav;			// 
-	gchar			*PathName_Dest_Mp3;			// 
-	gchar			*PathName_Dest_Ogg;			// 
-	gchar			*PathName_Dest_M4a;			// 
-	gchar			*PathName_Dest_Aac;			// 
-	gchar			*PathName_Dest_Mpc;			// 
-	gchar			*PathName_Dest_Ape;			// 
-	gchar			*PathName_Dest_WavPack;			// 
+	gchar			*PathName_Dest_Flac;				// Emplacement du fichier
+	gchar			*PathName_Dest_Wav;					// 
+	gchar			*PathName_Dest_Mp3;					// 
+	gchar			*PathName_Dest_Ogg;					// 
+	gchar			*PathName_Dest_M4a;					// 
+	gchar			*PathName_Dest_Aac;					// 
+	gchar			*PathName_Dest_Mpc;					// 
+	gchar			*PathName_Dest_Ape;					// 
+	gchar			*PathName_Dest_WavPack;				// 
 	gchar			*PathName_Dest_Tmp;
-	TAGS			*tags;					// Tags
+	TAGS			*tags;								// Tags
 	gboolean		 BoolM3uForWav;
-	EXTRACT_EXPERT		 ExtractExpert;
+	EXTRACT_EXPERT	ExtractExpert;
 	gboolean		 EtatBoolWavpack;
 } CD_AUDIO;
 
-typedef struct {							// UN ENTETE POUR LE CD
-	gchar			*TitleCD;				// Titre integral du CD
-	gchar			*Title;					// Titre du CD
-	gchar			*Artiste;				// Nom de l'artiste
-	gboolean		 BoolMultiArtiste;			// 
-	gchar			*StrDureeCd;				// Duree totale du cd
-	gint			 TotalTracks;				// Nombre total de pistes trouvees
-	gint			 NumGenre;				// Genre en numerique
-	gchar			*StrGenre;				// Genre en chaine
-	gint			 NumYear;				// Annee du cd en numerique
-	gchar			*StrYear;				// Annee du cd en chaine
-	GList			*GList_Audio_cd;			// UNE STRUCTURE 'AUDIO' PAR PISTE
-	gboolean		 Bool_Read_Infos_cd;			// TRUE or FALSE
-	gchar			*Message;				// Message pour l'utilisateur
-	gchar			*NameCD_Device;				// Pointeur sur le device en selection 
-	gchar			 Str_Nice [ 10 ];			// Priorite systeme
-	gchar			 Str_Bitrate_Lame [ 10 ];		// Bitrate pour Lame
+typedef struct {										// UN ENTETE POUR LE CD
+	gchar			*TitleCD;							// Titre integral du CD
+	gchar			*Title;								// Titre du CD
+	gchar			*Artiste;							// Nom de l'artiste
+	gboolean		 BoolMultiArtiste;					// 
+	gchar			*StrDureeCd;						// Duree totale du cd
+	gint			 TotalTracks;						// Nombre total de pistes trouvees
+	gint			 NumGenre;							// Genre en numerique
+	gchar			*StrGenre;							// Genre en chaine
+	gint			 NumYear;							// Annee du cd en numerique
+	gchar			*StrYear;							// Annee du cd en chaine
+	GList			*GList_Audio_cd;					// UNE STRUCTURE 'AUDIO' PAR PISTE
+	gboolean		 Bool_Read_Infos_cd;				// TRUE or FALSE
+	gchar			*Message;							// Message pour l'utilisateur
+	gchar			*NameCD_Device;						// Pointeur sur le device en selection 
+	gchar			 Str_Nice [ 10 ];					// Priorite systeme
+	gchar			 Str_Bitrate_Lame [ 10 ];			// Bitrate pour Lame
 	gchar			 Str_Bitrate_oggenc [ 10 ]; 		// Bitrate pour Oggenc
 } ENTETE_CD;
 
