@@ -1,9 +1,9 @@
  /*
  *  file      : cd_audio_extract.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -291,7 +291,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				Audio->ListConv[ NUM_FLAC ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				PtrTabArgs = filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv( PtrTabArgs, Audio, NUM_FLAC );
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_Ape == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = MAC_WAV_TO_APE;
@@ -307,7 +307,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				Audio->ListConv[ NUM_APE ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				PtrTabArgs = filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_APE);
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_WavPack == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = WAVPACK_WAV_TO_WAVPACK;
@@ -323,7 +323,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				Audio->ListConv[ NUM_WAVPACK ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				PtrTabArgs = filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_WAVPACK);
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_Sox == ETAT_CONV_CD_WAITING || Audio->Etat_Ogg == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = OGGENC_WAV_TO_OGG;
@@ -347,7 +347,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				Audio->ListConv[ NUM_OGG ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				PtrTabArgs = filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_OGG);
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_m4a == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = FAAC_WAV_TO_M4A;
@@ -363,7 +363,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				Audio->ListConv[ NUM_M4A ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				PtrTabArgs = filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_M4A);
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_Aac == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = AACPLUSENC_WAV_TO_AAC;
@@ -380,7 +380,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				Audio->ListConv[ NUM_AAC ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				PtrTabArgs = filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_AAC);
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_Sox == ETAT_CONV_CD_WAITING || Audio->Etat_Mpc == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = MPPENC_WAV_TO_MPC;
@@ -403,7 +403,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				Audio->ListConv[ NUM_MPC ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				PtrTabArgs = filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_MPC);
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			}
 			if (Audio->Etat_Mp3 == ETAT_CONV_CD_WAITING) {
 				param_filelc.type_conv             = LAME_WAV_TO_MP3;
@@ -420,7 +420,7 @@ void cdaudioextract_create_list_is_Convert (void)
 				Audio->ListConv[ NUM_MP3 ].WithCommandLineUser = param_filelc.With_CommandLineUser;
 				PtrTabArgs = filelc_get_command_line (&param_filelc);
 				cdaudioextract_save_arg_from_conv (PtrTabArgs, Audio, NUM_MP3);
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			}
 		}
 		List = g_list_next(List);
@@ -670,14 +670,14 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtract_1, gchar *FileExtract_2
 				if (*Ptr1 != *Ptr2) {
 					if (NbrPass <= 4) {
 						// Si le contenu des segments est different
-						Str = g_strdup_printf (_("[Erreur du segment numero: %d]\n%d) Lecture PASS 1/2\n"), Elem, NbrPass);
+						Str = g_strdup_printf (_("[Error on segment #%d] %d) Playing PASS 1/2\n"), Elem, NbrPass);
 						cdaudioextract_set_list_to_vte (Str);
 						g_free (Str);
 						Str = NULL;
 						BoolDiff = TRUE;
 					}
 					else { // NbrPass > 4
-						Str = g_strdup_printf (_("--> Deja %d fois 2 lectures du segment %d!\n    Abandon  :/\n"), NbrPass, Elem);
+						Str = g_strdup_printf (_("--> Segment %d already read two %d times!\n    Abandon  :/\n"), NbrPass, Elem);					
 						cdaudioextract_set_list_to_vte (Str);
 						g_free (Str);
 						Str = NULL;
@@ -697,7 +697,7 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtract_1, gchar *FileExtract_2
 			conv_exec_extract (FALSE, CDPARANOIA_CD_TO_WAV_EXPERT_SEGMENT, "CDPARANOIA_CD_TO_WAV_EXPERT_SEGMENT");
 			
 			// Extraction segment 'Elem' PASS 2/2
-			Str = g_strdup_printf (_("%d) Lecture PASS 2/2\n"), NbrPass);
+			Str = g_strdup_printf (_("%d) Read PASS 2/2\n"), NbrPass);
 			cdaudioextract_set_list_to_vte (Str);
 			g_free (Str);
 			Str = NULL;
@@ -777,11 +777,11 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 						
 						gchar *Str = NULL;
 						
-						Str = g_strdup_printf (_("\n[Piste: %d]\n"), Audio->Num_Track);
+						Str = g_strdup_printf (_("\n[Track: %d]\n"), Audio->Num_Track);
 						cdaudioextract_set_list_to_vte (Str);
 						g_free (Str);
 						Str = NULL;
-						Str = g_strdup (_("Extraction mode expert PASS 1/2\n"));
+						Str = g_strdup (_("Ripping expert mode PASS 1/2\n"));
 						cdaudioextract_set_list_to_vte (Str);
 						g_free (Str);
 						Str = NULL;
@@ -792,7 +792,7 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 					
 					if (FALSE == conv.bool_stop) {
 						
-						cdaudioextract_set_list_to_vte (_("Extraction mode expert PASS 2/2\n"));
+						cdaudioextract_set_list_to_vte (_("Ripping expert mode PASS 2/2\n"));
 						
 						cdaudioextract_restitue_arg_to_extract (Audio, NUM_WAV_EXPERT_2);
 						conv_exec_extract (Audio->ListConv[ NUM_WAV_EXPERT_2 ].WithCommandLineUser, CDPARANOIA_CD_TO_WAV_EXPERT, "CDPARANOIA_CD_TO_WAV_EXPERT");
@@ -800,7 +800,7 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 					
 					if (FALSE == conv.bool_stop) {
 						
-						cdaudioextract_set_list_to_vte (_("Controle du contenu des fichiers extraits\n"));
+						cdaudioextract_set_list_to_vte (_("Control the content of the extracted files\n"));
 						
 						cdaudioextract_copy_src_to_dest (
 								Audio->ExtractExpert.Name1,
@@ -915,7 +915,7 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 			
 			conv.bool_percent_extract = conv.bool_percent_conv = TRUE;
 			conv_to_convert (PtrTabArgs, FALSE, NORMALISE_GET_LEVEL, "NORMALISE_GET_LEVEL -> PEAK/GROUP");
-			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+			PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			
 			// -- APPLIQUER LA MOYENNE PEAK
 			if (FALSE == conv.bool_stop) {
@@ -940,7 +940,7 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 				
 				conv.bool_percent_extract = conv.bool_percent_conv = TRUE;
 				conv_to_convert (PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> PEAK/GROUP");
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 
 				CdNormalise_set_normalise_ok ();
 
@@ -1032,7 +1032,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				
 				// NORMALISATION PEAK
 				conv_to_convert (PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Peak");
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 				
 				conv_copy_src_to_dest (Name, Audio->PathName_Dest_Wav);
 				g_unlink (Name);
@@ -1089,7 +1089,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 				PtrTabArgs [ pos++ ] = NULL;
 				
 				conv_to_convert (PtrTabArgs, FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 				
 				PRINT("DEBUG FOR @DZEF");
 				if( TRUE == OptionsCommandLine.BoolVerboseMode )
@@ -1119,7 +1119,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_free( PtrTabArgs[ 2 ] );
 			cdaudioextract_restitue_arg_to_conv( PtrTabArgs, Audio, NUM_FLAC );
 			conv_to_convert (PtrTabArgs, Audio->ListConv[ NUM_FLAC ].WithCommandLineUser,  FLAC_WAV_TO_FLAC, "FLAC_WAV_TO_FLAC");
-			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+			PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 
 			Audio->EtatSelection_Flac = CD_ETAT_ATTENTE;
 
@@ -1146,7 +1146,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_free( PtrTabArgs[ 2 ] );
 			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_APE);
 			conv_to_convert (PtrTabArgs, Audio->ListConv[ NUM_APE ].WithCommandLineUser,  MAC_WAV_TO_APE, "MAC_WAV_TO_APE");
-			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+			PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 
 			Audio->EtatSelection_Ape = CD_ETAT_ATTENTE;
 
@@ -1178,7 +1178,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_free( PtrTabArgs[ 2 ] );
 			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_WAVPACK);
 			conv_to_convert (PtrTabArgs, Audio->ListConv[ NUM_WAVPACK ].WithCommandLineUser,  WAVPACK_WAV_TO_WAVPACK, "WAVPACK_WAV_TO_WAVPACK");
-			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+			PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			
 			Audio->EtatSelection_WavPack = CD_ETAT_ATTENTE;
 
@@ -1220,7 +1220,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_free( PtrTabArgs[ 2 ] );
 			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_OGG);
 			conv_to_convert( PtrTabArgs, Audio->ListConv[ NUM_OGG ].WithCommandLineUser, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
-			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+			PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			
 			Audio->EtatSelection_Ogg = CD_ETAT_ATTENTE;
 
@@ -1247,7 +1247,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_free( PtrTabArgs[ 2 ] );
 			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_M4A);
 			conv_to_convert( PtrTabArgs, Audio->ListConv[ NUM_M4A ].WithCommandLineUser, FAAC_WAV_TO_M4A, "FAAC_WAV_TO_M4A");
-			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+			PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 
 			Audio->EtatSelection_M4a = CD_ETAT_ATTENTE;
 
@@ -1274,7 +1274,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_free( PtrTabArgs[ 2 ] );
 			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_AAC);
 			conv_to_convert( PtrTabArgs, Audio->ListConv[ NUM_AAC ].WithCommandLineUser, AACPLUSENC_WAV_TO_AAC, "AACPLUSENC_WAV_TO_AAC");
-			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+			PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 
 			Audio->EtatSelection_Aac = CD_ETAT_ATTENTE;
 
@@ -1303,7 +1303,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_free( PtrTabArgs[ 2 ] );
 			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_MPC);
 			conv_to_convert( PtrTabArgs, Audio->ListConv[ NUM_MPC ].WithCommandLineUser, MPPENC_WAV_TO_MPC, "MPPENC_WAV_TO_MPC");
-			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+			PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 
 			Audio->EtatSelection_Mpc = CD_ETAT_ATTENTE;
 
@@ -1330,7 +1330,7 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 			g_free( PtrTabArgs[ 2 ] );
 			cdaudioextract_restitue_arg_to_conv (PtrTabArgs, Audio, NUM_MP3);
 			conv_to_convert( PtrTabArgs, Audio->ListConv[ NUM_MP3 ].WithCommandLineUser, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
-			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+			PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			
 			Audio->EtatSelection_Mp3 = CD_ETAT_ATTENTE;
 
@@ -1473,7 +1473,7 @@ static gint cdaudioextract_timeout (gpointer data)
 		GList		*List = NULL;
 		FILE		*fp = NULL;
 
-		gtk_timeout_remove (conv.handler_timeout_conv);
+		g_source_remove (conv.handler_timeout_conv);
 
 		// Creation du fichier *.m3u
 		if (TRUE == var_cd.Bool_create_file_m3u) {
@@ -1709,7 +1709,7 @@ static gint cdaudioextract_timeout (gpointer data)
 		if (FALSE == conv.bool_stop) {
 			NotifySend_msg (_("XCFA: Extraction CD"), _("Ok"), conv.bool_stop);
 		} else {
-			NotifySend_msg (_("XCFA: Extraction CD"), _("Arret par l'utilisateur"), conv.bool_stop);
+			NotifySend_msg (_("XCFA: Extraction CD"), _("Stop by user"), conv.bool_stop);
 		}
 	}
 	return (TRUE);
@@ -1978,10 +1978,10 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 		gchar *Ptr = NULL;
 		Ptr = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_name_file_cue));
 		if (*Ptr == '\0') {
-			wininfo_create (
+			wind_info_init (
 				WindMain,
-				_("Nom de fichier unique absent"),
-				_("Veuillez saisir un nom pour le fichier unique"),
+				_("File name not found"),
+				_("Please enter a file name"),
 				  "");
 			return;
 		}
@@ -2010,7 +2010,12 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 	BaseIoctl.PathNameDestFileCue = NULL;
 	cdaudioextract_set_flags_before_extraction ();
 
-	WindScan_open ("Extract / Convert from CD", WINDSCAN_PULSE);
+	// WindScan_open ("Extract / Convert from CD", WINDSCAN_PULSE);
+	wind_scan_init(
+		WindMain,
+		"Extract / Convert from CD",
+		WINDSCAN_PULSE
+		);
 	WindScan_set_label ("<b><i>Extract from CD ...</i></b>");
 	WindScan_set_pulse ();
 	if (EXTRACT_WITH_CDPARANOIA_EXPERT == Config.ExtractCdWith) {
@@ -2037,7 +2042,7 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 	conv.bool_thread_extract = TRUE;
  	pthread_create (&nmr_tid, NULL ,(void *)cdaudioextract_thread_extraction_from_cd, (void *)NULL);
 	PRINT("DEBUT TIMEOUT");
-	conv.handler_timeout_conv = gtk_timeout_add (50, cdaudioextract_timeout, 0);
+	conv.handler_timeout_conv = g_timeout_add (50, cdaudioextract_timeout, 0);
 }
 
 
