@@ -1,9 +1,9 @@
  /*
  *  file      : cd_audio_toc.h
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -91,7 +91,7 @@ static gint cdaudiotoc_timeout_do_read_toc_cd (gpointer data)
 	if (var_cd.bool_thread_read_toc_cd == FALSE) {
 
 		// FIN du timeout Update_cdaudio_do_read_toc_cd
-		gtk_timeout_remove (var_cd.handler_timeout_read_toc_cd);
+		g_source_remove (var_cd.handler_timeout_read_toc_cd);
 
 		cdaudio_put_label_duree ("");
 		cdaudio_put_label_titre ("");
@@ -151,21 +151,21 @@ void cdaudiotoc_reffresh_list_cd (void)
 	
 		PRINT_FUNC_LF();
 		if( FALSE == libutils_find_file( "icedax" ) && FALSE == libutils_find_file( "cdda2wav" )) {
-			wininfo_create (
+			wind_info_init (
 				WindMain,
 				_("cdda2wav and icedax NOT FOUND"),
 				_("Please, install packages [ icedax, cdda2wav ]"),
 			  	"");
 		}
 		else if( FALSE == libutils_find_file( "icedax" )) {
-			wininfo_create (
+			wind_info_init (
 				WindMain,
 				_("icedax NOT FOUND"),
 				_("Please, install package [ icedax ]"),
 			  	"");
 		}
 		else if( FALSE == libutils_find_file( "cdda2wav" )) {
-			wininfo_create (
+			wind_info_init (
 				WindMain,
 				_("cdda2wav NOT FOUND"),
 				_("Please, install package [ cdda2wav ]"),
@@ -175,7 +175,7 @@ void cdaudiotoc_reffresh_list_cd (void)
 	}
 	if( FALSE == PrgInit.bool_cdparanoia ) {
 		PRINT_FUNC_LF();
-		wininfo_create (
+		wind_info_init (
 			WindMain,
 			_("cdparanoia NOT FOUND"),
 			_("Please, install package [ cdparanoia ]"),
@@ -183,7 +183,7 @@ void cdaudiotoc_reffresh_list_cd (void)
 		return;
 	}
 	if( FALSE == PrgInit.bool_cd_discid ) {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
 			_("cd-discid NOT FOUND"),
 			_("Please, install packages [ cd-discid ]"),
@@ -198,16 +198,21 @@ void cdaudiotoc_reffresh_list_cd (void)
 		if( '\0' == *Config.entry_proxy_server ) BoolAccess = FALSE;
 		if( '\0' == *Config.entry_proxy_port ) BoolAccess = FALSE;
 		if( FALSE == BoolAccess ) {
-			wininfo_create (
+			wind_info_init (
 				WindMain,
-				_("ERREUR datas proxy"),
-				_("Veuillez renseigner les champs du proxy"),
+				_("ERROR datas proxy"),
+				_("Please complete all fields proxy"),
 			  	"");
 			return;
 		}
 	}
 	
-	WindScan_open ("Scan CD", WINDSCAN_PULSE);
+	// WindScan_open ("Scan CD", WINDSCAN_PULSE);
+	wind_scan_init(
+		WindMain,
+		"Scan CD",
+		WINDSCAN_PULSE
+		);
 	WindScan_show_cancel( FALSE );
 	WindScan_set_label ("<b><i>Scanning CD ...</i></b>");
 	WindScan_set_pulse ();
@@ -224,7 +229,7 @@ void cdaudiotoc_reffresh_list_cd (void)
 	// ACTIVATION de l'update qui attends la fin du thread cd audio
 	var_cd.bool_thread_read_toc_cd = TRUE;
 	var_cd.bool_timeout_read_toc_cd = TRUE;
-	var_cd.handler_timeout_read_toc_cd = gtk_timeout_add (50, cdaudiotoc_timeout_do_read_toc_cd, 0);
+	var_cd.handler_timeout_read_toc_cd = g_timeout_add (50, cdaudiotoc_timeout_do_read_toc_cd, 0);
 	pthread_create (&nmr_tid, NULL ,(void *)cdaudiotoc_thread_do_read_toc_cd, (void *)NULL);
 }
 // 
@@ -233,7 +238,7 @@ void cdaudiotoc_button_eject_cd_clicked (void)
 {
 	if (FALSE == libutils_find_file ("eject")) {
 		PRINT_FUNC_LF();
-		wininfo_create (
+		wind_info_init (
 			WindMain,
 			"eject NOT FOUND !",
 			"Please, install package [ eject ]",
