@@ -1,9 +1,9 @@
  /*
  *  file      : cd_cue.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -539,7 +539,7 @@ static gint cdcue_timeout (gpointer data)
 		cdcue_write_cue ();
 		
 		// FIN timeout
-		gtk_timeout_remove (cdcue.handler_timeout);
+		g_source_remove (cdcue.handler_timeout);
 	}
 	
 	return (TRUE);
@@ -565,7 +565,7 @@ void on_button_cue_creation_from_cd_clicked (GtkButton *button, gpointer user_da
 		var_cd.bool_timeout_read_toc_cd = TRUE;
 		
 		// Le timer de fin
-		cdcue.handler_timeout = gtk_timeout_add (100, cdcue_timeout, 0);
+		cdcue.handler_timeout = g_timeout_add (100, cdcue_timeout, 0);
 		
 		// Et action
 		cdaudiotoc_reffresh_list_cd ();
