@@ -1,9 +1,9 @@
  /*
  *  file      : cd_curl.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -153,22 +153,22 @@ TOTAL  340327 [75:37:52]
 */
 
 typedef struct {
-	gchar		*NameGenre;		// jazz || rock || ...
+	gchar		*NameGenre;			// jazz || rock || ...
 	gint		NumCdDiscId;		// NUM
 	gchar		*StrCdDiscId;		// STR
 } VAR_LIST_POPUP;
 
 typedef struct {
-	gchar		*Title;			// Titre d'une piste
+	gchar		*Title;				// Titre d'une piste
 	gchar		StrTime[ 10 ];		// Temps ( duree ) d'une piste mm:ss
-	gint		NumSector;		// Numero du secteur corespondant a la piste
+	gint		NumSector;			// Numero du secteur corespondant a la piste
 } LIST_SECTOR;
 
 
 typedef struct {
-	gchar		*StrDiscID;		// STR
+	gchar		*StrDiscID;			// STR
 	GString		*GStrCdDiscID;		// STRING
-	gint		LenDisc;		// EN SECONDES
+	gint		LenDisc;			// EN SECONDES
 	gint		TotalTracks;		// TOTAL TRACKS
 	GList		*ListDiscId;		// VAR_LIST_POPUP
 	LIST_SECTOR	*ListSector;		// CDPARANOIA
@@ -180,9 +180,9 @@ typedef struct {
 
 VAR_SECTOR	VarSector;
 
-typedef enum {					// DO_CURL_QUERY CdCurl_discdb_do_query( void )
+typedef enum {						// DO_CURL_QUERY CdCurl_discdb_do_query( void )
 	DO_CURL_QUERY_FALSE = 0,		// NO QUERY
-	DO_CURL_QUERY_TRUE,			// QUERY IS OK
+	DO_CURL_QUERY_TRUE,				// QUERY IS OK
 	DO_CURL_QUERY_REPEAT			// 211 Found inexact matches
 } DO_CURL_QUERY;
 
@@ -325,7 +325,7 @@ void CdCurl_set_list_discid( void )
 		List = g_list_first( VarSector.ListDiscId );
 		while ( List ) {
 			if( NULL != ( PtrVarList = (VAR_LIST_POPUP *)List->data )) {
-				gtk_combo_box_append_text( GTK_COMBO_BOX(var_cd.Adr_combobox_discid_cd), PtrVarList->NameGenre );
+				gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_cd.Adr_combobox_discid_cd), PtrVarList->NameGenre );
 				NbrOptions ++;
 			}
 			List = g_list_next( List );
@@ -731,7 +731,7 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 	}	
 	
 	if( NULL == DatasBuffer ) {
-		EnteteCD.Message = g_strdup( _("La liaison internet est absente") );
+		EnteteCD.Message = g_strdup( _("A web connection is missing") );
 		// MINIMUM D'INFORMATION ET RETOUR
 		// SET Track
 		for( Track = 0; Track < VarSector.TotalTracks; Track ++ ) {
