@@ -1,9 +1,9 @@
  /*
  *  file      : cd_expander.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -451,6 +451,7 @@ void on_entry_tag_genre_changed( GtkEditable *editable, gpointer user_data )
 // 	gint   num;
 // 	gchar *name;
 // } STRUCT_TAGS_FILE_MP3;
+/**
 gboolean on_match_select(GtkEntryCompletion *widget, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {  
 	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
@@ -460,7 +461,8 @@ gboolean on_match_select(GtkEntryCompletion *widget, GtkTreeModel *model, GtkTre
 		g_value_unset(&value);
 	}
 	return FALSE;
-}    
+}
+*/    
 void on_entry_tag_genre_realize( GtkWidget *widget, gpointer user_data )
 {
 	STRUCT_TAGS_FILE_MP3	*Contact;
@@ -472,7 +474,7 @@ void on_entry_tag_genre_realize( GtkWidget *widget, gpointer user_data )
 	completion = gtk_entry_completion_new();
 	gtk_entry_completion_set_text_column( completion, _CONTACT_NAME_ );
 	gtk_entry_set_completion( GTK_ENTRY(widget), completion );
-	g_signal_connect( G_OBJECT(completion), "match-selected", G_CALLBACK(on_match_select), NULL );
+	// g_signal_connect( G_OBJECT(completion), "match-selected", G_CALLBACK(on_match_select), NULL );
 	g_signal_connect( G_OBJECT(widget), "changed", G_CALLBACK(on_entry_tag_genre_changed), widget );
 	model = gtk_list_store_new( 1, G_TYPE_STRING );
 	for( Contact = StructTagsFileMp3; Contact && Contact->name; Contact++ ) {
@@ -587,11 +589,10 @@ void on_checkbutton_creation_fichier_unique_cue_clicked (GtkButton *button, gpoi
 // 
 void on_combobox_choice_file_cue_realize (GtkWidget *widget, gpointer user_data)
 {
-	libcombo_alloc (GTK_COMBO_BOX (widget));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "WAV");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "FLAC");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "OGG");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "MPC");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "WAV");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "FLAC");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "OGG");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "MPC");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
 }
 // 
