@@ -354,7 +354,7 @@ gboolean config_read_value_path( gchar *p_Search, gchar **p_ValuePath, gchar *p_
 		
 		if( TRUE == config_new_strcmp( Conf.Larrbuf[ Cpt ], p_Search )) {
 			if( NULL != ( Ptr = config_get_target( Conf.Larrbuf[ Cpt ] ))) {
-				if( TRUE == libutils_test_dir_exist( Ptr )) {
+				if( TRUE == g_file_test( Ptr, G_FILE_TEST_IS_DIR )) {
 					*p_ValuePath = Ptr;
 				} else {
 					if( NULL == p_default )	*p_ValuePath = g_strdup( g_getenv( "HOME" ));
