@@ -558,6 +558,7 @@ gchar **conv_with_sox_get_param( gchar *filesrc, gchar *filedest, gchar *frequen
 	PtrTabArgs [ pos++ ] = g_strdup ("-c");
 	PtrTabArgs [ pos++ ] = g_strdup (voie);
 
+	/*
 	switch (atoi (bits)) {
 		case 8 :  PtrTabArgs [ pos++ ] = g_strdup ("-1"); break;
 		case 16 : PtrTabArgs [ pos++ ] = g_strdup ("-2"); break;
@@ -569,6 +570,17 @@ gchar **conv_with_sox_get_param( gchar *filesrc, gchar *filedest, gchar *frequen
 	PtrTabArgs [ pos++ ] = g_strdup ("-o");
 	PtrTabArgs [ pos++ ] = g_strdup (filedest);
 	PtrTabArgs [ pos++ ] = NULL;
+	*/
+	switch (atoi (bits)) {
+		case 8 :  PtrTabArgs [ pos++ ] = g_strdup ("-b"); PtrTabArgs [ pos++ ] = g_strdup ("8"); break;
+		case 16 : PtrTabArgs [ pos++ ] = g_strdup ("-b"); PtrTabArgs [ pos++ ] = g_strdup ("16"); break;
+		case 24 : PtrTabArgs [ pos++ ] = g_strdup ("-b"); PtrTabArgs [ pos++ ] = g_strdup ("24"); break;
+		case 32 : PtrTabArgs [ pos++ ] = g_strdup ("-b"); PtrTabArgs [ pos++ ] = g_strdup ("32"); break;
+		case 64 : PtrTabArgs [ pos++ ] = g_strdup ("-b"); PtrTabArgs [ pos++ ] = g_strdup ("64"); break;
+		default : PtrTabArgs [ pos++ ] = g_strdup ("-b"); PtrTabArgs [ pos++ ] = g_strdup ("16"); break;
+	}
+	PtrTabArgs [ pos++ ] = g_strdup (filedest);
+	PtrTabArgs [ pos++ ] = NULL;
 
 	return( (gchar **)PtrTabArgs );
 }
@@ -584,8 +596,10 @@ gchar **conv_with_sox_float_get_param( gchar *filesrc, gchar *filedest )
 	PtrTabArgs [ pos++ ] = g_strdup ("-t");
 	PtrTabArgs [ pos++ ] = g_strdup ("wavpcm");
 	PtrTabArgs [ pos++ ] = g_strdup ("-S");
-	PtrTabArgs [ pos++ ] = g_strdup ("-f");
-	PtrTabArgs [ pos++ ] = g_strdup ("-o");
+	//PtrTabArgs [ pos++ ] = C_strdup ("-f");
+	PtrTabArgs [ pos++ ] = g_strdup ("-e");
+	PtrTabArgs [ pos++ ] = g_strdup ("floating-point");
+	// PtrTabArgs [ pos++ ] = C_strdup ("-o");
 	PtrTabArgs [ pos++ ] = g_strdup (filedest);
 	PtrTabArgs [ pos++ ] = NULL;
 
