@@ -57,7 +57,8 @@ void cursor_set_clear (void)
 {
 	if (cursor_type != GDK_HAND2) {
 		cursor_type = GDK_HAND2;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -68,7 +69,8 @@ void cursor_set_hand (void)
 {
 	if (cursor_type != GDK_HAND2) {
 		cursor_type = GDK_HAND2;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -79,7 +81,8 @@ void cursor_set_saisie (void)
 {
 	if (cursor_type != GDK_XTERM) {
 		cursor_type = GDK_XTERM;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -90,7 +93,8 @@ void cursor_set_gauche_droite (void)
 {
 	if (cursor_type != GDK_SB_H_DOUBLE_ARROW) {
 		cursor_type = GDK_SB_H_DOUBLE_ARROW;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -101,7 +105,8 @@ void cursor_set_haut (void)
 {
 	if (cursor_type != GDK_TOP_SIDE) {
 		cursor_type = GDK_TOP_SIDE;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -112,7 +117,8 @@ void cursor_set_bas (void)
 {
 	if (cursor_type != GDK_BOTTOM_SIDE) {
 		cursor_type = GDK_BOTTOM_SIDE;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -123,7 +129,8 @@ void cursor_set_gauche (void)
 {
 	if (cursor_type != GDK_LEFT_SIDE) {
 		cursor_type = GDK_LEFT_SIDE;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -134,7 +141,8 @@ void cursor_set_droit (void)
 {
 	if (cursor_type != GDK_RIGHT_SIDE) {
 		cursor_type = GDK_RIGHT_SIDE;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -145,7 +153,8 @@ void cursor_set_haut_gauche (void)
 {
 	if (cursor_type != GDK_TOP_LEFT_CORNER) {
 		cursor_type = GDK_TOP_LEFT_CORNER;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -156,7 +165,8 @@ void cursor_set_haut_droit (void)
 {
 	if (cursor_type != GDK_TOP_RIGHT_CORNER) {
 		cursor_type = GDK_TOP_RIGHT_CORNER;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -167,7 +177,8 @@ void cursor_set_bas_gauche (void)
 {
 	if (cursor_type != GDK_BOTTOM_LEFT_CORNER) {
 		cursor_type = GDK_BOTTOM_LEFT_CORNER;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -178,7 +189,8 @@ void cursor_set_bas_droit (void)
 {
 	if (cursor_type != GDK_BOTTOM_RIGHT_CORNER) {
 		cursor_type = GDK_BOTTOM_RIGHT_CORNER;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -189,7 +201,8 @@ void cursor_set_move (void)
 {
 	if (cursor_type != GDK_FLEUR) {
 		cursor_type = GDK_FLEUR;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -200,7 +213,8 @@ void cursor_set_old (void)
 {
 	if (cursor_type != GDK_LEFT_PTR) {
 		cursor_type = GDK_LEFT_PTR;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -211,7 +225,8 @@ void cursor_set_watch (void)
 {
 	if (cursor_type != GDK_WATCH) {
 		cursor_type = GDK_WATCH;
-		_cursor = gdk_cursor_new (cursor_type);
+		// _cursor = gdk_cursor_new (cursor_type);
+		_cursor = gdk_cursor_new_for_display( gdk_display_get_default(), cursor_type );
 		gdk_window_set_cursor (gtk_widget_get_window(WindMain), _cursor);
 		gdk_flush ();
 	}
@@ -223,3 +238,35 @@ gboolean cursor_get_watch (void)
 	return (cursor_type == GDK_WATCH ? TRUE : FALSE);
 }
 
+
+
+/*
+cursor.c:214:3: attention : ‘gdk_cursor_new’ is deprecated (declared at /usr/include/gtk-3.0/gdk/gdkcursor.h:223) [-Wdeprecated-declarations]
+
+
+http://cpansearch.perl.org/src/KRYDE/Gtk2-Ex-WidgetCursor-15/devel/invisible-blank.c
+
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <gtk/gtk.h>
+
+int
+main (int argc, char **argv)
+{
+  GdkDisplay *display;
+  GdkCursor *cursor;
+
+  gtk_init (&argc, &argv);
+  display = gdk_display_get_default();
+
+  cursor = gdk_cursor_new_for_display (display, GDK_BLANK_CURSOR);
+  printf ("%p\n", cursor);
+
+  cursor = gdk_cursor_new_for_display (display, GDK_BLANK_CURSOR);
+  printf ("%p\n", cursor);
+
+  return 0;
+}
+
+*/
