@@ -1,9 +1,9 @@
  /*
  *  file      : dvd_extract.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -185,7 +185,7 @@ void *dvdextract_pthread (void *data)
 			
 			PtrTabArgs = dvdextract_set_arg( (GList *)StructDvdExtract->list );
 			RetConvert = conv_to_convert( PtrTabArgs, FALSE, MPLAYER_AUDIO_TO_WAV, "NEW:-> MPLAYER_AUDIO_TO_WAV" );
-			PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+			PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 			
 			if( FALSE == conv.bool_stop && TRUE == RetConvert ) {
 								
@@ -207,7 +207,7 @@ void *dvdextract_pthread (void *data)
 				PtrTabArgs [ pos++ ] = g_strdup ("44100");
 				PtrTabArgs [ pos++ ] = NULL;
 				conv_to_convert( PtrTabArgs, FALSE, MPLAYER_WAV_TO_WAV, "MPLAYER_WAV_TO_WAV");
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 				
 				conv_copy_src_to_dest ("/tmp/toto.wav", StructDvdExtract->Path);
 				
@@ -228,7 +228,7 @@ void *dvdextract_pthread (void *data)
 					PtrTabArgs [ pos++ ] = g_strdup (StructDvdExtract->Path);
 					PtrTabArgs [ pos++ ] = NULL;
 					conv_to_convert( PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> Peak");
-					PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+					PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 					
 					PRINT("TRAITEMENT NORMALISE  PEAK  OK");
 					
@@ -299,7 +299,7 @@ void *dvdextract_pthread (void *data)
 							}
 							PtrTabArgs [ pos++ ] = NULL;
 							conv_to_convert( PtrTabArgs, FALSE, NORMALISE_GET_LEVEL, "NORMALISE_GET_LEVEL TEST -> PEAK/GROUP");
-							PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+							PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 						}
 						if (FALSE == conv.bool_stop) {
 							// -- APPLIQUER LA MOYENNE PEAK-GROUP
@@ -318,7 +318,7 @@ void *dvdextract_pthread (void *data)
 							}
 							PtrTabArgs [ pos++ ] = NULL;
 							conv_to_convert( PtrTabArgs, FALSE, NORMALISE_EXEC, "NORMALISE_EXEC Wav -> PEAK/GROUP");
-							PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+							PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 							
 							PRINT("TRAITEMENT NORMALISE  PEAK_COLLECTIF  OK");
 						}
@@ -373,7 +373,7 @@ static gint dvdextract_timeout (gpointer data)
 		GList           *listTwo = NULL;
 		gchar           *ptr = NULL;
 		
-		gtk_timeout_remove (VarDvdextract.Handler_Timeout);
+		g_source_remove (VarDvdextract.Handler_Timeout);
 
 		WindScan_close ();
 		
@@ -409,9 +409,9 @@ static gint dvdextract_timeout (gpointer data)
 		dvd_set_flag_buttons_dvd ();
 		
 		if (FALSE == conv.bool_stop) {
-			NotifySend_msg (_("XCFA: Extraction DVD"), _("Ok"), conv.bool_stop);
+			NotifySend_msg (_("XCFA: DVD rip"), _("Ok"), conv.bool_stop);
 		} else {
-			NotifySend_msg (_("XCFA: Extraction DVD"), _("Arret par l'utilisateur"), conv.bool_stop);
+			NotifySend_msg (_("XCFA: DVD rip"), _("Stop by user"), conv.bool_stop);
 		}
 	}
 	else if (TRUE == VarDvdextract.bool_mess) {
@@ -445,11 +445,16 @@ void dvdextract_dvd_to_file (void)
 	VarDvdextract.bool_update = TRUE;
 	VarDvdextract.BoolListIsPeakAlbum = dvd_get_value_normalise_dvd () == 0 ? TRUE : FALSE;
 	
-	WindScan_open ("Extract With Mplayer", WINDSCAN_PULSE);
-	WindScan_set_label ("<b><i>Extraction en cours ...</i></b>");
+	// WindScan_open ("Extract With Mplayer", WINDSCAN_PULSE);
+	wind_scan_init(
+		WindMain,
+		"Extract With Mplayer",
+		WINDSCAN_PULSE
+		);
+	WindScan_set_label ("<b><i>Extraction in progress ...</i></b>");
 
 	VarDvdextract.bool_end_pthread = FALSE;
-	VarDvdextract.Handler_Timeout = gtk_timeout_add (100, dvdextract_timeout, 0);
+	VarDvdextract.Handler_Timeout = g_timeout_add (100, dvdextract_timeout, 0);
 
 	pthread_create (&nmr_tid, NULL ,(void *)dvdextract_pthread, (void *)NULL);
 	// DEBUG
