@@ -1,9 +1,9 @@
  /*
  *  file      : file.h
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright :( C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -29,19 +29,19 @@
 #define file_h 1
 
 typedef struct {
-	gboolean		 bool_tag_cd;				// TRUE is CD-AUDIO else is FILE
-	gboolean		 bool_save;				// TRUE -> save
-	gchar			*Album;					// %b
-	gchar			*Artist;				// %a
-	gchar			*Title;					// %d
-	gchar			*Number;				// %c
-	gint			 IntNumber;				//
-	gchar			*Genre;					// %g
-	gint			 IntGenre;				//
-	gchar			*Year;					// %e
-	gint			 IntYear;				//
-	gchar			*Comment;				//
-	gchar			*Description;				//
+	gboolean		 bool_tag_cd;						// TRUE is CD-AUDIO else is FILE
+	gboolean		 bool_save;							// TRUE -> save
+	gchar			*Album;								// %b
+	gchar			*Artist;							// %a
+	gchar			*Title;								// %d
+	gchar			*Number;							// %c
+	gint			 IntNumber;							//
+	gchar			*Genre;								// %g
+	gint			 IntGenre;							//
+	gchar			*Year;								// %e
+	gint			 IntYear;							//
+	gchar			*Comment;							//
+	gchar			*Description;						//
 } TAGS;
 
 //
@@ -51,117 +51,117 @@ typedef struct {
 //
 
 typedef struct {
-	gint			 level;					// Niveau en dBFS
-	gint			 NewLevel;				// Nouveau niveau en dBFS
+	gint			 level;								// Niveau en dBFS
+	gint			 NewLevel;							// Nouveau niveau en dBFS
 } LEVEL_DBFS;
 
 typedef struct {
-	gchar			*time;					// Temps d'ecoute
-	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*hertz;					//
-	TAGS			*tags;					// Tags
+	gchar			*time;								// Temps d'ecoute
+	guint			 SecTime;							// Temps d'ecoute en secondes
+	gchar			*hertz;								//
+	TAGS			*tags;								// Tags
 } INFO_M4A;
 
 typedef struct {
-	gchar			*time;					// Temps d'ecoute
-	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*hertz;					//
-	TAGS			*tags;					// Tags
+	gchar			*time;								// Temps d'ecoute
+	guint			 SecTime;							// Temps d'ecoute en secondes
+	gchar			*hertz;								//
+	TAGS			*tags;								// Tags
 } INFO_AAC;
 
 typedef struct {
-	gboolean		 BoolBwf;				// 'fmt ', 'bext', 'qlty', 'levl', 'link','axml'
-	gchar			*time;					// Temps d'ecoute
-	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*hertz;					// Taux d'échantillonnage en hertz( qualité du son)
-	gchar			*voie;					// 1, 2, 4, 6
-	gchar			*bits;					// 8, 16, ,24, 32 ou 64
-	gchar			*NewHertz;				// Nouvelle valeur
-	gchar			*NewVoie;				// Nouvelle valeur
-	gchar			*NewBits;				// Nouvelle valeur
-	gboolean		 BoolConv;				// TRUE si nouvelles valeurs differenetes de anciennes valeurs
-	TAGS			*tags;					// Tags
-	LEVEL_DBFS		 LevelDbfs;				//
+	gboolean		 BoolBwf;							// 'fmt ', 'bext', 'qlty', 'levl', 'link','axml'
+	gchar			*time;								// Temps d'ecoute
+	guint			 SecTime;							// Temps d'ecoute en secondes
+	gchar			*hertz;								// Taux d'échantillonnage en hertz( qualité du son)
+	gchar			*voie;								// 1, 2, 4, 6
+	gchar			*bits;								// 8, 16, ,24, 32 ou 64
+	gchar			*NewHertz;							// Nouvelle valeur
+	gchar			*NewVoie;							// Nouvelle valeur
+	gchar			*NewBits;							// Nouvelle valeur
+	gboolean		 BoolConv;							// TRUE si nouvelles valeurs differenetes de anciennes valeurs
+	TAGS			*tags;								// Tags
+	LEVEL_DBFS		 LevelDbfs;							//
 } INFO_WAV;
 
-typedef enum {								// type:     bitrate:
+typedef enum {											// type:     bitrate:
 	NONE_MPEG = -1,
-	MPEG_1 = 0,							// MPV_1     [ 32 40 48 56 64 80 96 112 128 160 192 224 256 320 ]
-	MPEG_2,								// MPV_2     [  8 16 24 32 40 48 56  64  80  96 112 128 144 160 ]
-	MPEG_25								// MPV_25    [  8 16 24 32 40 48 56  64  80  96 112 128 144 160 ]
+	MPEG_1 = 0,											// MPV_1     [ 32 40 48 56 64 80 96 112 128 160 192 224 256 320 ]
+	MPEG_2,												// MPV_2     [  8 16 24 32 40 48 56  64  80  96 112 128 144 160 ]
+	MPEG_25												// MPV_25    [  8 16 24 32 40 48 56  64  80  96 112 128 144 160 ]
 } MPEG_IS;
 
 typedef struct {
-	gchar			*bitrate;				//
-	gchar			*time;					// Temps d'ecoute
-	guint			 SecTime;				// Temps d'ecoute en secondes
-	MPEG_IS			 mpeg_is;				//
-	gchar			*size;					//
-	TAGS			*tags;					// Tags
-	LEVEL_DBFS		 LevelDbfs;				//
+	gchar			*bitrate;							//
+	gchar			*time;								// Temps d'ecoute
+	guint			 SecTime;							// Temps d'ecoute en secondes
+	MPEG_IS			 mpeg_is;							//
+	gchar			*size;								//
+	TAGS			*tags;								// Tags
+	LEVEL_DBFS		 LevelDbfs;							//
 } INFO_MP3;
 
 typedef struct {
-	gchar			*Channels;				//
-	gchar			*Rate;					//
-	gchar			*Nominal_bitrate;			//
-	gchar			*time;					// Temps d'ecoute
-	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*size;					//
-	TAGS			*tags;					// Tags
-	LEVEL_DBFS		 LevelDbfs;				// Datas du dBFS
+	gchar			*Channels;							//
+	gchar			*Rate;								//
+	gchar			*Nominal_bitrate;					//
+	gchar			*time;								// Temps d'ecoute
+	guint			 SecTime;							// Temps d'ecoute en secondes
+	gchar			*size;								//
+	TAGS			*tags;								// Tags
+	LEVEL_DBFS		 LevelDbfs;							// Datas du dBFS
 } INFO_OGG;
 
 typedef struct {
-	gchar			*time;					// Temps d'ecoute
-	guint			 SecTime;				// Temps d'ecoute en secondes
-	TAGS			*tags;					// Tags
+	gchar			*time;								// Temps d'ecoute
+	guint			 SecTime;							// Temps d'ecoute en secondes
+	TAGS			*tags;								// Tags
 } INFO_FLAC;
 
 typedef struct {
-	TAGS			*tags;					// Tags
+	TAGS			*tags;								// Tags
 } INFO_WMA;
 
 typedef struct {
-	TAGS			*tags;					// Tags
+	TAGS			*tags;								// Tags
 } INFO_RM;
 
 typedef struct {
-	TAGS			*tags;					// Tags
+	TAGS			*tags;								// Tags
 } INFO_DTS;
 
 typedef struct {
-	TAGS			*tags;					// Tags
+	TAGS			*tags;								// Tags
 } INFO_AIFF;
 
 typedef struct {
-	gchar			*namefile;				// Nom complet du fichier
-	TAGS			*tags;					// Tags
+	gchar			*namefile;							// Nom complet du fichier
+	TAGS			*tags;								// Tags
 } INFO_MPC;
 
 typedef struct {
-	TAGS			*tags;					// Tags
-	gchar			*time;					// Temps d'ecoute
-	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*size;					//
+	TAGS			*tags;								// Tags
+	gchar			*time;								// Temps d'ecoute
+	guint			 SecTime;							// Temps d'ecoute en secondes
+	gchar			*size;								//
 } INFO_SHN;
 
 typedef struct {
-	TAGS			*tags;					// Tags
-	gchar			*time;					// Temps d'ecoute
-	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*size;					//
+	TAGS			*tags;								// Tags
+	gchar			*time;								// Temps d'ecoute
+	guint			 SecTime;							// Temps d'ecoute en secondes
+	gchar			*size;								//
 } INFO_APE;
 
 typedef struct {
-	TAGS			*tags;					// Tags
-	gchar			*time;					// Temps d'ecoute
-	guint			 SecTime;				// Temps d'ecoute en secondes
-	gchar			*size;					//
+	TAGS			*tags;								// Tags
+	gchar			*time;								// Temps d'ecoute
+	guint			 SecTime;							// Temps d'ecoute en secondes
+	gchar			*size;								//
 } INFO_WAVPACK;
 
 typedef struct {
-	TAGS			*tags;					// Tags
+	TAGS			*tags;								// Tags
 } INFO_AC3;
 
 /*
@@ -192,13 +192,13 @@ typedef struct {
 */
 
 typedef struct {
-	gboolean		 Bool_Conv;				// TRUE si conversion
-	gchar			*destwav;				// Temporaire: Pathname
-	gchar			*destsox;				// Temporaire: Pathname
-	gchar			*destmp3;				// Temporaire: Pathname
-	gchar			*destogg;				// Temporaire: Pathname
-	gchar			*destfile;				// Destination du fichier apres rectification
-	gchar			*Bitrate;				// Le bitrate actuel
+	gboolean		 Bool_Conv;							// TRUE si conversion
+	gchar			*destwav;							// Temporaire: Pathname
+	gchar			*destsox;							// Temporaire: Pathname
+	gchar			*destmp3;							// Temporaire: Pathname
+	gchar			*destogg;							// Temporaire: Pathname
+	gchar			*destfile;							// Destination du fichier apres rectification
+	gchar			*Bitrate;							// Le bitrate actuel
 } CONV_FIC_MP3OGG;
 
 //
@@ -208,11 +208,11 @@ typedef struct {
 //
 
 typedef struct {
-	gchar			*Path;					// Path du fichier source
-	gchar			*TmpSrc;				// $TMP/original
-	gchar			*TmpDest;				// $TMP/modifie
-	gchar			*TmpMplayer;				// $TMP/
-	gchar			*NameDest;				// Copie vers la destination
+	gchar			*Path;								// Path du fichier source
+	gchar			*TmpSrc;							// $TMP/original
+	gchar			*TmpDest;							// $TMP/modifie
+	gchar			*TmpMplayer;						// $TMP/
+	gchar			*NameDest;							// Copie vers la destination
 } CONV_FIC_WAV;
 
 //
@@ -225,7 +225,7 @@ typedef enum {
 	FILE_IS_NONE = 0,
 	FILE_IS_FLAC,
 	FILE_IS_WAV,
-	// FILE_IS_BFW,	// BROADCAST WAVE FORMAT
+	// FILE_IS_BFW,										// BROADCAST WAVE FORMAT
 	FILE_IS_MP3,
 	FILE_IS_OGG,
 	/* Les fichiers au format AAC, portant l'extension
@@ -293,19 +293,19 @@ RMS
 */
 typedef enum {
 	NORM_NONE = 0,
-	NORM_READY_FOR_SELECT,						// Pret a la selection wav,mp3, ogg
-	NORM_PEAK_ALBUM,						// NORM_PEAK_ALBUM
-	NORM_PEAK,							// NORM_PEAK
-	NORM_RMS_MIX_ALBUM,						//( scan) NORM_RMS_MIX_ALBUM
-	NORM_RMS_FIX							//( scan) NORM_RMS_FIX
+	NORM_READY_FOR_SELECT,								// Pret a la selection wav,mp3, ogg
+	NORM_PEAK_ALBUM,									// NORM_PEAK_ALBUM
+	NORM_PEAK,											// NORM_PEAK
+	NORM_RMS_MIX_ALBUM,									//( scan) NORM_RMS_MIX_ALBUM
+	NORM_RMS_FIX										//( scan) NORM_RMS_FIX
 } ETAT_NORMALISE;
 
 typedef enum {
-	RPG_NONE = 0,							// Attente de selection
-	RPG_ATTENTE,							// Attente de selection
-	RPG_PISTE,							// Mode PISTE
-	RPG_ALBUM,							// Mode ALBUM
-	RPG_EFFACER							// Mode EFFACER
+	RPG_NONE = 0,										// Attente de selection
+	RPG_ATTENTE,										// Attente de selection
+	RPG_PISTE,											// Mode PISTE
+	RPG_ALBUM,											// Mode ALBUM
+	RPG_EFFACER											// Mode EFFACER
 } ETAT_REPLAYGAIN;
 
 typedef enum {
@@ -346,56 +346,56 @@ enum {
 
 
 typedef struct {
-	ETAT_PLAY_FILE		 EtatPlay;				//
-	gchar			*name_dest;				// Nom du fichier de destination sans le path ni l'extension
-	gchar			*dest_flac;				//
-	gchar			*dest_wav;				//
-	gchar			*dest_mp3;				//
-	gchar			*dest_ogg;				//
-	gchar			*dest_m4a;				//
-	gchar			*dest_aac;				//
-	gchar			*dest_mpc;				//
-	gchar			*dest_ape;				//
-	gchar			*dest_wavpack;				//
-	gchar			*dest_wavpack_md5;			//
-	gchar			*tmp_flac;				//
-	gchar			*tmp_wav;				//
-	gchar			*tmp_sox;				// wav to wav
-	gchar			*tmp_sox_24;				// wav to wav
-	gchar			*tmp_mp3;				//
-	gchar			*tmp_ogg;				//
-	gchar			*tmp_m4a;				//
-	gchar			*tmp_aac;				//
-	gchar			*tmp_shn;				//
-	gchar			*tmp_wma;				//
-	gchar			*tmp_rm;				//
-	gchar			*tmp_dts;				//
-	gchar			*tmp_aiff;				//
-	gchar			*tmp_mpc;				//
-	gchar			*tmp_ape;				//
-	gchar			*tmp_wavpack;				//
-	gchar			*tmp_wavpack_md5;			//
-	gchar			*tmp_ac3;				//
-	gboolean		 BoolEtatConv [ ETAT_BOOL_TOTAL ];	//
-	ETAT_CONV_FILE		 Etat_Flac;				//
-	ETAT_CONV_FILE		 Etat_Wav;				//
-	ETAT_CONV_FILE		 Etat_Mp3;				//
-	ETAT_CONV_FILE		 Etat_Ogg;				//
-	ETAT_CONV_FILE		 Etat_m4a;				//
-	ETAT_CONV_FILE		 Etat_aac;				//
-	ETAT_CONV_FILE		 Etat_Mpc;				//
-	ETAT_CONV_FILE		 Etat_Ape;				//
-	ETAT_CONV_FILE		 Etat_wavpack;				//
-	gboolean		 BoolNewString;				//
+	ETAT_PLAY_FILE		 EtatPlay;						//
+	gchar			*name_dest;							// Nom du fichier de destination sans le path ni l'extension
+	gchar			*dest_flac;							//
+	gchar			*dest_wav;							//
+	gchar			*dest_mp3;							//
+	gchar			*dest_ogg;							//
+	gchar			*dest_m4a;							//
+	gchar			*dest_aac;							//
+	gchar			*dest_mpc;							//
+	gchar			*dest_ape;							//
+	gchar			*dest_wavpack;						//
+	gchar			*dest_wavpack_md5;					//
+	gchar			*tmp_flac;							//
+	gchar			*tmp_wav;							//
+	gchar			*tmp_sox;							// wav to wav
+	gchar			*tmp_sox_24;						// wav to wav
+	gchar			*tmp_mp3;							//
+	gchar			*tmp_ogg;							//
+	gchar			*tmp_m4a;							//
+	gchar			*tmp_aac;							//
+	gchar			*tmp_shn;							//
+	gchar			*tmp_wma;							//
+	gchar			*tmp_rm;							//
+	gchar			*tmp_dts;							//
+	gchar			*tmp_aiff;							//
+	gchar			*tmp_mpc;							//
+	gchar			*tmp_ape;							//
+	gchar			*tmp_wavpack;						//
+	gchar			*tmp_wavpack_md5;					//
+	gchar			*tmp_ac3;							//
+	gboolean		 BoolEtatConv [ ETAT_BOOL_TOTAL ];
+	ETAT_CONV_FILE		 Etat_Flac;						//
+	ETAT_CONV_FILE		 Etat_Wav;						//
+	ETAT_CONV_FILE		 Etat_Mp3;						//
+	ETAT_CONV_FILE		 Etat_Ogg;						//
+	ETAT_CONV_FILE		 Etat_m4a;						//
+	ETAT_CONV_FILE		 Etat_aac;						//
+	ETAT_CONV_FILE		 Etat_Mpc;						//
+	ETAT_CONV_FILE		 Etat_Ape;						//
+	ETAT_CONV_FILE		 Etat_wavpack;					//
+	gboolean		 BoolNewString;						//
 
 } CONV_FIC;
 
 typedef enum {
-	STRUCT_NO_REMOVE = 0,						//
-	STRUCT_ALL_REMOVE,						// Remove in treeview ALL FILE
-	STRUCT_WAV_REMOVE_WAV,						// Remove in treeview WAV
-	STRUCT_MP3OGG_REMOVE,						// Remove in treeview MP3OGG
-	STRUCT_SPLIT_REMOVE						// Remove in treeview SPLIT
+	STRUCT_NO_REMOVE = 0,								//
+	STRUCT_ALL_REMOVE,									// Remove in treeview ALL FILE
+	STRUCT_WAV_REMOVE_WAV,								// Remove in treeview WAV
+	STRUCT_MP3OGG_REMOVE,								// Remove in treeview MP3OGG
+	STRUCT_SPLIT_REMOVE									// Remove in treeview SPLIT
 } TYPE_REMOVE_STRUCT;
 
 
@@ -407,41 +407,41 @@ typedef enum {
 
 
 typedef struct {
-	gchar			*namefile;				// Nom complet du fichier
+	gchar			*namefile;							// Nom complet du fichier
 	gchar			*NameFileCopyFromNormalizate;		//
-	gchar			*NameDest;				// Nom de la destination
+	gchar			*NameDest;							// Nom de la destination
 	TYPE_FILE_IS		 type_infosong_file_is;			// Type du fichier
-	void 			*info;					// En fonction du type de fichier pointeur sur INFO_xxx
-	ETAT_TRASH_FILE		 EtatTrash;				// Etat pour la poubelle
-	ETAT_SELECTION		 EtatSelection_Wav;			// Etat de la selection WAV
+	void 			*info;								// En fonction du type de fichier pointeur sur INFO_xxx
+	ETAT_TRASH_FILE		 EtatTrash;						// Etat pour la poubelle
+	ETAT_SELECTION		 EtatSelection_Wav;				// Etat de la selection WAV
 	ETAT_SELECTION		 EtatSelection_Flac;			// Etat de la selection FLAC
-	ETAT_SELECTION		 EtatSelection_Ape;			// Etat de la selection APE
+	ETAT_SELECTION		 EtatSelection_Ape;				// Etat de la selection APE
 	ETAT_SELECTION		 EtatSelection_WavPack;			// Etat de la selection WAVPACK
-	ETAT_SELECTION		 EtatSelection_Ogg;			// Etat de la selection OGG
-	ETAT_SELECTION		 EtatSelection_M4a;			// Etat de la selection M4A
-	ETAT_SELECTION		 EtatSelection_Aac;			// Etat de la selection AAC
-	ETAT_SELECTION		 EtatSelection_Mpc;			// Etat de la selection MPC
-	ETAT_SELECTION		 EtatSelection_Mp3;			// Etat de la selection MP3
-	ETAT_NORMALISE		 Etat_Normalise;			// Etat de la selection de normalisation
-	ETAT_SCAN		 Etat_Scan;				// Etat de la selection du scan
-	gint			 LevelMix;				// Niveau du MIX
-	ETAT_REPLAYGAIN		 Etat_ReplayGain;			// Etat de la selection du gain
-	CONV_FIC		*PConv;					// Pointeur pour conversion de tous les fichiers
-	CONV_FIC_WAV		*PConvWav;				// Pointeur pour conversion WAV TO WAV
-	CONV_FIC_MP3OGG		*PConvMp3Ogg;				// Pointeur pour modification bitrate mp3 et ogg
-	TYPE_REMOVE_STRUCT	 BoolRemove;				// TRUE si suppression de la liste sinon FALSE
+	ETAT_SELECTION		 EtatSelection_Ogg;				// Etat de la selection OGG
+	ETAT_SELECTION		 EtatSelection_M4a;				// Etat de la selection M4A
+	ETAT_SELECTION		 EtatSelection_Aac;				// Etat de la selection AAC
+	ETAT_SELECTION		 EtatSelection_Mpc;				// Etat de la selection MPC
+	ETAT_SELECTION		 EtatSelection_Mp3;				// Etat de la selection MP3
+	ETAT_NORMALISE		 Etat_Normalise;				// Etat de la selection de normalisation
+	ETAT_SCAN		 Etat_Scan;							// Etat de la selection du scan
+	gint			 LevelMix;							// Niveau du MIX
+	ETAT_REPLAYGAIN		 Etat_ReplayGain;				// Etat de la selection du gain
+	CONV_FIC		*PConv;								// Pointeur pour conversion de tous les fichiers
+	CONV_FIC_WAV		*PConvWav;						// Pointeur pour conversion WAV TO WAV
+	CONV_FIC_MP3OGG		*PConvMp3Ogg;					// Pointeur pour modification bitrate mp3 et ogg
+	TYPE_REMOVE_STRUCT	 BoolRemove;					// TRUE si suppression de la liste sinon FALSE
 
 	// MP3: DEBIT MODE
-	gint			Mp3_Debit;				//
-	gint			Mp3_Mode;				//
+	gint			Mp3_Debit;							//
+	gint			Mp3_Mode;							//
 	// OGG: DEBIT MANAGED DOWNMIX
-	gint			Ogg_Debit;				//
-	gint			Ogg_Managed;				//
-	gint			Ogg_Downmix;				//
-	gboolean		BoolChanged;				//
+	gint			Ogg_Debit;							//
+	gint			Ogg_Managed;						//
+	gint			Ogg_Downmix;						//
+	gboolean		BoolChanged;						//
 } DETAIL;
 
-extern GList *entetefile;						// pointeur sur DETAIL
+extern GList *entetefile;								// pointeur sur DETAIL
 
 //
 // ---------------------------------------------------------------------------
@@ -449,29 +449,29 @@ extern GList *entetefile;						// pointeur sur DETAIL
 // ---------------------------------------------------------------------------
 //
 typedef struct {
-	GtkComboBox		*AdrComboboxNormalise;			// Adresse
+	GtkComboBox		*AdrComboboxNormalise;				// Adresse
 	GtkSpinButton		*AdrSpinbuttonNormalise;		// Adresse
-	GtkWidget		*Adr_Label_Number;			// Adresse
-	GtkWidget		*Adr_scroll;				// Adresse
-	GtkListStore		*Adr_List_Store;			// Adresse
-	GtkTreeModel		*Adr_Tree_Model;			// Adresse
-	GtkTreeSelection	*Adr_Line_Selected;			// Adresse
-	GtkWidget		*Adr_TreeView;				// Adresse
-	GtkComboBox		*Adr_combobox_DestFile;			// Adresse
-	GtkComboBox		*Adr_combobox_select_type;		// Adresse
-	GtkComboBox		*Adr_combobox_normalise;		// Adresse
-	GdkPixbuf		*Pixbuf_Trash;				// trash.png
-	GdkPixbuf		*Pixbuf_NoTrash;			// coche.png
-	GdkPixbuf		*Pixbuf_FilePlay;			// play.png
-	GdkPixbuf		*Pixbuf_FileStop;			// sol.png
-	GdkPixbuf		*Pixbuf_Coche;				// coche.png
-	GdkPixbuf		*Pixbuf_Coche_exist;			// coche_exist.png
-	GdkPixbuf		*Pixbuf_Selected;			// selected.png
-	GdkPixbuf		*Pixbuf_Selected_exist;			// selected_exist.png
-	GdkPixbuf		*Pixbuf_Selected_expert;		// selected_expert.png
+	GtkWidget		*Adr_Label_Number;					// Adresse
+	GtkWidget		*Adr_scroll;						// Adresse
+	GtkListStore		*Adr_List_Store;				// Adresse
+	GtkTreeModel		*Adr_Tree_Model;				// Adresse
+	GtkTreeSelection	*Adr_Line_Selected;				// Adresse
+	GtkWidget		*Adr_TreeView;						// Adresse
+	GtkComboBox		*Adr_combobox_DestFile;				// Adresse
+	GtkComboBox		*Adr_combobox_select_type;			// Adresse
+	GtkComboBox		*Adr_combobox_normalise;			// Adresse
+	GdkPixbuf		*Pixbuf_Trash;						// trash.png
+	GdkPixbuf		*Pixbuf_NoTrash;					// coche.png
+	GdkPixbuf		*Pixbuf_FilePlay;					// play.png
+	GdkPixbuf		*Pixbuf_FileStop;					// sol.png
+	GdkPixbuf		*Pixbuf_Coche;						// coche.png
+	GdkPixbuf		*Pixbuf_Coche_exist;				// coche_exist.png
+	GdkPixbuf		*Pixbuf_Selected;					// selected.png
+	GdkPixbuf		*Pixbuf_Selected_exist;				// selected_exist.png
+	GdkPixbuf		*Pixbuf_Selected_expert;			// selected_expert.png
 	GdkPixbuf		*Pixbuf_Selected_expert_exist;		// selected_expert_exist.png
-	GdkPixbuf		*Pixbuf_Normalize_Coche;		// normalize2.png
-	GdkPixbuf		*Pixbuf_NotInstall;			// not_install.png
+	GdkPixbuf		*Pixbuf_Normalize_Coche;			// normalize2.png
+	GdkPixbuf		*Pixbuf_NotInstall;					// not_install.png
 	GtkCellRenderer		*Renderer;
 	GtkTreeViewColumn	*Adr_ColumnFilePlay;
 	GtkTreeViewColumn	*Adr_ColumnFileTrash;
@@ -490,28 +490,28 @@ typedef struct {
 	GtkTreeViewColumn	*Adr_ColumnFileReplayGain;
 	GtkTreeViewColumn	*Adr_ColumnFileName;
 	gint			 PageNum;
-	GdkPixbuf		*Pixbuf_rpg_piste;			// rpg_piste.png
-	GdkPixbuf		*Pixbuf_rpg_album;			// rpg_album.png
-	GdkPixbuf		*Pixbuf_rpg_effacer;			// rpg_effacer.png
-	GdkPixbuf		*Pixbuf_rpg_wait;			// rpg_wait.png
+	GdkPixbuf		*Pixbuf_rpg_piste;					// rpg_piste.png
+	GdkPixbuf		*Pixbuf_rpg_album;					// rpg_album.png
+	GdkPixbuf		*Pixbuf_rpg_effacer;				// rpg_effacer.png
+	GdkPixbuf		*Pixbuf_rpg_wait;					// rpg_wait.png
 
-	GdkPixbuf		*Pixbuf_norm_fix;			// norm_fix.png
-	GdkPixbuf		*Pixbuf_norm_mix;			// norm_mix.png
-	GdkPixbuf		*Pixbuf_norm_peak;			// norm_peak.png
-	GdkPixbuf		*Pixbuf_norm_wait;			// norm_wait.png
+	GdkPixbuf		*Pixbuf_norm_fix;					// norm_fix.png
+	GdkPixbuf		*Pixbuf_norm_mix;					// norm_mix.png
+	GdkPixbuf		*Pixbuf_norm_peak;					// norm_peak.png
+	GdkPixbuf		*Pixbuf_norm_wait;					// norm_wait.png
 
 } VAR_FILE;
 
 extern VAR_FILE var_file;
 
 typedef struct {
-	GtkWidget		*Adr_scroll;				// Adresse
-	GtkListStore		*Adr_List_Store;			// Adresse
-	GtkTreeModel		*Adr_Tree_Model;			// Adresse
-	GtkTreeSelection	*Adr_Line_Selected;			// Adresse
-	GtkWidget		*Adr_TreeView;				// Adresse
-	GtkWidget		*Adr_Entry_Dest;			// Adresse
-	GdkPixbuf		*Pixbuf_NotInstall;			// not_install.png
+	GtkWidget		*Adr_scroll;						// Adresse
+	GtkListStore		*Adr_List_Store;				// Adresse
+	GtkTreeModel		*Adr_Tree_Model;				// Adresse
+	GtkTreeSelection	*Adr_Line_Selected;				// Adresse
+	GtkWidget		*Adr_TreeView;						// Adresse
+	GtkWidget		*Adr_Entry_Dest;					// Adresse
+	GdkPixbuf		*Pixbuf_NotInstall;					// not_install.png
 	GtkCellRenderer		*Renderer;
 	GtkTreeViewColumn	*Adr_ColumnFileWavHertz;
 	GtkTreeViewColumn	*Adr_ColumnFileWavVoie;
@@ -526,15 +526,15 @@ typedef struct {
 extern VAR_FILE_WAV var_file_wav;
 
 typedef struct {
-	GtkWidget		*Adr_scroll;				// Adresse
-	GtkListStore		*Adr_List_Store;			// Adresse
-	GtkTreeModel		*Adr_Tree_Model;			// Adresse
-	GtkTreeSelection	*Adr_Line_Selected;			// Adresse
-	GtkWidget		*Adr_TreeView;				// Adresse
-	GtkWidget		*Adr_Entry_Dest;			// Adresse
-	GtkWidget		*Adr_Button_Dest;			// Adresse
-	GtkComboBox		*Adr_combobox_DestFile;			// Adresse
-	GdkPixbuf		*Pixbuf_NotInstall;			// not_install.png
+	GtkWidget		*Adr_scroll;						// Adresse
+	GtkListStore		*Adr_List_Store;				// Adresse
+	GtkTreeModel		*Adr_Tree_Model;				// Adresse
+	GtkTreeSelection	*Adr_Line_Selected;				// Adresse
+	GtkWidget		*Adr_TreeView;						// Adresse
+	GtkWidget		*Adr_Entry_Dest;					// Adresse
+	GtkWidget		*Adr_Button_Dest;					// Adresse
+	GtkComboBox		*Adr_combobox_DestFile;				// Adresse
+	GdkPixbuf		*Pixbuf_NotInstall;					// not_install.png
 	GtkCellRenderer		*Renderer;
 	GtkTreeViewColumn	*Adr_ColumnFileMp3OggType;
 	GtkTreeViewColumn	*Adr_ColumnFileMp3OggBitrate;
@@ -547,18 +547,17 @@ typedef struct {
 extern VAR_FILE_MP3OGG var_file_mp3ogg;
 
 typedef struct {
-	GtkWidget		*Adr_scroll;				// Adresse
-	GtkListStore		*Adr_List_Store;			// Adresse
-	GtkTreeModel		*Adr_Tree_Model;			// Adresse
-	GtkTreeSelection	*Adr_Line_Selected;			// Adresse
-	GtkWidget		*Adr_TreeView;				// Adresse
+	GtkWidget		*Adr_scroll;						// Adresse
+	GtkListStore		*Adr_List_Store;				// Adresse
+	GtkTreeModel		*Adr_Tree_Model;				// Adresse
+	GtkTreeSelection	*Adr_Line_Selected;				// Adresse
+	GtkWidget		*Adr_TreeView;						// Adresse
 	GtkWidget		*Adr_entry_tag_album;
 	GtkWidget		*Adr_entry_tag_title;
 	GtkWidget		*Adr_entry_tag_artist;
 	GtkWidget		*Adr_entry_tag_comment;
 	GtkWidget		*Adr_spinbutton_tag_year;
 	GtkWidget		*Adr_spinbutton_tag_track;
-	GtkComboBox		*Adr_combobox_tag_genre;
 	GtkWidget		*Adr_label_tag_change;
 	GtkWidget		*Adr_table_tag;
 	GtkCellRenderer		*Renderer;
@@ -673,6 +672,7 @@ gboolean	FileWav_del_file_clicked( void );
 gboolean	FileTags_del_file_clicked( void );
 void		FileTags_appliquer_clicked( void );
 void		FileTags_set_flag_buttons( void );
+void 		FileTags_changed_all_tags (gint TYPE_TAG);
 //
 // ---------------------------------------------------------------------------
 //  FILE_WAV_CONV.C
@@ -717,7 +717,7 @@ typedef struct {
 // Allocate Tab Args
 //
 gchar		**filelc_AllocTabArgs( void );
-gchar		**filelc_RevoveTab( gchar **p_PtrTabArgs );
+gchar		**filelc_RemoveTab( gchar **p_PtrTabArgs );
 // gint		filelc_get_command_line_remove( void );
 // gint		filelc_get_command_line_nice( void );
 gchar		**filelc_get_command_line( PARAM_FILELC *param_filelc );
@@ -731,9 +731,6 @@ void		filelc_get_command_line_extract_elem( gint Elem, gchar *Dev, gchar *Dest )
 //
 void		filetrash_action( void );
 gboolean	filetrash_ok( void );
-gboolean	filetrash_move_to_trash( gchar *Name );
-gchar		*filetrash_get_trash( void );
-void		filetrash_test_trash_is_ok( void );
 
 
 #endif
