@@ -1,9 +1,9 @@
  /*
  *  file      : file_action.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -177,12 +177,12 @@ static gint fileaction_timeout (gpointer data)
 	    FALSE == FileAction.bool_trash) {
 		
 		WindScan_close ();
-		gtk_timeout_remove (FileAction.handler_timeout);
+		g_source_remove (FileAction.handler_timeout);
 		
 		if (FALSE == conv.bool_stop) {
-			NotifySend_msg (_("XCFA: Traitement fichiers"), _("Ok"), conv.bool_stop);
+			NotifySend_msg (_("XCFA: Processing files"), _("Ok"), conv.bool_stop);
 		} else {
-			NotifySend_msg (_("XCFA: Traitement fichiers"), _("Arret par l'utilisateur"), conv.bool_stop);
+			NotifySend_msg (_("XCFA: Processing files"), _("Stop by user"), conv.bool_stop);
 		}
 	}
 	
@@ -229,7 +229,7 @@ void fileaction_choice (void)
 	FileAction.bool_ReplaygainApply    = file_get_bool_ReplaygainApply ();
 	FileAction.bool_trash              = filetrash_ok ();
 		
-	FileAction.handler_timeout = gtk_timeout_add (150, fileaction_timeout, 0);
+	FileAction.handler_timeout = g_timeout_add (150, fileaction_timeout, 0);
 }
 
 
