@@ -1,9 +1,9 @@
  /*
  *  file      : file_analyse.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -719,17 +719,18 @@ static gint fileanalyze_timeout (gpointer data)
 	}
 	else if (FALSE == VarAnalyze.BoolInThread) {
 		WindScan_close ();
-		gtk_timeout_remove (VarAnalyze.HandlerTimeoutDo);
+		g_source_remove (VarAnalyze.HandlerTimeoutDo);
 		file_affiche_glist ();
 		FileWav_affiche_glist ();
 		FileMp3Ogg_affiche_glist ();
 		FileTags_affiche_glist ();
 		
 		if (TRUE == VarAnalyze.BoolNoFindCheckMp3) {
-			wininfo_create (
+			wind_info_init (
 				WindMain,
 				_("Package checkmp3 (mp3check) NOT FOUND !"),
-				_("Veuillez installer checkmp3 ou mp3check pour\nla prise en compte des fichiers mp3"),
+				_("Please install or checkmp3 mp3check for\nconsideration of mp3 files"),
+				
 			  	"");
 		}
 	}
@@ -747,7 +748,12 @@ void fileanalyze_add_file_to_treeview (TYPE_FILESELECTION p_TypeFileselection, G
 	
 	if (NULL == p_list) return;
 	
-	WindScan_open ("Files scan", WINDSCAN_PULSE);
+	// WindScan_open ("Files scan", WINDSCAN_PULSE);
+	wind_scan_init(
+		WindMain,
+		"Files scan",
+		WINDSCAN_PULSE
+		);
 	WindScan_set_label ("<b><i>Scan directory, verify and load ...</i></b>");
 	
 	// TYPE DE FICHIER EN RECHERCHE
@@ -770,7 +776,7 @@ void fileanalyze_add_file_to_treeview (TYPE_FILESELECTION p_TypeFileselection, G
 	VarAnalyze.BoolNoFindCheckMp3 = FALSE;
 	
 	pthread_create (&nmr_tid_1, NULL ,(void *)fileanalyze_thread, (void *)NULL);
-	VarAnalyze.HandlerTimeoutDo = gtk_timeout_add (100, fileanalyze_timeout, 0);
+	VarAnalyze.HandlerTimeoutDo = g_timeout_add (100, fileanalyze_timeout, 0);
 }
 
 
