@@ -1,9 +1,9 @@
  /*
  *  file      : file_lc.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -68,7 +68,7 @@ gchar **filelc_AllocTabArgs( void )
 // 
 // Remove Tab Args
 // 
-gchar **filelc_RevoveTab( gchar **p_PtrTabArgs )
+gchar **filelc_RemoveTab( gchar **p_PtrTabArgs )
 {
 	gint	i;
 	
@@ -402,6 +402,30 @@ gchar **filelc_get_command_line( PARAM_FILELC *param_filelc )
 		
 		if (Config.BoolGenreTag && param_filelc->tags && param_filelc->tags->Genre && *param_filelc->tags->Genre) {
 			
+
+/**
+NAME
+       lame - create mp3 audio files
+
+SYNOPSIS
+       lame [options] <infile> <outfile>
+
+DESCRIPTION
+       LAME  is  a  program which can be used to create compressed audio files.
+       (Lame ain't an MP3 encoder).
+       These audio files can be played back by popular MP3 players such as mpg123 or madplay.
+       To read from stdin, use "-" for <infile>.
+       To write to stdout, use "-" for <outfile>.
+
+OPTIONS
+      ID3 tag options:
+
+      Input options:
+      --tg genre
+              audio/song genre (name or number in list)
+
+*/
+			/**
 			gint value = 147;
 			
 			if (param_filelc->tags->bool_tag_cd == FALSE) {
@@ -410,10 +434,15 @@ gchar **filelc_get_command_line( PARAM_FILELC *param_filelc )
 				value = param_filelc->tags->IntGenre;
 			}
 			if (value < 0 || value > 147) value = 147;
-			/*New = g_list_append (New, g_strdup ("--tg"));
-			New = g_list_append (New, g_strdup_printf ("%d", value));*/
+			// New = g_list_append (New, g_strdup ("--tg"));
+			// New = g_list_append (New, g_strdup_printf ("%d", value));
 			PtrTabArgs [ pos++ ] = g_strdup ("--tg");
 			PtrTabArgs [ pos++ ] = g_strdup_printf ("%d", value);
+			*/
+			PtrTabArgs [ pos++ ] = g_strdup ("--tg");
+			PtrTabArgs [ pos++ ] = g_strdup_printf ("%s", param_filelc->tags->Genre);
+			
+			
 		}
 		
 		if (Config.BoolYearTag && param_filelc->tags && param_filelc->tags->Year && *param_filelc->tags->Year) {
