@@ -1,9 +1,9 @@
  /*
  *  file      : file_mp3ogg.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -89,7 +89,6 @@ enum
 	COLUMN_FILEMP3OGG_SIZE,
 	COLUMN_FILEMP3OGG_TIME,
 	COLUMN_FILEMP3OGG_NAME,
-	COLUMN_FILEMP3OGG_COLOR,
 	COLUMN_FILEMP3OGG_POINTER_STRUCT,
 
 	COLUMN_FILE_NUM
@@ -506,7 +505,7 @@ void FileMp3Ogg_affiche_glist (void)
 						COLUMN_FILEMP3OGG_SIZE,			file_get_size (detail),
 						COLUMN_FILEMP3OGG_TIME,			file_get_time (detail),
 						COLUMN_FILEMP3OGG_NAME,			NameDest,
-						COLUMN_FILEMP3OGG_COLOR,		&YellowColor,
+						// COLUMN_FILEMP3OGG_COLOR,		&YellowColor,
 						COLUMN_FILEMP3OGG_POINTER_STRUCT,	detail,
 						-1);
 			
@@ -595,7 +594,7 @@ gboolean FileMp3Ogg_key_press_event (GtkWidget *widget, GdkEventKey *event, gpoi
 		gtk_tree_selection_unselect_all (var_file_mp3ogg.Adr_Line_Selected);
 		gtk_tree_selection_select_all (var_file_mp3ogg.Adr_Line_Selected);
 	}
-	if (keys.keyval == GDK_Delete) {
+	if (keys.keyval == GDK_KEY_Delete) {
 		GtkTreeIter   iter;
 		if (gtk_tree_model_get_iter_first (var_file_mp3ogg.Adr_Tree_Model, &iter)) {
 			on_file_button_del_file_clicked (NULL, NULL);
@@ -621,8 +620,11 @@ gboolean FileMp3Ogg_event (GtkWidget *treeview, GdkEvent *event, gpointer user_d
 	gboolean            BoolSelectColNom = FALSE;
 	gboolean            BoolSelectNewBitrate = FALSE;
 	
-	// SI PAS DANS LE TREEVIEW
-	gdk_window_get_pointer (((GdkEventButton*)event)->window, &x, &y, &state);
+	/* Si pas de selection a cet endroit retour */
+	GdkDeviceManager *manager = gdk_display_get_device_manager( gdk_display_get_default() );
+	GdkDevice		 *device = gdk_device_manager_get_client_pointer( manager );
+	gdk_window_get_device_position( ((GdkEventButton*)event)->window, device, &x, &y, &state );
+	// gdk_window_get_pointer (((GdkEventButton*)event)->window, &x, &y, &state);
 	if (FALSE == gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(treeview),
 					   x, y,
 					   &path, &column, &Pos_X, &Pos_Y)) {
@@ -665,7 +667,7 @@ gboolean FileMp3Ogg_event (GtkWidget *treeview, GdkEvent *event, gpointer user_d
 		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, detail->namefile );
 	}
 	else if( BoolSelectNewBitrate ) {
-		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("Click droit: acces popup") );
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("Right click: access popup") );
 	}
 	
 	StatusBar_puts( );
@@ -674,17 +676,20 @@ gboolean FileMp3Ogg_event (GtkWidget *treeview, GdkEvent *event, gpointer user_d
 }
 // 
 // 
-static void FileMp3Ogg_drag_data_received (GtkWidget	   *widget,
-					GdkDragContext     *drag_context,
-					gint                x,
-					gint                y,
-					GtkSelectionData   *data,
-					guint               info,
-					guint               time)
+static void FileMp3Ogg_drag_data_received(
+					GtkWidget        *widget,
+					GdkDragContext   *context,
+					gint              x,
+					gint              y,
+					GtkSelectionData *data,
+					guint             info,
+					guint             time,
+					gpointer          user_data)
 {
-        /* Une copie ne peut aller vers elle meme !!! */
-	if (gtk_drag_get_source_widget(drag_context) != widget) {
-		dragndrop_list_drag_data (widget, (gchar *)data->data);
+	// Une copie ne peut aller vers elle meme !!! */
+	if (gtk_drag_get_source_widget(context) != widget) {
+		// dragndrop_list_drag_data (widget, (gchar *)data->data);
+		dragndrop_list_drag_data( widget, (gchar*)gtk_selection_data_get_data( data ));
 	}
 }
 // 
@@ -725,7 +730,8 @@ static void FileMp3Ogg_drag_data_drop (GtkWidget *widget,
 
 			gtk_selection_data_set( selection_data,
 						// GDK_SELECTION_TYPE_STRING,
-						selection_data->target,
+						// selection_data->target,
+						GDK_POINTER_TO_ATOM(gtk_selection_data_get_data( selection_data )),
 						8,
 						(guchar *)text,
 						strlen( text )
@@ -896,7 +902,7 @@ static void FileMp3Ogg_add_columns_scrolledwindow (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	var_file_mp3ogg.Adr_ColumnFileMp3OggBitrate =
-	column = gtk_tree_view_column_new_with_attributes (_("Bitrate"),
+	column = gtk_tree_view_column_new_with_attributes ("Bitrate",
 						     renderer,
 						     "text", COLUMN_FILEMP3OGG_BITRATE,
 						     NULL);
@@ -912,7 +918,7 @@ static void FileMp3Ogg_add_columns_scrolledwindow (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	var_file_mp3ogg.Adr_ColumnFileMp3OggNewBitrate =
-	column = gtk_tree_view_column_new_with_attributes (_("Nouveau bitrate"),
+	column = gtk_tree_view_column_new_with_attributes (_("New bitrate"),
 						     renderer,
 						     "markup", COLUMN_FILEMP3OGG_NEWBITRATE,
 						     NULL);
@@ -926,7 +932,7 @@ static void FileMp3Ogg_add_columns_scrolledwindow (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	var_file_mp3ogg.Adr_ColumnFileMp3OggSize =
-	column = gtk_tree_view_column_new_with_attributes (_("Taille"),
+	column = gtk_tree_view_column_new_with_attributes (_("Size"),
 						     renderer,
 						     "text", COLUMN_FILEMP3OGG_SIZE,
 						     NULL);
@@ -940,7 +946,7 @@ static void FileMp3Ogg_add_columns_scrolledwindow (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	var_file_mp3ogg.Adr_ColumnFileMp3OggTime =
-	column = gtk_tree_view_column_new_with_attributes (_("Temps"),
+	column = gtk_tree_view_column_new_with_attributes (_("Time"),
 						     renderer,
 						     "text", COLUMN_FILEMP3OGG_TIME,
 						     NULL);
@@ -955,10 +961,10 @@ static void FileMp3Ogg_add_columns_scrolledwindow (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	var_file_mp3ogg.Adr_ColumnFileMp3OggName =
-	column = gtk_tree_view_column_new_with_attributes (_("Nom"),
+	column = gtk_tree_view_column_new_with_attributes (_("Name"),
 						     renderer,
 						     "markup", COLUMN_FILEMP3OGG_NAME,
-						      "background-gdk", COLUMN_FILEMP3OGG_COLOR,
+						     // "background-gdk", COLUMN_FILEMP3OGG_COLOR,
 						     NULL);
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
 				   GTK_TREE_VIEW_COLUMN_FIXED);
@@ -986,13 +992,13 @@ void on_scrolledwindow_file_mp3ogg_realize (GtkWidget *widget, gpointer user_dat
 				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_SIZE		*/
 				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_TIME		*/
 				G_TYPE_STRING,		/* COLUMN_FILEMP3OGG_NAME		*/
-				GDK_TYPE_COLOR,		/* COLUMN_FILEMP3OGG_COLOR		*/
+				// GDK_TYPE_COLOR,		/* COLUMN_FILEMP3OGG_COLOR		*/
 				G_TYPE_POINTER          /* COLUMN_FILEMP3OGG_POINTER_STRUCT	*/
 			   );
 	var_file_mp3ogg.Adr_Tree_Model = model = GTK_TREE_MODEL (store);
 	var_file_mp3ogg.Adr_TreeView =
 	treeview = gtk_tree_view_new_with_model (model);
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
+	// gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
 	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview)), GTK_SELECTION_MULTIPLE);	// GTK_SELECTION_BROWSE MULTIPLE
 	g_object_unref (model);
 	gtk_container_add (GTK_CONTAINER (widget), treeview);
