@@ -1,9 +1,9 @@
  /*
  *  file      : file_mp3ogg_conv.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -128,7 +128,7 @@ static void filemp3oggconv_thread (void *arg)
 				PtrTabArgs [ pos++ ] = g_strdup ("44100");
 				PtrTabArgs [ pos++ ] = NULL;
 				conv_to_convert( PtrTabArgs, FALSE, MPLAYER_WAV_TO_WAV, "MPLAYER_WAV_TO_WAV");
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 				
 				if( TRUE == libutils_test_file_exist( PConvMp3Ogg->destwav )) {
 					
@@ -143,7 +143,7 @@ static void filemp3oggconv_thread (void *arg)
 						}
 						PtrTabArgs = conv_with_sox_get_param( PConvMp3Ogg->destwav, PConvMp3Ogg->destsox, "44100", "2", "16" );
 						conv_to_convert( PtrTabArgs, FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-						PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+						PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 						conv_copy_src_to_dest (PConvMp3Ogg->destsox, PConvMp3Ogg->destwav);
 					
 						// conv.encode_completed ++;
@@ -169,7 +169,7 @@ static void filemp3oggconv_thread (void *arg)
 
 						PtrTabArgs = filelc_get_command_line (&param_filelc);
 						conv_to_convert( PtrTabArgs, FALSE, LAME_WAV_TO_MP3, "LAME_WAV_TO_MP3");
-						PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+						PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 
 						/* copy SOURCE MP3 -> DESTINATION MP3
 						*  ----------------------------------
@@ -213,7 +213,7 @@ static void filemp3oggconv_thread (void *arg)
 				PtrTabArgs [ pos++ ] = g_strdup ("44100");
 				PtrTabArgs [ pos++ ] = NULL;
 				conv_to_convert( PtrTabArgs, param_filelc.With_CommandLineUser, MPLAYER_OGG_TO_WAV, "MPLAYER_OGG_TO_WAV");
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 								
 				if( TRUE == libutils_test_file_exist( PConvMp3Ogg->destwav ) && libutils_get_size_file( PConvMp3Ogg->destwav ) > 0 ) {
 					
@@ -236,7 +236,7 @@ static void filemp3oggconv_thread (void *arg)
 
 					PtrTabArgs = filelc_get_command_line (&param_filelc);
 					conv_to_convert( PtrTabArgs, FALSE, OGGENC_WAV_TO_OGG, "OGGENC_WAV_TO_OGG");
-					PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+					PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 				
 					/* copy SOURCE OGG -> DESTINATION MP3
 					*  ----------------------------------
@@ -321,36 +321,36 @@ static gint filemp3oggconv_timeout (gpointer data)
 			conv.TmpRep  = libutils_remove_temporary_rep (conv.TmpRep);
 		}
 
-		gtk_timeout_remove (conv.handler_timeout_conv);
+		g_source_remove (conv.handler_timeout_conv);
 		WindScan_close ();
 		FileMp3Ogg_set_flag_buttons ();
 
 		if (FALSE == conv.bool_stop) {
-			NotifySend_msg (_("XCFA: Modification bitrate"), _("Ok"), conv.bool_stop);
+			NotifySend_msg (_("XCFA: Bitrate change"), _("Ok"), conv.bool_stop);
 		} else {
-			NotifySend_msg (_("XCFA: Modification bitrate"), _("Arret par l'utilisateur"), conv.bool_stop);
+			NotifySend_msg (_("XCFA: Bitrate change"), _("Stop by user"), conv.bool_stop);
 		}
 		if( TRUE == BoolErrMplayer ) {
-			wininfo_create (
+			wind_info_init (
 				WindMain,
-				_("Erreur depuis MPLAYER !"),
-				_("Vous pouvez activer XCFA en ligne de commande avec:         "),
+				_("Error from MPLAYER !"),
+				_("You can enable XCFA command line with:         "),
 				  "\n",
 				_("$ xcfa -verbose"),
 				  "\n",
-				_("pour consulter le type d'erreur renvoye par mplayer."),
+				_("to see the type of error returned by mplayer."),
 			  	"");
 		
 		}
 		else if( TRUE == BoolErrSox ) {
-			wininfo_create (
+			wind_info_init (
 				WindMain,
-				_("Erreur depuis SOX !"),
-				_("Vous pouvez activer XCFA en ligne de commande avec:         "),
+				_("Error from SOX !"),
+				_("You can enable XCFA command line with:         "),
 				  "\n",
 				_("$ xcfa -verbose"),
 				  "\n",
-				_("pour consulter le type d'erreur renvoye par sox."),
+				_("to see the type of error returned by sox."),
 			  	"");
 		
 		}
@@ -429,7 +429,7 @@ gboolean filemp3oggconv_is_regul_ok (void) {
 
 	if (bool_mp3 && bool_ogg) {
 		if (FALSE == PrgInit.bool_mplayer || FALSE == PrgInit.bool_lame || FALSE == PrgInit.bool_oggenc)
-		str = g_strdup_printf (_("   ATTENTION: Il faut installer   %s%s%s"),
+		str = g_strdup_printf (_("   WARNING : you need to install   %s%s%s"),
 					FALSE == PrgInit.bool_mplayer ? " \n   MPLAYER" : "",
 					FALSE == PrgInit.bool_lame    ? " \n   LAME"    : "",
 					FALSE == PrgInit.bool_oggenc  ? " \n   OGGENC"  : ""
@@ -437,19 +437,19 @@ gboolean filemp3oggconv_is_regul_ok (void) {
 	}
 	else if (bool_mp3) {
 		if (FALSE == PrgInit.bool_mplayer || FALSE == PrgInit.bool_lame)
-		str = g_strdup_printf (_("   ATTENTION: Il faut installer   %s%s"),
+		str = g_strdup_printf (_("   WARNING : you need to install   %s%s"),
 					FALSE == PrgInit.bool_mplayer ? " \n   MPLAYER" : "",
 					FALSE == PrgInit.bool_lame    ? " \n   LAME"    : ""
 					);
 	}
 	else if (bool_ogg) {
 		if (FALSE == PrgInit.bool_oggenc)
-		str = g_strdup_printf (_("   ATTENTION: Il faut installer   %s"),
+		str = g_strdup_printf (_("   WARNING : you need to install   %s"),
 					FALSE == PrgInit.bool_oggenc ? " \n   OGGENC"  : ""
 					);
 	}
 	if (NULL != str) {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
 			_("Package NOT FOUND !"),
 			str,
@@ -471,7 +471,12 @@ void filemp3oggconv_apply_regul_mp3ogg_by_conv (void)
 
 	if (TRUE == filemp3oggconv_is_regul_ok ()) {
 		
-		WindScan_open ("Conversions bitrate", WINDSCAN_PULSE);
+		// WindScan_open ("Conversions bitrate", WINDSCAN_PULSE);
+		wind_scan_init(
+			WindMain,
+			"Conversions bitrate",
+			WINDSCAN_PULSE
+			);
 		WindScan_set_label ("<b><i>Conversions bitrate ...</i></b>");
 	
 		BoolErrMplayer = FALSE;
@@ -481,7 +486,7 @@ void filemp3oggconv_apply_regul_mp3ogg_by_conv (void)
 		filemp3oggconv_set_flags_before_conversion ();
 		conv.bool_thread_conv = TRUE;
  		pthread_create (&nmr_tid, NULL ,(void *)filemp3oggconv_thread, (void *)NULL);
- 		conv.handler_timeout_conv = gtk_timeout_add (100, filemp3oggconv_timeout, 0);
+ 		conv.handler_timeout_conv = g_timeout_add (100, filemp3oggconv_timeout, 0);
 	}
 }
 
