@@ -1,9 +1,9 @@
  /*
  *  file      : file_scan_db.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -200,7 +200,7 @@ static gint FileScanDB_timeout (gpointer data)
 	
 	if (VarFileScanDB.bool_thread_end == TRUE) {
 		if (FALSE == VarFileScanDB.BoolWindScanUsed) WindScan_close ();
-		gtk_timeout_remove (VarFileScanDB.handler_timeout);
+		g_source_remove (VarFileScanDB.handler_timeout);
 	}
 	
 	return (TRUE);
@@ -221,8 +221,14 @@ void FileScanDB_action (gboolean BoolAllScan)
 		VarFileScanDB.bool_update = FALSE;
 		VarFileScanDB.MessUser = NULL;
 		
-		VarFileScanDB.BoolWindScanUsed = WindScan_open ("Scan dBFS", WINDSCAN_PULSE);
-		VarFileScanDB.handler_timeout = gtk_timeout_add (50, FileScanDB_timeout, 0);
+		// VarFileScanDB.BoolWindScanUsed = WindScan_open ("Scan dBFS", WINDSCAN_PULSE);
+		VarFileScanDB.BoolWindScanUsed =
+			wind_scan_init(
+				WindMain,
+				"Scan dBFS",
+				WINDSCAN_PULSE
+				);
+		VarFileScanDB.handler_timeout = g_timeout_add (50, FileScanDB_timeout, 0);
 		pthread_create (&VarFileScanDB.nmr_tid, NULL ,(void *)FileScanDB_thread, (void *)NULL);
 	}
 }
