@@ -1,9 +1,9 @@
  /*
  *  file      : file_tags.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -57,6 +57,7 @@
 #include "file.h"
 #include <taglib/tag_c.h>
 #include "statusbar.h"
+#include "popup.h"
 
 
 
@@ -67,7 +68,6 @@ enum
 	COLUMN_FILETAGS_TYPE = 0,
 	COLUMN_FILETAGS_TIME,
 	COLUMN_FILETAGS_NAME,
-	COLUMN_FILETAGS_COLOR,
 	
 	COLUMN_FILETAGS_POINTER_STRUCT,
 
@@ -352,20 +352,18 @@ void FileTags_set_spinbutton_tag_track (void)
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (var_file_tags.Adr_spinbutton_tag_track), (gdouble)tags->IntNumber);
 	FileTags_bool_changed_OK = TRUE;
 }
-// 
-// 
-void FileTags_set_combobox_tag_genre (void)
+void FileTags_set_combobox_tag_genre( void )
 {
 	TAGS  *tags = FileTags_get_tag (NULL);
-	
-	if (NULL == var_file_tags.Adr_combobox_tag_genre) return;
-	if (NULL == tags) return;
-	
+	// tags->Genre = g_strdup( FilePopupGenre.name );
+	// tags->IntGenre = tags_get_genre_by_value( FilePopupGenre.name );
 	FileTags_bool_changed_OK = FALSE;
-
-	gtk_combo_box_set_active (GTK_COMBO_BOX (var_file_tags.Adr_combobox_tag_genre), tags_get_elements_combobox (tags->IntGenre));
+	gtk_entry_set_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_tag_genre_file")), tags->Genre ? tags->Genre : "" );
+	printf(">tags->Genre     = %s\n", tags->Genre );
+	printf(">tags->IntGenre  = %d\n", tags->IntGenre );
 	FileTags_bool_changed_OK = TRUE;
 }
+
 // CETTE FONCTION INDIQUE QU UNE MODIFICATION DE TAG A EU LIEU
 // FLAG MODIFIE:         : LA COLONNE 'TYPE' EST EN ROUGE GRAS
 // APRES UNE SAUVEGARDE  : COLONNE 'TYPE'  EST EN COULEUR NORMALE
@@ -491,12 +489,29 @@ void FileTags_changed_all_tags (gint TYPE_TAG)
 				switch (TYPE_TAG) {
 				case TAG_GENRE :
 					if (NULL != (tags = FileTags_get_tag (detail))) {
-						g_free (tags->Genre);
-						tags->Genre = NULL;
-						tags->Genre = g_strdup ((gchar *)gtk_combo_box_get_active_text (var_file_tags.Adr_combobox_tag_genre));
-						tags->IntGenre = tags_get_num_combobox ((gint)gtk_combo_box_get_active (var_file_tags.Adr_combobox_tag_genre));
-						tags_set_flag_modification (tags, TRUE);
-						FileTags_set_label_tag_change ();
+						if( TRUE == FilePopupGenre.BoolFromPopup ) {
+							printf("TRUE == FilePopupGenre.BoolFromPopup\n");
+							if( tags->Genre )
+								g_free (tags->Genre);
+							tags->Genre = NULL;
+							tags->Genre = g_strdup( FilePopupGenre.name );
+							tags->IntGenre = tags_get_genre_by_value( FilePopupGenre.name );
+							gtk_entry_set_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_tag_genre_file")), FilePopupGenre.name );
+							if( TRUE == FileTags_bool_changed_OK )
+								tags_set_flag_modification (tags, TRUE);
+							FileTags_set_label_tag_change ();
+						}
+						else {
+							printf("FALSE == FilePopupGenre.BoolFromPopup\n");
+							if( tags->Genre )
+								g_free (tags->Genre);
+							tags->Genre = NULL;
+							tags->Genre = g_strdup( (gchar *)gtk_entry_get_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_tag_genre_file")) ));
+							tags->IntGenre = tags_get_genre_by_value( tags->Genre );
+							if( TRUE == FileTags_bool_changed_OK )
+								tags_set_flag_modification (tags, TRUE);
+							FileTags_set_label_tag_change ();
+						}
 					}
 					break;
 				case TAG_TRACK :
@@ -649,24 +664,64 @@ void on_spinbutton_tag_year_file_changed (GtkWidget *widget, gpointer user_data)
 	if (FALSE == FileTags_bool_changed_OK) return;
 	FileTags_changed_all_tags (TAG_YEAR);
 }
-// 
-// 
-void on_combobox_tag_genre_file_realize (GtkWidget *widget, gpointer user_data)
+
+#define _CONTACT_NAME_	0
+void on_entry_tag_genre_file_changed( GtkEditable *editable, gpointer user_data )
 {
-	libcombo_alloc (GTK_COMBO_BOX (widget));
-	tags_set_elements_combobox (widget);
-	gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (widget), 4);
-	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
-	var_file_tags.Adr_combobox_tag_genre = GTK_COMBO_BOX (widget);
+	gchar	*PtrEntry = NULL;
+	gint	NumEntry = -1;
+	
+	if( FALSE == FilePopupGenre.BoolFromPopup ) {
+		PRINT_FUNC_LF();
+		PtrEntry = (gchar *)gtk_entry_get_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_tag_genre_file")));
+		NumEntry = tags_get_genre_by_value( PtrEntry );
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print( "\tPtrEntry = %s\n", PtrEntry );
+			g_print( "\tNumEntry = %d\n", NumEntry);
+		}
+		FileTags_changed_all_tags (TAG_GENRE);
+		// cd_expander_set_genre( NumEntry, PtrEntry );
+	}
 }
-// 
-// 
-void on_combobox_tag_genre_file_changed (GtkComboBox *combobox, gpointer user_data)
+/**
+gboolean on_match_select_file(GtkEntryCompletion *widget, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{  
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		GValue value = {0, };
+		gtk_tree_model_get_value(model, iter, _CONTACT_NAME_, &value);
+		g_print( "You have selected %s\n", g_value_get_string(&value) );
+		g_value_unset(&value);
+	}
+	return FALSE;
+}    
+*/
+void on_entry_tag_genre_file_realize( GtkWidget *widget, gpointer user_data )
 {
-	if (NULL == var_file_tags.Adr_combobox_tag_genre) return;
-	if (FALSE == FileTags_bool_changed_OK) return;
-	FileTags_changed_all_tags (TAG_GENRE);
+	STRUCT_TAGS_FILE_MP3	*Contact;
+	GtkEntryCompletion		*completion;
+	GtkListStore			*model;
+	GtkTreeIter				iter;
+	
+	// set up completion
+	completion = gtk_entry_completion_new();
+	gtk_entry_completion_set_text_column( completion, _CONTACT_NAME_ );
+	gtk_entry_set_completion( GTK_ENTRY(widget), completion );
+	// g_signal_connect( G_OBJECT(completion), "match-selected", G_CALLBACK(on_match_select_file), NULL );
+	g_signal_connect( G_OBJECT(widget), "changed", G_CALLBACK(on_entry_tag_genre_file_changed), widget );
+	model = gtk_list_store_new( 1, G_TYPE_STRING );
+	for( Contact = StructTagsFileMp3; Contact && Contact->name; Contact++ ) {
+		gtk_list_store_append( model, &iter );
+		gtk_list_store_set( model, &iter, _CONTACT_NAME_, Contact->name, -1 );
+	}
+	gtk_entry_completion_set_model( completion, GTK_TREE_MODEL(model) );
 }
+
+
+void on_button_tag_call_popup_file_clicked( GtkButton *button, gpointer user_data )
+{
+	popup_menu_file();
+}
+
 // 
 // 
 void on_spinbutton_tag_track_file_realize (GtkWidget *widget, gpointer user_data)
@@ -891,7 +946,7 @@ void FileTags_affiche_glist( void )
 						COLUMN_FILETAGS_TYPE,		tags_get_str_type_file_is (detail->type_infosong_file_is),
 						COLUMN_FILETAGS_TIME,		file_get_time (detail),
 						COLUMN_FILETAGS_NAME,		NameDest,
-						COLUMN_FILETAGS_COLOR,		&YellowColor,
+						// COLUMN_FILETAGS_COLOR,		&YellowColor,
 						COLUMN_FILETAGS_POINTER_STRUCT,	detail,
 						-1);
 						
@@ -960,7 +1015,7 @@ gboolean FileTags_key_press_event (GtkWidget *widget, GdkEventKey *event, gpoint
 		gtk_tree_selection_unselect_all (var_file_tags.Adr_Line_Selected);
 		gtk_tree_selection_select_all (var_file_tags.Adr_Line_Selected);
 	}
-	if (keys.keyval == GDK_Delete) {
+	if (keys.keyval == GDK_KEY_Delete) {
 		GtkTreeIter   iter;
 		if (gtk_tree_model_get_iter_first (var_file_tags.Adr_Tree_Model, &iter)) {
 			on_file_button_del_file_clicked (NULL, NULL);
@@ -989,8 +1044,11 @@ gboolean FileTags_event (GtkWidget *treeview, GdkEvent *event, gpointer user_dat
 	// return (FALSE);
 	// PRINT_FUNC_LF();
 		
-	// SI PAS DANS LE TREEVIEW
-	gdk_window_get_pointer (((GdkEventButton*)event)->window, &x, &y, &state);
+	/* Si pas de selection a cet endroit retour */
+	GdkDeviceManager *manager = gdk_display_get_device_manager( gdk_display_get_default() );
+	GdkDevice		 *device = gdk_device_manager_get_client_pointer( manager );
+	gdk_window_get_device_position( ((GdkEventButton*)event)->window, device, &x, &y, &state );
+	// gdk_window_get_pointer (((GdkEventButton*)event)->window, &x, &y, &state);
 	if (FALSE == gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(treeview),
 					   x, y,
 					   &path, &column, &Pos_X, &Pos_Y)) {
@@ -1036,18 +1094,21 @@ gboolean FileTags_event (GtkWidget *treeview, GdkEvent *event, gpointer user_dat
 }
 // 
 // 
-static void FileTags_drag_data_received (GtkWidget	   *widget,
-					GdkDragContext     *drag_context,
-					gint                x,
-					gint                y,
-					GtkSelectionData   *data,
-					guint               info,
-					guint               time)
+static void FileTags_drag_data_received(
+					GtkWidget        *widget,
+					GdkDragContext   *context,
+					gint              x,
+					gint              y,
+					GtkSelectionData *data,
+					guint             info,
+					guint             time,
+					gpointer          user_data)
 {
 	/* PRINT_FUNC_LF(); */
         /* Une copie ne peut aller vers elle meme !!! */
-	if (gtk_drag_get_source_widget(drag_context) != widget) {
-		dragndrop_list_drag_data (widget, (gchar *)data->data);
+	if (gtk_drag_get_source_widget(context) != widget) {
+		//dragndrop_list_drag_data (widget, (gchar *)data->data);
+		dragndrop_list_drag_data( widget, (gchar*)gtk_selection_data_get_data( data ));
 	}
 }
 // 
@@ -1089,7 +1150,8 @@ static void FileTags_drag_data_drop (GtkWidget *widget,
 
 			gtk_selection_data_set( selection_data,
 						// GDK_SELECTION_TYPE_STRING,
-						selection_data->target,
+						// selection_data->target,
+						GDK_POINTER_TO_ATOM(gtk_selection_data_get_data( selection_data )),
 						8,
 						(guchar *)text,
 						strlen( text )
@@ -1172,7 +1234,7 @@ void FileTags_add_columns_scrolledwindow (GtkTreeView *treeview)
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	// var_file_tags.Adr_ColumnFileWavNewHertz =
 	var_file_tags.Adr_ColumnFileTagsTime =
-	column = gtk_tree_view_column_new_with_attributes (_("Temps"),
+	column = gtk_tree_view_column_new_with_attributes (_("Time"),
 						     renderer,
 						     "markup", COLUMN_FILETAGS_TIME,
 						     NULL);
@@ -1188,10 +1250,10 @@ void FileTags_add_columns_scrolledwindow (GtkTreeView *treeview)
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	// var_file_tags.Adr_ColumnFileWavNewHertz =
 	var_file_tags.Adr_ColumnFileTagsName =
-	column = gtk_tree_view_column_new_with_attributes (_("Nom"),
+	column = gtk_tree_view_column_new_with_attributes (_("Name"),
 						     renderer,
 						     "markup", COLUMN_FILETAGS_NAME,
-						      "background-gdk", COLUMN_FILETAGS_COLOR,
+						     // "background-gdk", COLUMN_FILETAGS_COLOR,
 						     NULL);
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
 				   GTK_TREE_VIEW_COLUMN_FIXED);
@@ -1215,13 +1277,13 @@ void on_scrolledwindow_tags_file_realize (GtkWidget *widget, gpointer user_data)
 				G_TYPE_STRING,		// COLUMN_FILETAGS_TYPE
 				G_TYPE_STRING,		// COLUMN_FILETAGS_TIME
 				G_TYPE_STRING,		// COLUMN_FILETAGS_NAME
-				GDK_TYPE_COLOR,		// COLUMN_FILETAGS_COLOR
+				// GDK_TYPE_COLOR,		// COLUMN_FILETAGS_COLOR
 				G_TYPE_POINTER          // COLUMN_FILETAGS_POINTER_STRUCT
 			   );
 	var_file_tags.Adr_Tree_Model = model = GTK_TREE_MODEL (store);
 	var_file_tags.Adr_TreeView =
 	treeview = gtk_tree_view_new_with_model (model);
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
+	// gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
 	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview)), GTK_SELECTION_MULTIPLE);	// GTK_SELECTION_BROWSE MULTIPLE
 	g_object_unref (model);
 	gtk_container_add (GTK_CONTAINER (widget), treeview);
