@@ -1,9 +1,9 @@
  /*
  *  file      : file_wav.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -67,7 +67,6 @@ enum
 	COLUMN_FILEWAV_BITS,
 	COLUMN_FILEWAV_NEW_BITS,
 	COLUMN_FILEWAV_NAME,
-	COLUMN_FILEWAV_COLOR,
 	
 	COLUMN_FILEWAV_POINTER_STRUCT,
 
@@ -271,7 +270,7 @@ void FileWav_affiche_glist (void)
 						COLUMN_FILEWAV_BITS,		info->bits,
 						COLUMN_FILEWAV_NEW_BITS,	NewBits,
 						COLUMN_FILEWAV_NAME,		NameDest,
-						COLUMN_FILEWAV_COLOR,		&YellowColor,
+						// COLUMN_FILEWAV_COLOR,		&YellowColor,
 						COLUMN_FILEWAV_POINTER_STRUCT,	detail,
 						-1);
 									
@@ -436,8 +435,11 @@ gboolean FileWav_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data
 	gboolean            BoolSelectColPISTE = FALSE;
 	gboolean            BoolSelectColQUANTIFICATION = FALSE;
 	
-	// SI PAS DANS LE TREEVIEW
-	gdk_window_get_pointer (((GdkEventButton*)event)->window, &x, &y, &state);
+	/* Si pas de selection a cet endroit retour */
+	GdkDeviceManager *manager = gdk_display_get_device_manager( gdk_display_get_default() );
+	GdkDevice		 *device = gdk_device_manager_get_client_pointer( manager );
+	gdk_window_get_device_position( ((GdkEventButton*)event)->window, device, &x, &y, &state );
+	// gdk_window_get_pointer (((GdkEventButton*)event)->window, &x, &y, &state);
 	if (FALSE == gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW(treeview),
 					   x, y,
 					   &path, &column, &Pos_X, &Pos_Y)) {
@@ -480,13 +482,13 @@ gboolean FileWav_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data
 		}
 	}
 	if (TRUE == BoolSelectColFREQUENCE) {
-		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("(Click Droit = Menu) / Choix de la frequence"));
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("(Right Click = Menu) / Select frequency"));
 	}
 	else if (TRUE == BoolSelectColPISTE) {
-		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("(Click Droit = Menu) / Choix du nombre de pistes (voies)"));
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("(Right Click = Menu) / Select number of tracks (channels)"));
 	}
 	else if (TRUE == BoolSelectColQUANTIFICATION) {
-		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("(Click Droit = Menu) / Choix du codage en nombre de bits"));
+		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, _("(Right Click = Menu) / Encoding selection in number of bits"));
 	}
 	else if (TRUE == BoolSelectColNom) {
 		StatusBar_set_mess( NOTEBOOK_FICHIERS, _STATUSBAR_SIMPLE_, detail->namefile);
@@ -500,17 +502,20 @@ gboolean FileWav_event (GtkWidget *treeview, GdkEvent *event, gpointer user_data
 }
 // 
 // 
-static void FileWav_drag_data_received (GtkWidget	   *widget,
-					GdkDragContext     *drag_context,
-					gint                x,
-					gint                y,
-					GtkSelectionData   *data,
-					guint               info,
-					guint               time)
+static void FileWav_drag_data_received(
+					GtkWidget        *widget,
+					GdkDragContext   *context,
+					gint              x,
+					gint              y,
+					GtkSelectionData *data,
+					guint             info,
+					guint             time,
+					gpointer          user_data)
 {
         /* Une copie ne peut aller vers elle meme !!! */
-	if (gtk_drag_get_source_widget(drag_context) != widget) {
-		dragndrop_list_drag_data (widget, (gchar *)data->data);
+	if (gtk_drag_get_source_widget(context) != widget) {
+		// dragndrop_list_drag_data (widget, (gchar *)data->data);
+		dragndrop_list_drag_data( widget, (gchar*)gtk_selection_data_get_data( data ));
 	}
 }
 // 
@@ -551,7 +556,8 @@ static void FileWav_drag_data_drop (GtkWidget *widget,
 			
 			gtk_selection_data_set( selection_data,
 						// GDK_SELECTION_TYPE_STRING,
-						selection_data->target,
+						// selection_data->target,
+						GDK_POINTER_TO_ATOM(gtk_selection_data_get_data( selection_data )),
 						8,
 						(guchar *)text,
 						strlen( text )
@@ -570,7 +576,7 @@ gboolean FileWav_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointe
 		gtk_tree_selection_unselect_all (var_file_wav.Adr_Line_Selected);
 		gtk_tree_selection_select_all (var_file_wav.Adr_Line_Selected);
 	}
-	if (keys.keyval == GDK_Delete) {
+	if (keys.keyval == GDK_KEY_Delete) {
 		GtkTreeIter   iter;
 		if (gtk_tree_model_get_iter_first (var_file_wav.Adr_Tree_Model, &iter)) {
 			on_file_button_del_file_clicked (NULL, NULL);
@@ -597,8 +603,8 @@ gboolean FileWav_event_click_mouse (GtkWidget *treeview, GdkEventButton *event,
 	// GdkPixbuf          *Pixbuf = NULL;
 	DETAIL             *detail = NULL;
 	gint                Pos_X = 0, Pos_Y = 0;
-	// gboolean            bool_key_Control = (keys.keyval == GDK_Control_L || keys.keyval == GDK_Control_R);
-	// gboolean            bool_key_Shift   = (keys.keyval == GDK_Shift_L || keys.keyval == GDK_Shift_R);
+	// gboolean            bool_key_Control = (keys.keyval == GDK_KEY_Control_L || keys.keyval == GDK_KEY_Control_R);
+	// gboolean            bool_key_Shift   = (keys.keyval == GDK_KEY_Shift_L || keys.keyval == GDK_KEY_Shift_R);
 	// gboolean            bool_key_Release = (bool_key_Control == FALSE &&  bool_key_Shift == FALSE);
 	// gboolean            bool_click_gauche = (event->button == 1);
 	gboolean            bool_click_droit = (event->button == 3);	
@@ -730,7 +736,7 @@ static void FileWav_add_columns_scrolledwindow (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	var_file_wav.Adr_ColumnFileWavHertz =
-	column = gtk_tree_view_column_new_with_attributes (_("Frequence"),
+	column = gtk_tree_view_column_new_with_attributes (_("Frequency"),
 						     renderer,
 						     "text", COLUMN_FILEWAV_HERTZ,
 						     NULL);
@@ -746,7 +752,7 @@ static void FileWav_add_columns_scrolledwindow (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	var_file_wav.Adr_ColumnFileWavNewHertz =
-	column = gtk_tree_view_column_new_with_attributes (_("FREQUENCE"),
+	column = gtk_tree_view_column_new_with_attributes (_("FREQUENCY"),
 						     renderer,
 						     "markup", COLUMN_FILEWAV_NEW_HERTZ,
 						     NULL);
@@ -760,7 +766,7 @@ static void FileWav_add_columns_scrolledwindow (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	var_file_wav.Adr_ColumnFileWavVoie =
-	column = gtk_tree_view_column_new_with_attributes (_("Piste"),
+	column = gtk_tree_view_column_new_with_attributes (_("Track"),
 						     renderer,
 						     "text", COLUMN_FILEWAV_VOIE,
 						     NULL);
@@ -776,7 +782,7 @@ static void FileWav_add_columns_scrolledwindow (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	var_file_wav.Adr_ColumnFileWavNewVoie =
-	column = gtk_tree_view_column_new_with_attributes (_("PISTE"),
+	column = gtk_tree_view_column_new_with_attributes (_("TRACK"),
 						     renderer,
 						     "markup", COLUMN_FILEWAV_NEW_VOIE,
 						     NULL);
@@ -821,10 +827,10 @@ static void FileWav_add_columns_scrolledwindow (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.5, NULL);
 	var_file_wav.Adr_ColumnFileWavName =
-	column = gtk_tree_view_column_new_with_attributes (_("Nom"),
+	column = gtk_tree_view_column_new_with_attributes (_("Name"),
 						     renderer,
 						     "markup", COLUMN_FILEWAV_NAME,
-						      "background-gdk", COLUMN_FILEWAV_COLOR,
+						     // "background-gdk", COLUMN_FILEWAV_COLOR,
 						     NULL);
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
 				   GTK_TREE_VIEW_COLUMN_FIXED);
@@ -854,13 +860,13 @@ void on_scrolledwindow_file_wav_realize (GtkWidget *widget, gpointer user_data)
 				G_TYPE_STRING,		/* COLUMN_FILEWAV_BITS			*/
 				G_TYPE_STRING,		/* COLUMN_FILEWAV_NEW_BITS		*/
 				G_TYPE_STRING,		/* COLUMN_FILEWAV_NAME			*/
-				GDK_TYPE_COLOR,		/* COLUMN_FILEWAV_COLOR			*/
+				// GDK_TYPE_COLOR,		/* COLUMN_FILEWAV_COLOR			*/
 				G_TYPE_POINTER          /* COLUMN_FILEWAV_POINTER_STRUCT	*/
 			   );
 	var_file_wav.Adr_Tree_Model = model = GTK_TREE_MODEL (store);
 	var_file_wav.Adr_TreeView =
 	treeview = gtk_tree_view_new_with_model (model);
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
+	// gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
 	gtk_tree_selection_set_mode (gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview)), GTK_SELECTION_MULTIPLE);	// GTK_SELECTION_BROWSE MULTIPLE
 	g_object_unref (model);
 	gtk_container_add (GTK_CONTAINER (widget), treeview);
