@@ -1,9 +1,9 @@
  /*
  *  file      : file_wav_conv.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -152,7 +152,7 @@ static void filewavconv_thread (void *arg)
 				
 				VarFilewavconv.BoolMplayer = TRUE;
 				conv_to_convert( PtrTabArgs, FALSE, MPLAYER_WAV_TO_WAV, "MPLAYER_WAV_TO_WAV");
-				PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+				PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 				VarFilewavconv.BoolMplayer = FALSE;
 
 				VarFilewavconv.BoolCopy = TRUE;
@@ -164,7 +164,7 @@ static void filewavconv_thread (void *arg)
 					VarFilewavconv.BoolSox = TRUE;
 					PtrTabArgs = conv_with_sox_get_param (PConvWav->TmpSrc, PConvWav->TmpDest, info->NewHertz, info->NewVoie, info->NewBits);
 					conv_to_convert( PtrTabArgs, FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-					PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+					PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 					
 					VarFilewavconv.BoolSox = FALSE;
 					VarFilewavconv.BoolCopy = TRUE;
@@ -258,7 +258,7 @@ static gint filewavconv_timeout (gpointer data)
 		if (VarFilewavconv.BoolCopy == TRUE) {
 			foo [ 0 ] = filewavconv_get_spinner();
 			foo [ 1 ] = '\0';
-			Str = g_strdup_printf (_("<b><i>%s   Copie fichier: %d%%</i></b>"),
+			Str = g_strdup_printf (_("<b><i>%s   Copy file: %d%%</i></b>"),
 							foo,
 							(gint)(conv.total_percent * 100));
 			WindScan_set_label (Str);
@@ -268,7 +268,7 @@ static gint filewavconv_timeout (gpointer data)
 		else if (VarFilewavconv.BoolRest == TRUE) {	
 			foo [ 0 ] = filewavconv_get_spinner();
 			foo [ 1 ] = '\0';
-			Str = g_strdup_printf (_("<b><i>%s   Restitution fichier: %d%%</i></b>"),
+			Str = g_strdup_printf (_("<b><i>%s   Return file: %d%%</i></b>"),
 							foo,
 							(gint)(conv.total_percent * 100));
 			WindScan_set_label (Str);
@@ -278,7 +278,7 @@ static gint filewavconv_timeout (gpointer data)
 		else if (VarFilewavconv.BoolSox == TRUE) {
 			foo [ 0 ] = filewavconv_get_spinner();
 			foo [ 1 ] = '\0';
-			Str = g_strdup_printf (_("<b><i>%s   Traitement Sox: %d%%</i></b>"),
+			Str = g_strdup_printf (_("<b><i>%s   Use Sox: %d%%</i></b>"),
 							foo,
 							(gint)(conv.total_percent * 100));
 			WindScan_set_label (Str);
@@ -295,7 +295,7 @@ static gint filewavconv_timeout (gpointer data)
 		
 		foo [ 0 ] = filewavconv_get_spinner();
 		foo [ 1 ] = '\0';
-		Str = g_strdup_printf (_("<b><i>%s   Traitement Mplayer: %d%%</i></b>"),
+		Str = g_strdup_printf (_("<b><i>%s   Use Mplayer: %d%%</i></b>"),
 						foo,
 						(gint)(conv.total_percent * 100));
 		WindScan_set_label (Str);
@@ -310,7 +310,7 @@ static gint filewavconv_timeout (gpointer data)
 		CONV_FIC_WAV	*PConvWav = NULL;
 		DETAIL		*detail = NULL;
 		
-		gtk_timeout_remove (conv.handler_timeout_conv);
+		g_source_remove (conv.handler_timeout_conv);
 		WindScan_close ();
 	
 		// SUPPRESSION DE LA STRUCTURE: DETAIL->CONV_FIC_WAV
@@ -342,7 +342,7 @@ static gint filewavconv_timeout (gpointer data)
 		if (FALSE == conv.bool_stop) {
 			NotifySend_msg (_("XCFA: Conversions WAV TO WAV"), _("Ok"), conv.bool_stop);
 		} else {
-			NotifySend_msg (_("XCFA: Conversions WAV TO WAV"), _("Arret par l'utilisateur"), conv.bool_stop);
+			NotifySend_msg (_("XCFA: Conversions WAV TO WAV"), _("Stop by user"), conv.bool_stop);
 		}
 	}
 	
@@ -456,7 +456,12 @@ void filewavconv_apply (void)
 
 	// PRINT_FUNC_LF();
 
-	WindScan_open ("Conversions files WAV", WINDSCAN_PULSE);
+	// WindScan_open ("Conversions files WAV", WINDSCAN_PULSE);
+	wind_scan_init(
+		WindMain,
+		"Conversions files WAV",
+		WINDSCAN_PULSE
+		);
 	WindScan_set_label ("<b><i>Conversions WAV TO WAV ...</i></b>");
 	
 	VarFilewavconv.PassMplayer = 0;
@@ -464,7 +469,7 @@ void filewavconv_apply (void)
 	filewavconv_set_flags_before ();
 
 	conv.bool_thread_conv = TRUE;
-	conv.handler_timeout_conv = gtk_timeout_add (50, filewavconv_timeout, 0);
+	conv.handler_timeout_conv = g_timeout_add (50, filewavconv_timeout, 0);
  	pthread_create (&nmr_tid, NULL ,(void *)filewavconv_thread, (void *)NULL);
 }
 
