@@ -1,9 +1,9 @@
  /*
  *  file      : fileselect.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -102,17 +102,17 @@ void ON_button_PATH_POCHETTE_clicked (GtkButton *button, gpointer user_data);
 
 SELECT Select [ ] =
 {
-{gettext_noop("Choix d'un dossier de destination"),			_REP_SIMPLE_,		NULL, ON_button_PATH_CHOICE_DESTINATION_clicked,		NULL},
-{gettext_noop("Choix d'un fichier CUE WAV FLAC OGG MP3 APE WMA"),	_FILE_SIMPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{gettext_noop("Choix d'un fichier musical"),				_FILE_SIMPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{gettext_noop("Choix d'un fichier"),					_FILE_SIMPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{gettext_noop("Choix de fichiers"),					_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{gettext_noop("Choix de fichiers WAV"),					_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{gettext_noop("Choix de fichiers MP3/OGG"),				_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{gettext_noop("Choix de fichiers FLAC MPC OGG MP3"),			_FILE_MULTIPLE_,	NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
-{gettext_noop("Importer des images pour la pochette"),			_FILE_IMG_MULTIPLE_,	NULL, ON_button_PATH_IMPORT_IMAGES_clicked,			NULL},
-{gettext_noop("Choix d'un chemin de stockage des images"),		_FILE_MULTIPLE_,	NULL, ON_button_PATH_POCHETTE_clicked,				NULL},
-{gettext_noop("Choix d'un lieu de sauvegarde"),				_FILE_MULTIPLE_,	NULL, ON_button_PATH_POCHETTE_clicked,				NULL},
+{gettext_noop("Choosing a destination folder"),					_REP_SIMPLE_,			NULL, ON_button_PATH_CHOICE_DESTINATION_clicked,	NULL},
+{gettext_noop("Choosing a file CUE WAV FLAC OGG MP3 APE WMA"),	_FILE_SIMPLE_,			NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choosing a file musical"),						_FILE_SIMPLE_,			NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choosing a file"),								_FILE_SIMPLE_,			NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choosing a file"),								_FILE_MULTIPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choosing a WAV file"),							_FILE_MULTIPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choosing a MP3 OGG file"),						_FILE_MULTIPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Choosing a FLAC MPC OGG MP3 file"),				_FILE_MULTIPLE_,		NULL, ON_button_PATH_LOAD_ONE_FILE_clicked,			NULL},
+{gettext_noop("Import pictures for the cover"),					_FILE_IMG_MULTIPLE_,	NULL, ON_button_PATH_IMPORT_IMAGES_clicked,			NULL},
+{gettext_noop("Choosing an Image Storage path"),				_FILE_MULTIPLE_,		NULL, ON_button_PATH_POCHETTE_clicked,				NULL},
+{gettext_noop("Choosing a place for backup"),					_FILE_MULTIPLE_,		NULL, ON_button_PATH_POCHETTE_clicked,				NULL},
  
 {NULL, -1}
 };
@@ -334,16 +334,18 @@ void chooserDialog_preview_update (GtkFileChooser *filechooser, gpointer data)
 	}
 }
 // Demande de creation de la fenetre de selection de fichier(s) ou de repertoire
+// https://developer.gnome.org/gtk3/stable/GtkFileChooserDialog.html
 // 
 void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Extern)
 {
 	GtkWidget *filechooserdialog;
-	GtkWidget *dialog_vbox1;
-	GtkWidget *dialog_action_area1;
-	GtkWidget *button_cancel;
-	GtkWidget *button_ok;
+	// GtkWidget *dialog_vbox1;
+	// GtkWidget *dialog_action_area1;
+	// GtkWidget *button_cancel;
+	// GtkWidget *button_ok;
 	GtkWidget *preview;
 	GtkFileFilter *filter;
+	gint			res;
 	
 	if (_NB_PATH_ <= 0) return;
 	if (Choice < 0 || Choice > _NB_PATH_) return;
@@ -354,7 +356,7 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 	filechooserdialog = Select[ Choice ].AdrFileChooser;
 
 	if (filechooserdialog != NULL) {
-		gdk_window_raise (filechooserdialog->window);
+		gdk_window_raise( gtk_widget_get_window(filechooserdialog) );
 		return;
 	}
 
@@ -379,22 +381,42 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 	*/
 	if (Select[ Choice ].TypeSelect == _REP_SIMPLE_ || Select[ Choice ].TypeSelect == _REP_MULTIPLE_) {
 		/* selection de directory */
+		/**
 		filechooserdialog = gtk_file_chooser_dialog_new (Select[ Choice ].Title,
 								  NULL,
 								  GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-								  /* |
-								  GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER,
-								  */
+								  // GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER,
 								  NULL,
 								  NULL);
+		*/
+		filechooserdialog = gtk_file_chooser_dialog_new (
+								Select[ Choice ].Title,
+								NULL,
+								GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+								_("Cancel"),
+								GTK_RESPONSE_CANCEL,
+								_("Open"),
+								GTK_RESPONSE_ACCEPT,
+								NULL);
 	}
 	else if (Select[ Choice ].TypeSelect == _FILE_SIMPLE_ || Select[ Choice ].TypeSelect == _FILE_MULTIPLE_) {
 		/* selection de fichiers(s) */
+		/**
 		filechooserdialog = gtk_file_chooser_dialog_new (Select[ Choice ].Title,
 								  NULL,
 								  GTK_FILE_CHOOSER_ACTION_OPEN,
 								  NULL,
 								  NULL);
+		*/
+		filechooserdialog = gtk_file_chooser_dialog_new (
+								Select[ Choice ].Title,
+								NULL,
+								GTK_FILE_CHOOSER_ACTION_OPEN,
+								_("Cancel"),
+								GTK_RESPONSE_CANCEL,
+								_("Open"),
+								GTK_RESPONSE_ACCEPT,
+								NULL);
 		if (_PATH_LOAD_SPLIT_FILE_ == Choice) {
 			filter = gtk_file_filter_new ();
 			gtk_file_filter_add_pattern (filter, "*.wav");
@@ -663,17 +685,28 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 	}
 	else if (Select[ Choice ].TypeSelect == _FILE_IMG_SIMPLE_ || Select[ Choice ].TypeSelect == _FILE_IMG_MULTIPLE_) {
 		/* selection de fichiers images avec previsualisation */
+		/**
 		filechooserdialog = gtk_file_chooser_dialog_new (Select[ Choice ].Title,
 								  NULL,
 								  GTK_FILE_CHOOSER_ACTION_OPEN,
-								  /*GTK_STOCK_CANCEL,
-								  GTK_RESPONSE_CANCEL,
-								  GTK_STOCK_OPEN,
-								  GTK_RESPONSE_ACCEPT,*/
+								  // GTK_STOCK_CANCEL,
+								  // GTK_RESPONSE_CANCEL,
+								  // GTK_STOCK_OPEN,
+								  // GTK_RESPONSE_ACCEPT,
 								  NULL,
 								  NULL);
+		*/
+		filechooserdialog = gtk_file_chooser_dialog_new (
+								Select[ Choice ].Title,
+								NULL,
+								GTK_FILE_CHOOSER_ACTION_OPEN,
+								_("Cancel"),
+								GTK_RESPONSE_CANCEL,
+								_("Open"),
+								GTK_RESPONSE_ACCEPT,
+								NULL);
 		preview = gtk_image_new ();
-		gtk_widget_set_usize(GTK_WIDGET(preview), 200, 200);
+		gtk_widget_set_size_request(GTK_WIDGET(preview), 200, 200);
 		gtk_file_chooser_set_preview_widget(GTK_FILE_CHOOSER(filechooserdialog),  GTK_WIDGET(preview));
 		gtk_file_chooser_set_preview_widget_active (GTK_FILE_CHOOSER (filechooserdialog), TRUE);
 		g_signal_connect(GTK_FILE_CHOOSER(filechooserdialog), "update-preview", G_CALLBACK (chooserDialog_preview_update), preview);
@@ -701,37 +734,15 @@ void fileselect_create (TYPE_FILESELECTION Choice, gchar *Path, void *Func_Exter
 
 	gtk_window_set_type_hint (GTK_WINDOW (filechooserdialog), GDK_WINDOW_TYPE_HINT_DIALOG);
 
-	dialog_vbox1 = GTK_DIALOG (filechooserdialog)->vbox;
-	gtk_widget_show (dialog_vbox1);
-
-	dialog_action_area1 = GTK_DIALOG (filechooserdialog)->action_area;
-	gtk_widget_show (dialog_action_area1);
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_END);
-
-	button_cancel = gtk_button_new_from_stock ("gtk-cancel");
-	gtk_widget_show (button_cancel);
-	gtk_dialog_add_action_widget (GTK_DIALOG (filechooserdialog), button_cancel, GTK_RESPONSE_CANCEL);
-	GTK_WIDGET_SET_FLAGS (button_cancel, GTK_CAN_DEFAULT);
-
-	button_ok = gtk_button_new_from_stock ("gtk-open");
-	gtk_widget_show (button_ok);
-	gtk_dialog_add_action_widget (GTK_DIALOG (filechooserdialog), button_ok, GTK_RESPONSE_OK);
-	GTK_WIDGET_SET_FLAGS (button_ok, GTK_CAN_DEFAULT);
-
 	g_signal_connect ((gpointer) filechooserdialog, "delete_event", G_CALLBACK (fileselect_on_filechooserdialog_delete_event), (gpointer)Choice);
 	g_signal_connect ((gpointer) filechooserdialog, "destroy_event", G_CALLBACK (fileselect_on_filechooserdialog_destroy_event), (gpointer)Choice);
-	g_signal_connect ((gpointer) button_cancel, "clicked", G_CALLBACK (fileselect_on_button_cancel_clicked), (gpointer)Choice);
-	g_signal_connect ((gpointer) button_ok, "clicked", G_CALLBACK (Select[ Choice ].Call_Func), (gpointer)Choice);
-
-	/* Store pointers to all widgets, for use by lookup_widget().
-	*/
-	GLADE_HOOKUP_OBJECT_NO_REF (filechooserdialog, filechooserdialog, "filechooserdialog");
-	GLADE_HOOKUP_OBJECT_NO_REF (filechooserdialog, dialog_vbox1, "dialog_vbox1");
-	GLADE_HOOKUP_OBJECT_NO_REF (filechooserdialog, dialog_action_area1, "dialog_action_area1");
-	GLADE_HOOKUP_OBJECT (filechooserdialog, button_cancel, "button_cancel");
-	GLADE_HOOKUP_OBJECT (filechooserdialog, button_ok, "button_ok");
-
-	gtk_widget_grab_default (button_ok);
-  	gtk_widget_show (filechooserdialog);
+  	
+  	res = gtk_dialog_run (GTK_DIALOG (filechooserdialog));
+  	if (res == GTK_RESPONSE_ACCEPT) {
+		Select[ Choice ].Call_Func( NULL, (gpointer)Choice );
+	}
+	else if(res == GTK_RESPONSE_CANCEL) {
+		fileselect_on_button_cancel_clicked( NULL, (gpointer)Choice );
+	}
 }
 
