@@ -1,9 +1,9 @@
  /*
  *  file      : global.h
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -49,43 +49,45 @@ extern	GtkWidget	*AdrLabelStatusbarGlobal;
 
 #define GLADE_GET_OBJECT(OBJ) gtk_builder_get_object (GtkXcfaProjet, OBJ)
 
+GtkBuilder *Builder_open( gchar *p_name_glade, GtkBuilder *p_GtkBuilder );
+
 // 
 // ---------------------------------------------------------------------------
 //  NOTEBOOK
 // ---------------------------------------------------------------------------
 // 
 // notebook_general
-#define NOTEBOOK_DVD_AUDIO	0
-#define NOTEBOOK_CD_AUDIO	1
+#define NOTEBOOK_DVD_AUDIO		0
+#define NOTEBOOK_CD_AUDIO		1
 	// notebook_expander_cd
-	#define NOTEBOOK_CD_AUDIO_TAGS		0
-	#define NOTEBOOK_CD_AUDIO_TITRE_CD	1
-	#define NOTEBOOK_CD_AUDIO_CUE		2
-#define NOTEBOOK_FICHIERS	2
+	#define NOTEBOOK_CD_AUDIO_TAGS			0
+	#define NOTEBOOK_CD_AUDIO_TITRE_CD		1
+	#define NOTEBOOK_CD_AUDIO_CUE			2
+#define NOTEBOOK_FICHIERS		2
 	// notebook_in_file
 	#define NOTEBOOK_FICHIERS_CONVERSION	0
-	#define NOTEBOOK_FICHIERS_WAV		1
-	#define NOTEBOOK_FICHIERS_MP3OGG	2	
-	#define NOTEBOOK_FICHIERS_TAGS		3
-#define NOTEBOOK_SPLIT		3
-#define NOTEBOOK_POCHETTE	4
-#define NOTEBOOK_OPTIONS	5
+	#define NOTEBOOK_FICHIERS_WAV			1
+	#define NOTEBOOK_FICHIERS_MP3OGG		2	
+	#define NOTEBOOK_FICHIERS_TAGS			3
+#define NOTEBOOK_SPLIT			3
+#define NOTEBOOK_POCHETTE		4
+#define NOTEBOOK_OPTIONS		5
 	// notebook_options
-	#define NOTEBOOK_OPTIONS_GENERAL	0
-	#define NOTEBOOK_OPTIONS_CD_AUDIO	1
-	#define NOTEBOOK_OPTIONS_LAME		2
-	#define NOTEBOOK_OPTIONS_OGGENC		3
-	#define NOTEBOOK_OPTIONS_FLAC		4
-	#define NOTEBOOK_OPTIONS_MAC		5
-	#define NOTEBOOK_OPTIONS_WAVPACK	6
-	#define NOTEBOOK_OPTIONS_MUSEPACK	7
-	#define NOTEBOOK_OPTIONS_FAAC		8
-	#define NOTEBOOK_OPTIONS_AACPLUSENC	9
+	#define NOTEBOOK_OPTIONS_GENERAL		0
+	#define NOTEBOOK_OPTIONS_CD_AUDIO		1
+	#define NOTEBOOK_OPTIONS_LAME			2
+	#define NOTEBOOK_OPTIONS_OGGENC			3
+	#define NOTEBOOK_OPTIONS_FLAC			4
+	#define NOTEBOOK_OPTIONS_MAC			5
+	#define NOTEBOOK_OPTIONS_WAVPACK		6
+	#define NOTEBOOK_OPTIONS_MUSEPACK		7
+	#define NOTEBOOK_OPTIONS_FAAC			8
+	#define NOTEBOOK_OPTIONS_AACPLUSENC		9
 	#define NOTEBOOK_OPTIONS_EXPORT_TAGS	10
 #define NOTEBOOK_PRGEXTERNES	6
 	// notebook_app_externes
 	#define NOTEBOOK_OPTIONS_PRGEXTERNES	0
-	#define NOTEBOOK_OPTIONS_EXTRA		1
+	#define NOTEBOOK_OPTIONS_EXTRA			1
 
 // 
 // ---------------------------------------------------------------------------
@@ -105,8 +107,8 @@ extern	GtkWidget	*AdrLabelStatusbarGlobal;
 // 
 #ifndef GLADE_HOOKUP_OBJECT
 #define GLADE_HOOKUP_OBJECT(component,widget,name) \
-  g_object_set_data_full (G_OBJECT (component), name, \
-    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)
+  g_object_set_data_full(G_OBJECT(component), name, \
+    g_object_ref(widget), (GDestroyNotify) g_object_unref)
 #endif
 
 #ifndef GLADE_HOOKUP_OBJECT_NO_REF
@@ -125,10 +127,10 @@ extern	GtkWidget	*AdrLabelStatusbarGlobal;
 
 // /usr/include/gtk-2.0/gdk/gdkkeysyms.h
 typedef struct {
-	gboolean	BoolGDKPress;		//
+	gboolean	BoolGDKPress;			//
 	gboolean	BoolGDK_Control_L_R;	// 
-	gboolean	BoolGDK_Control_A;	// 
-	guint		keyval;			// 
+	gboolean	BoolGDK_Control_A;		// 
+	guint		keyval;					// 
 } KEYS;
 
 extern KEYS keys;
