@@ -60,13 +60,11 @@
 #include "get_info.h"
 #include "mplayer.h"
 #include "win_about.h"
-#include "process.h"
 #include "split.h"
 #include "alsa_play.h"
 #include "win_info.h"
 #include "statusbar.h"
 #include "cd_curl.h"
-#include "bacon.h"
 
 // FIXME
 // TODO
@@ -75,7 +73,6 @@ GtkBuilder	*GtkXcfaProjet = NULL;
 GtkWidget	*WindMain = NULL;
 HOST_CONF	 HostConf;
 GtkWidget	*AdrLabelStatusbarGlobal = NULL;
-BaconMessageConnection *connection = NULL;
 
 
 KEYS keys = {
@@ -169,11 +166,6 @@ void remove_memory_apply (void)
 	VERBOSE ("AlsaPlay_remove ()\n");
 	AlsaPlay_remove ();
 
-	if (TRUE == libutils_test_file_exist (XCFA_FILE_LOAD)) {
-		if( TRUE == OptionsCommandLine.BoolVerboseMode )
-			g_print ("g_unlink (%s)\n", XCFA_FILE_LOAD);
-		g_unlink (XCFA_FILE_LOAD);
-	}
 	if (TRUE == libutils_test_file_exist (SPLIT_FILE_TMP_WAV)) {
 		if( TRUE == OptionsCommandLine.BoolVerboseMode )
 			g_print ("g_unlink (%s)\n", SPLIT_FILE_TMP_WAV);
@@ -381,7 +373,6 @@ void on_show_fields_activate (GtkMenuItem *menuitem, gpointer user_data)
 */
 void segfault_handler(int sig)
 {
-	g_unlink (XCFA_FILE_LOAD);
 	remove_memory_apply ();
 
 	g_print ("\n=========================================================\n");
@@ -394,20 +385,12 @@ void segfault_handler(int sig)
 
 	exit (EXIT_FAILURE);
 }
+
 //
 //
-typedef enum {
-	_PARAMS_GET_ALL_OPTIONS_ = 0,
-	_PARAMS_GET_OPTIONS_ONLY_
-} PARAMS_CMD_LINE;
-//
-//
-GList *AnalyseCommandLine_set_argv( gint argc, gchar *argv[], PARAMS_CMD_LINE ParamsCmdLine )
+void AnalyseCommandLine_set_argv( gint argc, gchar *argv[] )
 {
 	gint	 i;
-	gchar	*str_current_dir = NULL;
-	// FILE	*fp = NULL;
-	GList	*GListFile = NULL;
 
 	if( optind < argc ) {
 
@@ -433,73 +416,7 @@ GList *AnalyseCommandLine_set_argv( gint argc, gchar *argv[], PARAMS_CMD_LINE Pa
 				OptionsCommandLine.BoolHelpMode = TRUE;
 			}
 		}
-
-		// STOP ?
-		if( _PARAMS_GET_OPTIONS_ONLY_ == ParamsCmdLine )return( (GList *)NULL );
-
-		if( FALSE == OptionsCommandLine.BoolVerboseMode && FALSE == OptionsCommandLine.BoolVersionMode ) {
-			str_current_dir = g_get_current_dir();
-			// fp = fopen( XCFA_FILE_LOAD, "a" );
-			for( i = optind; i < argc; i++ )
-			{
-				if( *argv[ i ] == '-' ) continue;
-
-				// FROM DESKTOP
-				if( argv[i][0] == '/' ) {
-
-					// fprintf( fp, "%s\n", argv[ i ] );
-					GListFile = g_list_append( GListFile, g_strdup( argv[ i ] ));
-				}
-				else {
-					gchar *str = NULL;
-
-					str = g_strdup_printf( "%s/%s", str_current_dir, argv[i] );
-					// fprintf( fp, "%s\n", str );
-					GListFile = g_list_append( GListFile, g_strdup( str ));
-					g_free( str );
-					str = NULL;
-				}
-			}
-			// fclose( fp );
-			g_free( str_current_dir );
-			str_current_dir = NULL;
-		}
 	}
-	return( (GList *)GListFile );
-}
-//
-//
-void main_save( GList *p_GListFile )
-{
-	GList   *list = NULL;
-	gchar	*PtrName = NULL;
-	FILE	*fp = NULL;
-
-	// g_return_if_fail (p_GListFile != NULL);
-	if( NULL != p_GListFile ) {
-		if( NULL != (list = g_list_first( p_GListFile ))) {
-			fp = fopen( XCFA_FILE_LOAD, "a" );
-			while( list ) {
-				if (NULL != (PtrName = (gchar *)list->data)) {
-					fprintf( fp, "%s\n", PtrName );
-					if( TRUE == OptionsCommandLine.BoolVersionMode ) g_print( "%s\n", PtrName );
-				}
-				list = g_list_next( list );
-			}
-			fclose( fp );
-		}
-	}
-}
-//
-//
-static void on_message_received( const char *message, gpointer data )
-{
-	FILE	*fp = NULL;
-
-	fp = fopen( XCFA_FILE_LOAD, "a" );
-	fprintf( fp, "%s\n", message );
-	fclose( fp );
-	gtk_window_present (GTK_WINDOW (WindMain));
 }
 /* gint main (gint argc, gchar *argv[], gchar **envp)
  *
@@ -515,7 +432,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	gchar	*PathShareProjet = NULL;
 	gchar	*Path = NULL;
 	gchar	*PackageVersion = NULL;
-	GList	*GListFile = NULL;
 
 	/* Init type system as soon as possible */
 	// g_type_init ();
@@ -534,7 +450,7 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	g_print ("***************************\n\n");
 
 	// ANALYSE UNIQUEMENT LES OPTIONS
-	AnalyseCommandLine_set_argv( argc, &argv[0], _PARAMS_GET_OPTIONS_ONLY_ );
+	AnalyseCommandLine_set_argv( argc, &argv[0] );
 
 	if( TRUE == OptionsCommandLine.BoolVersionMode || TRUE == OptionsCommandLine.BoolHelpMode ) {
 		if( TRUE == OptionsCommandLine.BoolHelpMode ) {
@@ -544,7 +460,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 			g_print( "	--verbose	Activate verbose mode\n" );
 		}
 		g_print( "\n" );
-		g_unlink( XCFA_FILE_LOAD );
 		g_unlink( SPLIT_FILE_TMP_WAV );
 		return( EXIT_SUCCESS );
 	}
@@ -574,49 +489,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	setlocale( LC_ALL, "" );
 	gtk_init( &argc, &argv );
 
-	/*
-	Code revu depuis:
-		bacon-message-connection.c bacon-message-connection.h
-		Copyright (C) 2003
-		Bastien Nocera <hadess@hadess.net>
-	LA connection PEUT ETRE LIBEREE DES LE CHARGEMENT TOTAL DEPUIS LA LIGNE DE COMMANDE
-	LES FICHIERS SERONT PRIT EN COMPTE DEPUIS:
-		process_goto_timeout()
-	*/
-	connection = bacon_message_connection_new( "xcfa" );
-	if( NULL != connection )
-	{
-		if( FALSE == bacon_message_connection_get_is_server( connection ))
-		{
-			// g_print( "\nCLIENT:\nGET COMMAND LINE AND EXIT\n" );
-			GListFile = AnalyseCommandLine_set_argv( argc, &argv[0], _PARAMS_GET_ALL_OPTIONS_ );		// Get and save param-file
-			// SEND WITH:
-			//	bacon_message_connection_send( connection, str );
-			bacon_message_connection_send( connection, GListFile );
-			GListFile = libutils_remove_glist( GListFile );
-			// g_print( "bacon_utils_get_current_workspace() = %d\n",  bacon_utils_get_current_workspace() +1 );
-			bacon_message_connection_free( connection );
-
-			exit( EXIT_SUCCESS );
-		}
-		else
-		{
-			g_unlink( XCFA_FILE_LOAD );
-			g_unlink( SPLIT_FILE_TMP_WAV );
-			// g_print( "\nSERVER:\nGET COMMAND LINE AND CONTINUE\n" );
-			bacon_message_connection_set_callback( connection, on_message_received, NULL );
-			GListFile = AnalyseCommandLine_set_argv( argc, &argv[0], _PARAMS_GET_ALL_OPTIONS_ );		// Get and save param-file
-			// SAVE TO:
-			// 	XCFA_FILE_LOAD
-			main_save( GListFile );
-			GListFile = libutils_remove_glist( GListFile );
-		}
-	}
-	else
-	{
-		g_warning( "Cannot create the 'gedit' connection." );
-	}
-
 	if (NULL == (GtkXcfaProjet = gtk_builder_new ())) {
 		return (EXIT_FAILURE);
 	}
@@ -765,9 +637,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 
 	poche_set_flag_buttons();
 
-	// SI CHARGEMENT DE FICHIERS DEPUIS LE BUREAU AVEC LE MENU CONTEXTUEL
-	process_goto_timeout ();
-
 	// ADMINISTRATOR MODE ?
 	if( 0 == getuid() ) {
 		wind_info_init (
@@ -786,8 +655,6 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 
 	gtk_main ();
 
-	// bacon_message_connection_free( connection );
-
 	exit(EXIT_SUCCESS);
 }
 
