@@ -1,9 +1,9 @@
  /*
  *  file      : options.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -129,11 +129,9 @@ void on_combobox_nice_realize (GtkWidget *widget, gpointer user_data)
 	gint   i;
 	gchar *Ptr = NULL;
 
-	// libcombo_alloc (GTK_COMBO_BOX (widget));
-	
 	for (i = 0; i < 20; i++) {
 		Ptr = g_strdup_printf ("%d", i);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), Ptr);
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), Ptr );
 		g_free (Ptr);
 		Ptr = NULL;
 	}
@@ -166,10 +164,10 @@ void options_path_tmp (gchar *path)
 		gtk_button_set_label (GTK_BUTTON (var_options.Adr_path_temp), Config.PathnameTMP);
 	}
 	else {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("ERREUR: Lieu de stockage non autorise !"),
-			_("Veuillez recommencer."),
+			_("ERROR : storage location not permitted !"),
+			_("Please start again."),
 			  "");
 	}
 }
