@@ -1,9 +1,9 @@
  /*
  *  file      : options_cd.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -119,7 +119,7 @@ void OptionsCd_set_entry_and_label( void )
 				Ptr
 				);
 		g_string_append_printf (gstr,
-				_("Pour evaluer les templates, vous devez activer une lecture de cdaudio")
+				_("To assess the templates, you must enable a reading cdaudio")
 				);
 		g_string_append_printf (gstr,
 				"</span>"
