@@ -1,9 +1,9 @@
  /*
  *  file      : options_faac.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -91,10 +91,8 @@ gchar *OptionsFaac_get_faac_set_choice_vbr_abr (void)
 
 void on_combobox_faac_conteneur_realize (GtkWidget *widget, gpointer user_data)
 {
-	libcombo_alloc (GTK_COMBO_BOX (widget));
-
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Transport Stream (ADTS) - Extension .aac"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("MPEG-4 File Format (MP4) - Extension .m4a"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Transport Stream (ADTS) - Extension .aac"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("MPEG-4 File Format (MP4) - Extension .m4a"));
 	
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.ConteneurFacc);
 	var_options.Adr_Widget_faac_conteneur = GTK_COMBO_BOX (widget);
@@ -116,10 +114,9 @@ void on_combobox_faac_conteneur_changed (GtkComboBox *combobox, gpointer user_da
 
 void on_combobox_faac_choice_vbr_abr_realize (GtkWidget *widget, gpointer user_data)
 {
-	libcombo_alloc (GTK_COMBO_BOX (widget));
 	var_options.Adr_Widget_faac_choice_vbr_abr = GTK_COMBO_BOX (widget);
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "VBR");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "ABR");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "VBR");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "ABR");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.AbrVbrFacc);
 }
 void on_combobox_faac_choice_vbr_abr_changed (GtkComboBox *combobox, gpointer user_data)
@@ -132,28 +129,26 @@ void on_combobox_faac_choice_vbr_abr_changed (GtkComboBox *combobox, gpointer us
 	if (var_options.Adr_Widget_faac_choice_vbr_abr == NULL) return;
 	if (var_options.Adr_Widget_faac_set_choice_vbr_abr == NULL) return;
 	
-	libcombo_alloc (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr));
-	
 	switch (gtk_combo_box_get_active (var_options.Adr_Widget_faac_choice_vbr_abr)) {
 	
 	/* VBR
 	 * 10, 30, 50, 70, 80, 90, 100, 120, 150, 200, 250, 300, 400, 500
     	 */
 	case 0 :
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "10");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "30");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "50");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "70");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "80");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "90");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "100");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "120");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "150");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "200");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "250");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "300");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "400");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "500");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "10");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "30");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "50");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "70");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "80");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "90");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "100");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "120");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "150");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "200");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "250");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "300");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "400");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "500");
 		
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), Config.VbrFaccIndice);
 		break;
@@ -162,12 +157,12 @@ void on_combobox_faac_choice_vbr_abr_changed (GtkComboBox *combobox, gpointer us
 	 * 56, 64, 80, 96, 128, 152
 	 */
 	case 1 :
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "56");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "64");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "80");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "96");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "128");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), "152");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "56");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "64");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "80");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "96");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "128");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_faac_set_choice_vbr_abr), "152");
 		
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), Config.AbrFaccIndice);
 		break;
@@ -179,7 +174,6 @@ void on_combobox_faac_choice_vbr_abr_changed (GtkComboBox *combobox, gpointer us
 
 void on_combobox_faac_set_choice_vbr_abr_realize (GtkWidget *widget, gpointer user_data)
 {
-	// libcombo_alloc (GTK_COMBO_BOX (widget));
 	var_options.Adr_Widget_faac_set_choice_vbr_abr = GTK_COMBO_BOX (widget);
 	on_combobox_faac_choice_vbr_abr_changed (NULL,NULL);
 }
