@@ -1,9 +1,9 @@
  /*
  *  file      : options_flac.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -58,21 +58,19 @@ gchar *optionsFlac_get_compression_level_flac (void)
 
 
 
-void on_options_combobox_flac_compression_realize (GtkWidget *widget, gpointer user_data)
+void on_combobox_flac_compression_realize (GtkWidget *widget, gpointer user_data)
 {
  	var_options.Adr_Widget_flac_compression =  GTK_COMBO_BOX (widget);
 
-	// libcombo_alloc (GTK_COMBO_BOX (widget));
-	
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("0  (Rapide)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget),   "1");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget),   "2");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget),   "3");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget),   "4");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget),   "5");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget),   "6");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget),   "7");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("8  (Lent)"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("0  (Fast)"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget),   "1");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget),   "2");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget),   "3");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget),   "4");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget),   "5");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget),   "6");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget),   "7");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("8  (Low)"));
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.CompressionLevelFlac);
 }
