@@ -1,9 +1,9 @@
  /*
  *  file      : options_mp3.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -208,12 +208,10 @@ gchar *optionsLame_get_str_val_mode_lame (void)
 
 void on_combobox_lame_abr_cbr_vbr_realize (GtkWidget *widget, gpointer user_data)
 {
-	// libcombo_alloc (GTK_COMBO_BOX (widget));
-	
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "ABR");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "CBR");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "VBR");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "VBR-NEW");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "ABR");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "CBR");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "VBR");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "VBR-NEW");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.BitrateLameIndice);
 	var_options.Adr_Widget_Lame_abr_cbr_vbr = GTK_COMBO_BOX (widget);
 }
@@ -226,7 +224,6 @@ void on_combobox_lame_abr_cbr_vbr_changed (GtkComboBox *combobox, gpointer user_
 	if (NULL == var_options.Adr_Widget_Lame_bitrate) return;
 	if ((ind = gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_abr_cbr_vbr))) < 0) return;
 	Config.BitrateLameIndice = ind;
-	// libcombo_alloc (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate));
 	bool_do_enter_options_mp3 = FALSE;
 	libcombo_remove_options (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate));
 	
@@ -234,78 +231,78 @@ void on_combobox_lame_abr_cbr_vbr_changed (GtkComboBox *combobox, gpointer user_
 	
 	/* ABR 0 .. 13 */
 	case 0 :
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 32");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 40");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 48");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 56");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 64");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 80");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 96");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "112");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "128");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "160");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "192");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "224");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "256");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "320");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 32");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 40");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 48");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 56");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 64");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 80");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 96");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "112");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "128");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "160");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "192");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "224");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "256");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "320");
 		break;
 	
 	/* CBR 0 .. 14 */
 	case 1 :
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 32");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 40");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 48");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 56");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 64");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 80");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " 96");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "112");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "128");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "160");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "192");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "224");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "256");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "320");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset insane");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 32");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 40");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 48");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 56");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 64");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 80");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " 96");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "112");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "128");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "160");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "192");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "224");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "256");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "320");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset insane");
 		break;
 	
 	/* VBR 0 .. 14 */
 	case 2 :
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset medium");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset standard");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset extreme");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset fast standard");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset fast extreme");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), _("V0     (meilleure qualite)"));
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V1");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V2");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V3");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V4");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V5");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V6");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V7");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V8");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), _("V9     (moins bonne qualite)"));
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset medium");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset standard");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset extreme");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset fast standard");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset fast extreme");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), _("V0     (Best quality)"));
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V1");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V2");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V3");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V4");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V5");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V6");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V7");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V8");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), _("V9     (Poor quality)"));
 		break;
 	
 	/* VBR_NEW 0 .. 15 */
 	case 3 :
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), " ");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset medium");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset standard");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset extreme");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset fast standard");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "preset fast extreme");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V0");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V1");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V2");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V3");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V4");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V5");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V6");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V7");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V8");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), "V9");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), " ");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset medium");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset standard");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset extreme");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset fast standard");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "preset fast extreme");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V0");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V1");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V2");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V3");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V4");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V5");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V6");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V7");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V8");
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(var_options.Adr_Widget_Lame_bitrate), "V9");
 		break;
 	}
 	bool_do_enter_options_mp3 = TRUE;
@@ -334,14 +331,12 @@ void on_combobox_lame_type_bitrate_changed (GtkComboBox *combobox, gpointer user
 
 void on_combobox_lame_mode_realize (GtkWidget *widget, gpointer user_data)
 {
-	libcombo_alloc (GTK_COMBO_BOX (widget));
-
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Defaut");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Stereo");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Join Stereo");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Forced Join Stereo");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Duo Channels");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "Mono");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "Defaut");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "Stereo");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "Join Stereo");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "Forced Join Stereo");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "Duo Channels");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "Mono");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.TabModeLame[ Config.BitrateLameIndice ]);
 	var_options.Adr_Widget_Lame_Mode = GTK_COMBO_BOX (widget);
 	on_combobox_lame_abr_cbr_vbr_changed (NULL, NULL);
