@@ -1,9 +1,9 @@
  /*
  *  file      : options_musepack.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -65,15 +65,13 @@ void on_combobox_mppenc_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_options.Adr_Widget_Mppenc = GTK_COMBO_BOX (widget);
 
-	libcombo_alloc (GTK_COMBO_BOX (widget));
-	
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("telephone: lowest quality              :   32 ..  48 kbit/s"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("thumb      : low quality/internet     :   58 ..  86 kbit/s"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("radio        : medium (MP3) quality : 112 .. 152 kbit/s"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("standard  : high quality (dflt)         : 142 .. 184 kbit/s"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("xtreme     : extreme high quality   : 168 .. 212 kbit/s"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("insane      : extreme high quality   : 232 .. 268 kbit/s"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("braindead : extreme high quality   : 232 .. 278 kbit/s"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("telephone: lowest quality              :   32 ..  48 kbit/s"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("thumb      : low quality/internet     :   58 ..  86 kbit/s"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("radio        : medium (MP3) quality : 112 .. 152 kbit/s"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("standard  : high quality (dflt)         : 142 .. 184 kbit/s"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("xtreme     : extreme high quality   : 168 .. 212 kbit/s"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("insane      : extreme high quality   : 232 .. 268 kbit/s"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("braindead : extreme high quality   : 232 .. 278 kbit/s"));
 	
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.QualityMppenc);
 }
