@@ -1,9 +1,9 @@
  /*
  *  file      : options_oggenc.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -102,7 +102,7 @@ gchar *optionsOggenc_get_val_bitrate_oggenc (void)
 // 
 gboolean optionsOggenc_get_bool_managed_oggenc (void)
 {
-	if (GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET (GLADE_GET_OBJECT("eventbox_combobox_oggenc_managed"))) == TRUE) {
+	if( gtk_widget_is_sensitive(GTK_WIDGET (GLADE_GET_OBJECT("eventbox_combobox_oggenc_managed"))) == TRUE) {
 		if (gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_managed)) == 0) return (TRUE);
 	}
 	return (FALSE);
@@ -111,7 +111,7 @@ gboolean optionsOggenc_get_bool_managed_oggenc (void)
 // 
 gboolean optionsOggenc_get_bool_downmix_oggenc (void)
 {
-	if (GTK_WIDGET_IS_SENSITIVE(GTK_WIDGET (GLADE_GET_OBJECT("eventbox_combobox_oggenc_downmix"))) == TRUE) {
+	if (gtk_widget_is_sensitive(GTK_WIDGET (GLADE_GET_OBJECT("eventbox_combobox_oggenc_downmix"))) == TRUE) {
 		if (gtk_combo_box_get_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_downmix)) == 0) return (TRUE);
 	}
 	return (FALSE);
@@ -121,32 +121,31 @@ gboolean optionsOggenc_get_bool_downmix_oggenc (void)
 void on_combobox_oggenc_bitrate_realize (GtkWidget *widget, gpointer user_data)
 {
 	var_options.Adr_Widget_Oggenc_bitrate = GTK_COMBO_BOX (widget);
-	// libcombo_alloc (GTK_COMBO_BOX (widget));
 
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), " 45  kbit/s");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), " 64  kbit/s");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), " 80  kbit/s");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), " 96  kbit/s");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "112  kbit/s");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "128  kbit/s");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "160  kbit/s");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "192  kbit/s");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "224  kbit/s");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "256  kbit/s");
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), "320  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), " 45  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), " 64  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), " 80  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), " 96  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "112  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "128  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "160  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "192  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "224  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "256  kbit/s");
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), "320  kbit/s");
 
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite -1   (Moins bonne qualite)"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  0"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  1"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  2"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  3"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  4"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  5"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  6"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  7"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  8"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  9"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Qualite  10  (Meilleure qualite)"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality -1   (Poor quality)"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  0"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  1"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  2"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  3"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  4"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  5"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  6"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  7"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  8"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  9"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Quality  10  (Best quality)"));
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.BitrateOggenc);
 }
@@ -174,10 +173,8 @@ void on_combobox_oggenc_bitrate_changed (GtkComboBox *combobox, gpointer user_da
 // 
 void on_combobox_oggenc_managed_realize (GtkWidget *widget, gpointer user_data)
 {
-	libcombo_alloc (GTK_COMBO_BOX (widget));
-	
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Oui"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Non"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Yes"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("No"));
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.ManagedOggenc);
 
@@ -196,10 +193,8 @@ void on_combobox_oggenc_managed_changed (GtkComboBox *combobox, gpointer user_da
 // 
 void on_combobox_oggenc_downmix_realize (GtkWidget *widget, gpointer user_data)
 {
-	libcombo_alloc (GTK_COMBO_BOX (widget));
-	
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Mono force"));
-	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Stereo"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Force mono"));
+	gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), _("Stereo"));
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), Config.DownmixOggenc);
 
