@@ -1,9 +1,9 @@
  /*
  *  file      : play_file.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -102,11 +102,10 @@ void PlayFile_play (gchar *PathNameFile)
 	PRINT_FUNC_LF();
 	
 	if (FALSE == extra_get_lecteur_audio_is_ok ()) {
-		PRINT("VEUILLEZ SAISIR UN LECTEUR AUDIO");
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("PAS de lecteur audio present"),
-			_("Veuillez installez un lecteur audio."),
+			_("NO audio player present"),
+			_("Please install an audio player."),
 			  "");
 		return;
 	}
