@@ -1,9 +1,9 @@
  /*
  *  file      : poche.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -61,38 +61,38 @@
 
 
 VIEW view = {
-	FALSE,			// BoolAccessChanged;			// COMBOBOX changed is TRUE
+	FALSE,			// BoolAccessChanged;				// COMBOBOX changed is TRUE
 	
-	NULL,			// *AdrComboBoxChoice;			// 
+	NULL,			// *AdrComboBoxChoice;				// 
 	
-	NULL,			// *AdrEntrySearchImgWeb;		// Adresse saisie image web
-	NULL,			// *AdrEntryNameFileSave;		// Adresse saisie nom fichier image
-	NULL,			// *AdrEntryTitleCD;			// Adresse saisie titre du CD
+	NULL,			// *AdrEntrySearchImgWeb;			// Adresse saisie image web
+	NULL,			// *AdrEntryNameFileSave;			// Adresse saisie nom fichier image
+	NULL,			// *AdrEntryTitleCD;				// Adresse saisie titre du CD
 	
-	NULL,			// *TitleCD;				// 
-	NULL,			// *Buffer_none;			// 
-	NULL,			// *Buffer_title;			// 
-	NULL,			// *Buffer_title_time;			// 
+	NULL,			// *TitleCD;						// 
+	NULL,			// *Buffer_none;					// 
+	NULL,			// *Buffer_title;					// 
+	NULL,			// *Buffer_title_time;				// 
 	NULL,			// *Buffer_artist_title_time;		// 
 	
-	NULL,			// *AdrDrawingarea;			// Adresse de la surface
-	FALSE,			// BoolScaleAdjust;			// TRUE = ajustement de l'echelle avec la surface de la fentre
-	NULL,			// *image;				// Adresse de l'image
-	1.0,			// scale;				// Pourcentage de surface de l'image
-	0.0,			// x0;					// Pos X
-	0.0,			// y0;					// Pos Y
-	0,			// image_width;				// Width
-	0,			// image_height;			// Height
-	NULL,			// *ListImage;				// Pointeur de structure IMAGE pour AdrDrawingarea
-	FALSE,			// BoolEventButtonPress;		// TRUE == BOUTON SOURIS PRESSED
-	NULL,			// *GetImage;				// Adresse de l'image en selection
-	IMG_NONE,		// ImgCorner;				// See IMG_CORNER
+	NULL,			// *AdrDrawingarea;					// Adresse de la surface
+	FALSE,			// BoolScaleAdjust;					// TRUE = ajustement de l'echelle avec la surface de la fentre
+	NULL,			// *image;							// Adresse de l'image
+	1.0,			// scale;							// Pourcentage de surface de l'image
+	0.0,			// x0;								// Pos X
+	0.0,			// y0;								// Pos Y
+	0,				// image_width;						// Width
+	0,				// image_height;					// Height
+	NULL,			// *ListImage;						// Pointeur de structure IMAGE pour AdrDrawingarea
+	FALSE,			// BoolEventButtonPress;			// TRUE == BOUTON SOURIS PRESSED
+	NULL,			// *GetImage;						// Adresse de l'image en selection
+	IMG_NONE,		// ImgCorner;						// See IMG_CORNER
 	NULL,			// *Adr_viewport_image_preview;		// Adresse viewport
-	NULL,			// *Adr_table;				// Adresse table contenu dans le viewport
-	NULL,			// *glist;				// Contient les structures GLIST_POCHETTE
-	NULL,			// *AdrTextview;			// Adresse textview
-	FALSE,			// BoolSaveToFile;			// TRUE si sauvegarde vers fichier
-				// HandleMove;				// Les coordonnees de saisie de l'image
+	NULL,			// *Adr_table;						// Adresse table contenu dans le viewport
+	NULL,			// *glist;							// Contient les structures GLIST_POCHETTE
+	NULL,			// *AdrTextview;					// Adresse textview
+	FALSE,			// BoolSaveToFile;					// TRUE si sauvegarde vers fichier
+					// HandleMove;						// Les coordonnees de saisie de l'image
 	};
 
 
@@ -101,6 +101,67 @@ gdouble oldY = -1.0;
 
 
 
+void draw_queue( void )
+{
+	/**
+	void
+	gtk_widget_queue_draw_area( GtkWidget *widget,
+								gint x,
+								gint y,
+								gint width,
+								gint height);
+	GtkAllocation	allocation;
+	gtk_widget_get_allocation( view.AdrDrawingarea, &allocation );
+
+	GtkAllocation	allocation;
+	
+	
+	
+	gtk_widget_get_allocation( GTK_WIDGET(GLADE_GET_OBJECT("viewport1")), &allocation );
+
+	gtk_widget_queue_draw_area(
+						// view.AdrDrawingarea,
+						GTK_WIDGET(GLADE_GET_OBJECT("viewport1")),
+						0,
+						0,
+						// view.image_width,
+						// view.image_height
+						// allocation.width,
+						// allocation.height
+						//  gtk_widget_get_allocated_width( view.AdrDrawingarea ) ,
+						//  gtk_widget_get_allocated_height( view.AdrDrawingarea ) 
+						gtk_widget_get_allocated_width( GTK_WIDGET(GLADE_GET_OBJECT("viewport1")) ) ,
+						gtk_widget_get_allocated_height( GTK_WIDGET(GLADE_GET_OBJECT("viewport1")) ) 
+						);
+	printf("1) 0, 0, %d %d \n", view.image_width, view.image_height );
+	printf("2) 0, 0, %d %d \n", allocation.width, allocation.height );
+	
+	
+	gtk_widget_queue_draw_area(
+						view.AdrDrawingarea,
+						0,
+						0,
+						view.image_width,
+						view.image_height
+						);
+
+	gtk_widget_queue_draw(
+						view.AdrDrawingarea
+						);
+	
+
+	gtk_widget_queue_draw_area(
+						view.AdrDrawingarea,
+						0,
+						0,
+						view.image_width,
+						view.image_height
+						);
+	*/
+	gtk_widget_queue_draw(
+						view.AdrDrawingarea
+						);
+}
 // 
 // 
 void poche_remove_view (void)
@@ -169,8 +230,8 @@ void poche_remove_ListImage( void )
 gboolean poche_is_erase_active( void )
 {
 	GList	*List = NULL;
-        IMAGE	*Image = NULL;
-        gboolean	BoolEraseActive = FALSE;
+	IMAGE	*Image = NULL;
+	gboolean	BoolEraseActive = FALSE;
         
 	List = g_list_first( view.ListImage );
 	while( List ) {
@@ -194,13 +255,15 @@ void poche_set_flag_buttons (void )
 	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_normal")), TRUE );
 	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_plus")), TRUE );
 	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_ajuster")), TRUE );
-	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_change_font")), poche_get_struct_selected_is_txt() == NULL ? FALSE : TRUE );
-	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("togglebutton_font_bold")), poche_get_struct_selected_is_txt() == NULL ? FALSE : TRUE );
-	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("togglebutton_font_italic")), poche_get_struct_selected_is_txt() == NULL ? FALSE : TRUE );
+	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_change_font")), Image && Image->BoolIsSelected ? TRUE : FALSE );
+	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("togglebutton_font_bold")), Image && Image->BoolIsSelected ? TRUE : FALSE );
+	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("togglebutton_font_italic")), Image && Image->BoolIsSelected ? TRUE : FALSE );
 	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_import_img_web")), *pochetxt_get_ptr_entry_img_web() == '\0' ? FALSE : TRUE );
-	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("combobox_choice_get_cd")), (NULL != view.Buffer_none && NULL != Image) ? TRUE : FALSE );
+	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("combobox_choice_get_cd")), Image && Image->BoolIsSelected ? TRUE : FALSE );
 	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("frame_texte_poche")), (NULL != Image) ? TRUE : FALSE );
-	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("button_import_title_cd")), (NULL != view.Buffer_none) ? TRUE : FALSE );
+
+	// For 'button_import_title_cd' see: void cdaudio_set_flag_buttons (void)
+
 	
 	if( NULL != Image ) {
 		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("togglebutton_font_bold")), Image->BoolFontBold );
@@ -227,30 +290,52 @@ void poche_print_zoom_changed( gdouble p_zoom_scale )
 // 
 void poche_set_size_request( void )
 {
-	gtk_widget_set_size_request( view.AdrDrawingarea, (gint)((gdouble)view.image_width * view.scale), (gint)((gdouble)view.image_height * view.scale) );
+	gtk_widget_set_size_request(
+					view.AdrDrawingarea,
+					(gint)((gdouble)view.image_width * view.scale),
+					(gint)((gdouble)view.image_height * view.scale)
+					// view.image_width * view.scale,
+					// view.image_height * view.scale
+					);
 }
 // 
 // 
+gboolean on_drawingareamain_draw( GtkWidget *widget, cairo_t *p_cr, gpointer user_data )
+{
+	pochedraw_paint( NULL, p_cr );
+	// poche_set_flag_buttons();
+	return( FALSE );
+}
+/*
 gboolean on_drawingareamain_expose_event( GtkWidget *widget, GdkEventExpose *event, gpointer user_data )
 {
-	pochedraw_paint( NULL );
+	pochedraw_paint( NULL, p_cr );
 	poche_set_flag_buttons();
 	return( FALSE );
 }
+*/
+gboolean on_scrolledwindow_poche_draw( GtkWidget *widget, cairo_t *p_cr, gpointer user_data )
+{
+	pochedraw_paint( NULL, p_cr );
+	// poche_set_flag_buttons();
+	return( FALSE );
+}
+
 // 
 // 
 IMAGE *poche_get_is_move( gdouble x, gdouble y )
 {
 	cairo_t	*cr;
 	GdkRectangle	zone;
-	GdkRegion	*region = NULL;
+	// GdkRegion	*region = NULL;
+	cairo_region_t *region = NULL;
 	IMAGE		*Image = NULL;
 	GList		*List = NULL;
 	gboolean	BoolInZone = FALSE;
 	
-	cr = gdk_cairo_create( view.AdrDrawingarea->window );
-        cairo_scale (cr, view.scale, view.scale);
-        cairo_translate (cr, view.x0, view.y0);
+	cr = gdk_cairo_create( gtk_widget_get_window(view.AdrDrawingarea) );
+	cairo_scale (cr, view.scale, view.scale);
+	cairo_translate (cr, view.x0, view.y0);
 	List = g_list_last( view.ListImage );
 	while( List ) {
 		if( NULL != (Image = (IMAGE *)List->data ) && FALSE == Image->BoolStructRemove ) {
@@ -262,13 +347,14 @@ IMAGE *poche_get_is_move( gdouble x, gdouble y )
 			zone.y      = Image->y0;
 			zone.width  = Image->image_width;
 			zone.height = Image->image_height;
-			region = gdk_region_rectangle (&zone);
-			if( gdk_region_point_in( region, x, y )) {
+			region = cairo_region_create_rectangle (&zone);
+			if( cairo_region_contains_point( region, x, y )) {
+			// if( gdk_region_point_in( region, x, y )) {
 				BoolInZone = TRUE;
 				Image->XPointer = x;
 				Image->YPointer = y;
 			}
-			gdk_region_destroy (region);
+			cairo_region_destroy (region);
 			if( TRUE == BoolInZone ) {
 				cairo_destroy( cr );
 				return( Image );
@@ -284,15 +370,16 @@ IMAGE *poche_get_is_move( gdouble x, gdouble y )
 IMAGE *poche_get( gdouble x, gdouble y )
 {
 	cairo_t	*cr;
-	GdkRegion	*region = NULL;
+	// GdkRegion	*region = NULL;
+	cairo_region_t *region = NULL;
 	IMAGE		*Image = NULL;
 	GList		*List = NULL;
 	gboolean	BoolInZone = FALSE;
 	gint		CptImgCorner;
-	
-	cr = gdk_cairo_create( view.AdrDrawingarea->window );
-        cairo_scale (cr, view.scale, view.scale);
-        cairo_translate (cr, view.x0, view.y0);
+		
+	cr = gdk_cairo_create( gtk_widget_get_window(view.AdrDrawingarea) );
+	cairo_scale (cr, view.scale, view.scale);
+	cairo_translate (cr, view.x0, view.y0);
 	List = g_list_last( view.ListImage );
 	while( List ) {
 		if( NULL != (Image = (IMAGE *)List->data ) && FALSE == Image->BoolStructRemove ) {
@@ -306,13 +393,14 @@ IMAGE *poche_get( gdouble x, gdouble y )
 			
 			pochedraw_get_handle_move( Image, TRUE );
 			for( CptImgCorner = 0; CptImgCorner < IMG_SIZE; CptImgCorner ++ ) {
-				region = gdk_region_rectangle( &view.HandleMove.zone [ CptImgCorner ] );
-				if( gdk_region_point_in( region, x, y )) {
+				region = cairo_region_create_rectangle( &view.HandleMove.zone [ CptImgCorner ] );
+				// if( gdk_region_point_in( region, x, y )) {
+				if( cairo_region_contains_point( region, x, y )) {
 					BoolInZone = TRUE;
 					Image->XPointer = x;
 					Image->YPointer = y;
 				}
-				gdk_region_destroy (region);
+				cairo_region_destroy (region);
 				if( TRUE == BoolInZone ) {
 					cairo_destroy( cr );
 					view.ImgCorner = CptImgCorner;
@@ -380,7 +468,8 @@ void poche_set_selected_first_image( IMAGE *p_Image )
 	if( NULL != List && NULL != ListLast  ) {
 		ListLast->data = Image;
 		List->data     = ImageLast;
-		gtk_widget_queue_draw( view.AdrDrawingarea );
+		// gtk_widget_queue_draw( view.AdrDrawingarea );
+		draw_queue();
 	}
 }
 void poche_set_selected_up_image( IMAGE *p_Image )
@@ -403,7 +492,8 @@ void poche_set_selected_up_image( IMAGE *p_Image )
 						if( NULL != List && NULL != ListLast  ) {
 							ListLast->data = Image;
 							List->data     = ImageLast;
-							gtk_widget_queue_draw( view.AdrDrawingarea );
+							// gtk_widget_queue_draw( view.AdrDrawingarea );
+							draw_queue();
 						}
 					}
 				}
@@ -433,7 +523,8 @@ void poche_set_selected_down_image( IMAGE *p_Image )
 						if( NULL != List && NULL != ListLast  ) {
 							ListLast->data = Image;
 							List->data     = ImageLast;
-							gtk_widget_queue_draw( view.AdrDrawingarea );
+							// gtk_widget_queue_draw( view.AdrDrawingarea );
+							draw_queue();
 						}
 					}
 				}
@@ -477,7 +568,8 @@ void poche_set_selected_last_image( IMAGE *p_Image )
 	if( NULL != List && NULL != ListFisrt  ) {
 		ListFisrt->data = Image;
 		List->data     = ImageLast;
-		gtk_widget_queue_draw( view.AdrDrawingarea );
+		// gtk_widget_queue_draw( view.AdrDrawingarea );
+		draw_queue();
 	}
 }
 // 
@@ -492,12 +584,12 @@ gboolean on_drawingareamain_button_press_event( GtkWidget *widget, GdkEventButto
 	GList		*List = NULL;
  	gboolean	bool_click_droit = (event->button == 3);	
 	
-	cr = gdk_cairo_create( view.AdrDrawingarea->window );
-        cairo_scale (cr, view.scale, view.scale);
-        cairo_translate (cr, view.x0, view.y0);
-        x = event->x;
-        y = event->y;
-        cairo_device_to_user (cr, &x, &y);
+	cr = gdk_cairo_create( gtk_widget_get_window(view.AdrDrawingarea) );
+	cairo_scale (cr, view.scale, view.scale);
+	cairo_translate (cr, view.x0, view.y0);
+	x = event->x;
+	y = event->y;
+	cairo_device_to_user (cr, &x, &y);
 	
 	if( TRUE == bool_click_droit ) {
 		if( NULL != (Image = (IMAGE *)poche_get_is_move( x, y ))) {
@@ -536,7 +628,8 @@ gboolean on_drawingareamain_button_press_event( GtkWidget *widget, GdkEventButto
 				view.ImgCorner = IMG_MOVE;
 				view.GetImage = Image;
 				cairo_destroy( cr );
-				gtk_widget_queue_draw( view.AdrDrawingarea );
+				// gtk_widget_queue_draw( view.AdrDrawingarea );
+				draw_queue();
 				view.BoolEventButtonPress = TRUE;
 				
 				pochetxt_set_text_to_textview( Image );
@@ -557,7 +650,8 @@ gboolean on_drawingareamain_button_press_event( GtkWidget *widget, GdkEventButto
 		}
 		cursor_set_old();
 		cairo_destroy( cr );
-		gtk_widget_queue_draw( view.AdrDrawingarea );
+		// gtk_widget_queue_draw( view.AdrDrawingarea );
+		draw_queue();
 		view.BoolEventButtonPress = TRUE;
 		return( FALSE );
 	}
@@ -572,17 +666,20 @@ gboolean on_drawingareamain_button_press_event( GtkWidget *widget, GdkEventButto
 gboolean on_drawingareamain_button_release_event( GtkWidget *widget, GdkEventButton *event, gpointer user_data )
 {
 	cairo_t	*cr;
-        gdouble	x, y;
+	gdouble	x, y;
         
-	cr = gdk_cairo_create( view.AdrDrawingarea->window );
-        cairo_scale (cr, view.scale, view.scale);
-        cairo_translate (cr, view.x0, view.y0);
-        x = event->x;
-        y = event->y;
-        cairo_device_to_user (cr, &x, &y);
+	cr = gdk_cairo_create( gtk_widget_get_window(view.AdrDrawingarea) );
+	cairo_scale (cr, view.scale, view.scale);
+	cairo_translate (cr, view.x0, view.y0);
+	x = event->x;
+	y = event->y;
+	cairo_device_to_user (cr, &x, &y);
 	view.BoolEventButtonPress = FALSE;
 	view.GetImage = NULL;
 	cairo_destroy( cr );	
+
+	poche_set_flag_buttons();
+
 	return( FALSE );
 }
 // 
@@ -590,15 +687,16 @@ gboolean on_drawingareamain_button_release_event( GtkWidget *widget, GdkEventBut
 gboolean on_drawingareamain_motion_notify_event( GtkWidget *widget, GdkEventMotion *event, gpointer user_data )
 {
 	cairo_t		*cr;
-        gdouble		x, y;
-        gboolean	BoolRedraw = FALSE;
-	
-	cr = gdk_cairo_create( view.AdrDrawingarea->window );
-        cairo_scale (cr, view.scale, view.scale);
-        cairo_translate (cr, view.x0, view.y0);
-        x = event->x;
-        y = event->y;
-        cairo_device_to_user (cr, &x, &y);
+	gdouble		x, y;
+	gboolean	BoolRedraw = FALSE;
+
+
+	cr = gdk_cairo_create( gtk_widget_get_window(view.AdrDrawingarea) );
+	cairo_scale (cr, view.scale, view.scale);
+	cairo_translate (cr, view.x0, view.y0);
+	x = event->x;
+	y = event->y;
+	cairo_device_to_user (cr, &x, &y);
 	
 	if (oldX == -1.0 || oldY == -1.0) {
 		oldX = x;
@@ -822,7 +920,10 @@ gboolean on_drawingareamain_motion_notify_event( GtkWidget *widget, GdkEventMoti
 	oldX = x;
 	oldY = y;
 	cairo_destroy( cr );
-	if( TRUE == BoolRedraw ) gtk_widget_queue_draw( view.AdrDrawingarea );	
+	if( TRUE == BoolRedraw ) {
+		// gtk_widget_queue_draw( view.AdrDrawingarea );	
+		draw_queue();
+	}
 	return( FALSE );
 }
 // 
@@ -833,7 +934,8 @@ void on_button_moins_clicked( GtkButton *button, gpointer user_data )
 	view.scale -= 0.4;
 	if( view.scale < 0.4 ) view.scale = 0.4;
 	poche_set_size_request();
-	gtk_widget_queue_draw( view.AdrDrawingarea );
+	// gtk_widget_queue_draw( view.AdrDrawingarea );
+	draw_queue();
 }
 // 
 // 
@@ -842,7 +944,8 @@ void on_button_normal_clicked( GtkButton *button, gpointer user_data )
 	view.BoolScaleAdjust = FALSE;
 	view.scale  = 1.0;	
 	poche_set_size_request();
-	gtk_widget_queue_draw( view.AdrDrawingarea );
+	// gtk_widget_queue_draw( view.AdrDrawingarea );
+	draw_queue();
 }
 // 
 // 
@@ -852,14 +955,16 @@ void on_button_plus_clicked( GtkButton *button, gpointer user_data )
 	view.scale += 0.4;
 	if( view.scale > 6.0 ) view.scale = 6.0;
 	poche_set_size_request();
-	gtk_widget_queue_draw( view.AdrDrawingarea );
+	// gtk_widget_queue_draw( view.AdrDrawingarea );
+	draw_queue();
 }
 // 
 // 
 void on_button_ajuster_clicked( GtkButton *button, gpointer user_data )
 {
 	view.BoolScaleAdjust = TRUE;
-	gtk_widget_queue_draw( view.AdrDrawingarea );
+	// gtk_widget_queue_draw( view.AdrDrawingarea );
+	draw_queue();
 }
 // 
 // 
@@ -1005,22 +1110,26 @@ void poche_set_texte_title( gchar *p_str )
 		}
 		Image->Texte = g_strdup( p_str );
 	}
-	gtk_widget_queue_draw( view.AdrDrawingarea );
+	// gtk_widget_queue_draw( view.AdrDrawingarea );
+	draw_queue();
 }
 // 
 // 
-static void poche_drag_data_received (GtkWidget	        *widget,
-				     GdkDragContext     *drag_context,
-				     gint                x,
-				     gint                y,
-				     GtkSelectionData   *data,
-				     guint               info,
-				     guint               time)
+static void poche_drag_data_received(
+					GtkWidget        *widget,
+					GdkDragContext   *context,
+					gint              x,
+					gint              y,
+					GtkSelectionData *data,
+					guint             info,
+					guint             time,
+					gpointer          user_data)
 {
 	// PRINT("DND FROM DESKTOP TO DRAWING"); 
 	// Une copie ne peut aller vers elle meme !!!
-	if (gtk_drag_get_source_widget(drag_context) != widget) {
-		dragndrop_list_drag_data (widget, (gchar *)data->data);
+	if (gtk_drag_get_source_widget(context) != widget) {
+		// dragndrop_list_drag_data (widget, (gchar *)data->data);
+		dragndrop_list_drag_data( widget, (gchar*)gtk_selection_data_get_data( data ));
 	}
 }
 // 
@@ -1040,6 +1149,7 @@ void on_drawingareamain_realize( GtkWidget *widget, gpointer user_data )
 	
 	view.image_width  = cairo_image_surface_get_width( view.image );
 	view.image_height = cairo_image_surface_get_height( view.image );
+		
 	poche_set_size_request();
 	
 	// Drag and drop support
@@ -1093,7 +1203,8 @@ void poche_remove_image( void )
 					pochetxt_set_text_to_textview( Image );
 
 				}
-				gtk_widget_queue_draw( view.AdrDrawingarea );
+				// gtk_widget_queue_draw( view.AdrDrawingarea );
+				draw_queue();
 				poche_set_flag_buttons();
 				// DEBUG CDDB_CURL
 				pochetxt_set_combobox_choice( 0 );
@@ -1112,15 +1223,18 @@ void on_button_erase_clicked (GtkButton *button, gpointer user_data)
 }
 // 
 // 
-static void poche_drag_data_received_file (GtkWidget          *widget,
-				     		GdkDragContext     *drag_context,
-				     		gint                x,
-				     		gint                y,
-				    		GtkSelectionData   *data,
-				    		guint               info,
-				    		guint               time)
+static void poche_drag_data_received_file(
+					GtkWidget        *widget,
+					GdkDragContext   *context,
+					gint              x,
+					gint              y,
+					GtkSelectionData *data,
+					guint             info,
+					guint             time,
+					gpointer          user_data)
 {
-	dragndrop_list_drag_data (widget, (gchar *)data->data);
+	// dragndrop_list_drag_data (widget, (gchar *)data->data);
+	dragndrop_list_drag_data( widget, (gchar*)gtk_selection_data_get_data( data ));
 }
 // 
 // 
@@ -1130,7 +1244,8 @@ void poche_table_add_images_init (void)
 		gtk_widget_destroy( view.Adr_table );
 		view.Adr_table = NULL;
 	}
-	view.Adr_table = gtk_table_new (4, 5, TRUE);
+	// view.Adr_table = gtk_grid_new (4, 5, TRUE);
+	view.Adr_table = gtk_grid_new();
 	gtk_container_add (GTK_CONTAINER (view.Adr_viewport_image_preview), view.Adr_table);
 	gtk_widget_show_all (view.Adr_table);
 }
@@ -1188,13 +1303,18 @@ void poche_add_img_file_to_Drawingarea( GSList *p_list )
 	
 	PRINT_FUNC_LF();
 	
-	gdk_window_get_pointer( view.AdrDrawingarea->window, &X, &Y, &state ); 	
-	cr = gdk_cairo_create( view.AdrDrawingarea->window );
-        cairo_scale (cr, view.scale, view.scale);
-        cairo_translate (cr, view.x0, view.y0);
-        x = X;
-        y = Y;
-        cairo_device_to_user (cr, &x, &y);
+	/* Si pas de selection a cet endroit retour */
+	GdkDeviceManager *manager = gdk_display_get_device_manager( gdk_display_get_default() );
+	GdkDevice		 *device = gdk_device_manager_get_client_pointer( manager );
+	gdk_window_get_device_position( gtk_widget_get_window(view.AdrDrawingarea), device, &X, &Y, &state );
+	// gdk_window_get_pointer( view.AdrDrawingarea->window, &X, &Y, &state ); 
+		
+	cr = gdk_cairo_create( gtk_widget_get_window(view.AdrDrawingarea) );
+	cairo_scale (cr, view.scale, view.scale);
+	cairo_translate (cr, view.x0, view.y0);
+	x = X;
+	y = Y;
+	cairo_device_to_user (cr, &x, &y);
 	cairo_destroy( cr );
 	
 	while (gs_List) {
@@ -1203,7 +1323,8 @@ void poche_add_img_file_to_Drawingarea( GSList *p_list )
 			if( TRUE == FileIs_image( Ptr )) {
 				Image = poche_add_to_glist( Ptr, x, y, TRUE, _TYPE_IMAGE_ );
 				poche_set_selected_flag_image( Image );
-				gtk_widget_queue_draw( view.AdrDrawingarea );
+				// gtk_widget_queue_draw( view.AdrDrawingarea );
+				draw_queue();
 				return;
 			}
 		}
