@@ -1,9 +1,9 @@
  /*
  *  file      : poche_draw.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -65,6 +65,7 @@
 gdouble pochedraw_get_scale_adjust( void )
 {
 	gdouble	return_scale = 1.0;
+	GtkAllocation	allocation;
 	
 	if( TRUE == view.BoolScaleAdjust ) {
 		gdouble	scale_width = 1.0;
@@ -77,8 +78,11 @@ gdouble pochedraw_get_scale_adjust( void )
 			view.scale = SCALE_MIN;
 			poche_set_size_request();
 		}
-		scale_width = (gdouble)view.AdrDrawingarea->allocation.width / (gdouble)view.image_width;
-		scale_height = (gdouble)view.AdrDrawingarea->allocation.height / (gdouble)view.image_height;
+		gtk_widget_get_allocation( view.AdrDrawingarea, &allocation );
+		// scale_width  = (gdouble)view.AdrDrawingarea->allocation.width / (gdouble)view.image_width;
+		scale_width  = (gdouble)allocation.width / (gdouble)view.image_width;
+		// scale_height = (gdouble)view.AdrDrawingarea->allocation.height / (gdouble)view.image_height;
+		scale_height = (gdouble)allocation.height / (gdouble)view.image_height;
 		new_scale = MIN(scale_width, scale_height);
 		return_scale = new_scale;
 	}
@@ -534,54 +538,65 @@ void pochedraw_set_format( cairo_t *cr )
 	LocateY = MM(177);
 	cairo_move_to( cr, LocateX,  LocateY );
 	
-	PackageVersion = g_strdup_printf ("X Convert File Audio %s  -  GNU General Public License  -  2003..2013, Claude Bulin  -  fr", VERSION);
+	PackageVersion = g_strdup_printf ("X Convert File Audio %s  -  GNU General Public License  -  2003..2015, Claude Bulin  -  fr", VERSION);
 	cairo_show_text( cr, PackageVersion );
-	// cairo_show_text( cr, "ZoomC 0.0.19  GNU General Public License  -  2003 - 2013, Claude Bulin  -  fr" );
+	// cairo_show_text( cr, "ZoomC 0.0.19  GNU General Public License  -  2003 - 2015, Claude Bulin  -  fr" );
 	g_free( PackageVersion );
 	PackageVersion = NULL;
 	cairo_restore (cr);
 }
-void pochedraw_paint( cairo_surface_t *cs )
+cairo_t *pochedraw_paint( cairo_surface_t *cs, cairo_t *p_cr )
 {
 	cairo_t		*cr;
 	gint		canvas_w, canvas_h;
 	GList		*List = NULL;
 	IMAGE		*Image = NULL;
 	IMAGE		*ImageSelected = NULL;
+	GtkAllocation	allocation;
 	
-	
-	if( FALSE == view.BoolSaveToFile ) {
-		cr = gdk_cairo_create( view.AdrDrawingarea->window );
-	}
-	else {
+	if( TRUE == view.BoolSaveToFile ) {
+		// cr = gdk_cairo_create( gtk_widget_get_window(view.AdrDrawingarea) );
 		cr = cairo_create( cs );
 	}
-	cairo_save (cr);
+	else {
+		// cr = cairo_create( cs );
+		cr = p_cr;
+	}
+	// cairo_save (cr);
 	view.scale = pochedraw_get_scale_adjust();
+	gtk_widget_get_allocation( view.AdrDrawingarea, &allocation );
 	
 	// gdk_drawable_get_size (view.AdrDrawingarea->window, &canvas_w, &canvas_h );
-	canvas_w = view.AdrDrawingarea->allocation.width;
-	canvas_h = view.AdrDrawingarea->allocation.height;
+	// gdk_drawable_get_size( gtk_widget_get_window( view.AdrDrawingarea ), &canvas_w, &canvas_h );
+	// canvas_w = view.AdrDrawingarea->allocation.width;
+	canvas_w = allocation.width;
+	// canvas_h = view.AdrDrawingarea->allocation.height;
+	canvas_h = allocation.height;
+	// canvas_w = view.image_width;
+	// canvas_h = view.image_height;
+	
 	view.x0 = ((canvas_w / view.scale) - view.image_width) / 2.0;
 	view.y0 = ((canvas_h / view.scale) - view.image_height) / 2.0;
 
+	cairo_save (cr);
 	cairo_scale( cr, view.scale, view.scale );
 	cairo_translate( cr, view.x0, view.y0 );
 	cairo_set_source_surface( cr, view.image, 0.0, 0.0 );
 	cairo_paint( cr );
 
+
 	// PAINT PREVIEW SURFACE
 	cairo_set_source_rgb( cr, 1.0, 1.0, 1.0 );
+	// cairo_set_source_rgb( cr, 0.0, 0.0, 0.0 );
 	cairo_rectangle( cr,
 			 0,
 			 0,
 			 view.image_width,
 			 view.image_height
-			 );			
+			 );
 	cairo_fill( cr );
-			
+
 	cairo_restore (cr);
-	
 	// 
 	// Image[ n ]		image en dessous  / image below
 	// Image[ n +1 ]	
@@ -611,7 +626,9 @@ void pochedraw_paint( cairo_surface_t *cs )
 	}
 	cairo_restore (cr);
 	pochedraw_set_format( cr );
-	cairo_destroy( cr );
+	
+	return( cr );
+	// cairo_destroy( cr );
 }
 
 
