@@ -1,9 +1,9 @@
  /*
  *  file      : poche_save.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -65,8 +65,8 @@ void pochesave_write_png( gchar *fname, gint width, gint height )
 {
 	cairo_surface_t *cs;
 
-	cs = cairo_image_surface_create( CAIRO_FORMAT_ARGB32, width, height );
-	pochedraw_paint( cs );
+	cs = cairo_image_surface_create( CAIRO_FORMAT_ARGB32, MM(290), MM(360) );
+	pochedraw_paint( cs, NULL );
 	cairo_surface_write_to_png( cs, fname );
 	cairo_surface_destroy( cs );
 }
@@ -76,10 +76,17 @@ void pochesave_write_png( gchar *fname, gint width, gint height )
 void pochesave_write_pdf( gchar *fname, gint width, gint height )
 {
 	cairo_surface_t *cs;
-
-	cs = cairo_pdf_surface_create( fname, width, height );
-	pochedraw_paint( cs );
+	cairo_t			*cr = NULL;
+	
+	
+	// cs = cairo_pdf_surface_create( fname, MM(280), MM(300) );
+	// cs = cairo_pdf_surface_create( fname, width, height );
+	cs = cairo_pdf_surface_create( fname, width, 816 );
+	cr = pochedraw_paint( cs, NULL );
+	// cairo_surface_flush( cs );
 	cairo_surface_destroy( cs );
+	cairo_show_page( cr );
+	cairo_destroy( cr );
 }
 // SEE:
 // http://en.literateprograms.org/Hello_World_%28C,_Cairo%29
@@ -89,7 +96,7 @@ void pochesave_write_ps( gchar *fname, gint width, gint height )
 	cairo_surface_t *cs;
 	
 	cs = cairo_ps_surface_create( fname, width, height );
-	pochedraw_paint( cs );
+	pochedraw_paint( cs, NULL );
 	cairo_surface_destroy( cs );
 }
 // 
@@ -98,21 +105,20 @@ void pochesave_write_ps( gchar *fname, gint width, gint height )
 // 
 void on_button_save_clicked( GtkButton *button, gpointer user_data )
 {
-	gint		width;
-	gint		height;
 	gdouble		OldScale = view.scale;
 	gboolean	BoolScaleAdjust = view.BoolScaleAdjust;
 	gchar		*PathNameSaveFile = NULL;
 	gchar		*NameSaveFile = pochetxt_get_ptr_entry_name_file_to_save();
+	GtkAllocation	allocation;
 	
 	if( NULL == NameSaveFile || '\0' == *NameSaveFile ) {
-		wininfo_create (
+		wind_info_init (
 			WindMain,
-			_("Nom de fichier absent  !!"),
-			_("Pour resoudre ce probleme:"),
+			_("File name not found  !!"),
+			_("To solve this problem :"),
 			  "\n",
 			  "-----------------------------------\n",
-			_("Saisissez un nom de fichier sans extention"),
+			_("Enter a file name without extension"),
 		  	  "");
 		return;
 	}
@@ -122,24 +128,31 @@ void on_button_save_clicked( GtkButton *button, gpointer user_data )
 	// 
 	// PDF POSTSCRIPT
 	// 
-	// StatusBar_puts( _("Sauvegarde aux formats PDF et PostScript") );
-	StatusBar_set_mess( NOTEBOOK_POCHETTE,  _STATUSBAR_SIMPLE_, _("Sauvegarde aux formats PDF et PostScript") );
-	view.scale = 1.55;
+	StatusBar_set_mess( NOTEBOOK_POCHETTE,  _STATUSBAR_SIMPLE_, _("Saving to PDF") );
+	view.scale = 10;
 	poche_set_size_request();
-	gtk_widget_queue_draw( view.AdrDrawingarea );
-	while (gtk_events_pending()) gtk_main_iteration();
-	width  = view.AdrDrawingarea->allocation.width;
-	height = view.AdrDrawingarea->allocation.height;
+	view.scale = 1.55;
+	printf("view.scale = 1.55 \n" );
+	do {
+		poche_set_size_request();
+		while (gtk_events_pending()) gtk_main_iteration();
+		gtk_widget_get_allocation( view.AdrDrawingarea, &allocation );
+		printf("	allocation.width = %d   allocation.height = %d\n", allocation.width, allocation.height );
+	} while( allocation.width != 576 && allocation.height != 816 );
 	
-	PathNameSaveFile = g_strdup_printf( "%s/%s.pdf", Config.PathSaveImg, NameSaveFile );
-	// REDIRECTION VERS PDF ET POSTSCRIPT
+	// REDIRECTION VERS PDF
 	view.BoolSaveToFile  = TRUE;
-	pochesave_write_pdf( PathNameSaveFile, width, height );
+
+	PathNameSaveFile = g_strdup_printf( "%s/%s.pdf", Config.PathSaveImg, NameSaveFile );
+	gtk_widget_get_allocation( view.AdrDrawingarea, &allocation );
+	pochesave_write_pdf( PathNameSaveFile, allocation.width, allocation.height );
 	g_free( PathNameSaveFile );
 	PathNameSaveFile = NULL;
 	
+	/**
+	// REDIRECTION VERS POSTSCRIPT
 	PathNameSaveFile = g_strdup_printf( "%s/%s.ps", Config.PathSaveImg, NameSaveFile );
-	pochesave_write_ps( PathNameSaveFile, width, height );
+	pochesave_write_ps( PathNameSaveFile, allocation.width, allocation.height );
 	g_free( PathNameSaveFile );
 	PathNameSaveFile = NULL;
 	view.BoolSaveToFile  = FALSE;
@@ -150,20 +163,23 @@ void on_button_save_clicked( GtkButton *button, gpointer user_data )
 	// StatusBar_puts( _("Sauvegarde au format PNG") );
 	StatusBar_set_mess( NOTEBOOK_POCHETTE,  _STATUSBAR_SIMPLE_, _("Sauvegarde au format PNG") );
 	view.scale = 2.0;
-	poche_set_size_request();
-	gtk_widget_queue_draw( view.AdrDrawingarea );
-	while (gtk_events_pending()) gtk_main_iteration();
-	width  = view.AdrDrawingarea->allocation.width;
-	height = view.AdrDrawingarea->allocation.height;
+	printf("view.scale = 2.0 \n" );
+	do {
+		poche_set_size_request();
+		while (gtk_events_pending()) gtk_main_iteration();
+		gtk_widget_get_allocation( view.AdrDrawingarea, &allocation );
+		printf("	allocation.width = %d   allocation.height = %d\n", allocation.width, allocation.height );
+	} while( allocation.width > 576 && allocation.height > 816 );
 	
 	PathNameSaveFile = g_strdup_printf( "%s/%s.png", Config.PathSaveImg, NameSaveFile );
 	// REDIRECTION VERS PNG
 	view.BoolSaveToFile  = TRUE;
-	pochesave_write_png( PathNameSaveFile, width, height );
+	pochesave_write_png( PathNameSaveFile, allocation.width, allocation.height );
 	g_free( PathNameSaveFile );
 	PathNameSaveFile = NULL;
-	view.BoolSaveToFile  = FALSE;
+	*/
 	
+	view.BoolSaveToFile  = FALSE;
 	view.scale           = OldScale;
 	view.BoolScaleAdjust = BoolScaleAdjust;
 	poche_set_size_request();
