@@ -1,9 +1,9 @@
  /*
  *  file      : popup.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright :( C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -319,7 +319,7 @@ void popup_make_popup( POP_MENU *p_popup, gint nbr_op )
 	}
 	
 	menu = gtk_menu_new(  );	
-	gtk_widget_set_extension_events( menu, GDK_EXTENSION_EVENTS_ALL );
+	// gtk_widget_set_extension_events( menu, GDK_EXTENSION_EVENTS_ALL );
 
 	for( cpt = 0; cpt < nbr_op; cpt ++ ) {
 		if( p_popup[ cpt ].Op.Type > -1 ) {
@@ -346,7 +346,7 @@ void popup_make_popup( POP_MENU *p_popup, gint nbr_op )
 			gtk_menu_item_set_submenu( GTK_MENU_ITEM( p_popup[ cpt ].Widget), SubMenu );
 		}
 		else if( p_popup[ cpt ].Op.Type == -10 ) {
-			p_popup[ cpt ].Widget = gtk_image_menu_item_new_with_mnemonic( gettext(p_popup[ cpt ].Title) );
+			p_popup[ cpt ].Widget =  gtk_menu_item_new_with_mnemonic( gettext(p_popup[ cpt ].Title) );
 			gtk_widget_show( p_popup[ cpt ].Widget );
 			gtk_container_add( GTK_CONTAINER( SubMenu), p_popup[ cpt ].Widget );
 		}
@@ -486,22 +486,22 @@ void popup_file_wav_piste( DETAIL *detail)
 	
 	Menu = gtk_menu_new(  );
 	
-	CellTrack1 = gtk_menu_item_new_with_mnemonic( _("1  piste") );
+	CellTrack1 = gtk_menu_item_new_with_mnemonic( "1  track" );
 	gtk_widget_show( CellTrack1 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellTrack1  );
-	CellTrack2 = gtk_menu_item_new_with_mnemonic( _("2  pistes") );
+	CellTrack2 = gtk_menu_item_new_with_mnemonic( "2  track" );
 	gtk_widget_show( CellTrack2 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellTrack2  );
-	CellTrack4 = gtk_menu_item_new_with_mnemonic( _("4  pistes") );
+	CellTrack4 = gtk_menu_item_new_with_mnemonic( "4  track" );
 	gtk_widget_show( CellTrack4 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellTrack4  );
-	CellTrack6 = gtk_menu_item_new_with_mnemonic( _("6  pistes") );
+	CellTrack6 = gtk_menu_item_new_with_mnemonic( "6  track" );
 	gtk_widget_show( CellTrack6 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellTrack6  );
 	CellSeparate = gtk_separator_menu_item_new(  );
 	gtk_widget_show( CellSeparate );
 	gtk_container_add( GTK_CONTAINER( Menu), CellSeparate );
-	CellTrackOriginal = gtk_menu_item_new_with_mnemonic( _("Valeur d'origine") );
+	CellTrackOriginal = gtk_menu_item_new_with_mnemonic( _("Original value") );
 	gtk_widget_show( CellTrackOriginal );
 	gtk_container_add( GTK_CONTAINER( Menu), CellTrackOriginal  );
 	
@@ -586,37 +586,37 @@ void popup_file_wav_frequence( DETAIL *detail)
 	GtkWidget *CellHertzOriginal;
 		
 	Menu = gtk_menu_new(  );
-	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	// gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
 		
 
-	CellHertz8000 = gtk_menu_item_new_with_mnemonic( _(" 8000  Hertz") );
+	CellHertz8000 = gtk_menu_item_new_with_mnemonic( " 8000  Hertz" );
 	gtk_widget_show( CellHertz8000 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellHertz8000  );
-	CellHertz22000 = gtk_menu_item_new_with_mnemonic( _("22000  Hertz") );
+	CellHertz22000 = gtk_menu_item_new_with_mnemonic( "22000  Hertz" );
 	gtk_widget_show( CellHertz22000 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellHertz22000  );
-	CellHertz32000 = gtk_menu_item_new_with_mnemonic( _("32000  Hertz") );
+	CellHertz32000 = gtk_menu_item_new_with_mnemonic( "32000  Hertz" );
 	gtk_widget_show( CellHertz32000 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellHertz32000  );
-	CellHertz44056 = gtk_menu_item_new_with_mnemonic( _("44056  Hertz") );
+	CellHertz44056 = gtk_menu_item_new_with_mnemonic( "44056  Hertz" );
 	gtk_widget_show( CellHertz44056 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellHertz44056  );
-	CellHertz44100 = gtk_menu_item_new_with_mnemonic( _("44100  Hertz") );
+	CellHertz44100 = gtk_menu_item_new_with_mnemonic( "44100  Hertz" );
 	gtk_widget_show( CellHertz44100 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellHertz44100  );
-	CellHertz48000 = gtk_menu_item_new_with_mnemonic( _("48000  Hertz") );
+	CellHertz48000 = gtk_menu_item_new_with_mnemonic( "48000  Hertz" );
 	gtk_widget_show( CellHertz48000 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellHertz48000  );
-	CellHertz88200 = gtk_menu_item_new_with_mnemonic( _("88200  Hertz") );
+	CellHertz88200 = gtk_menu_item_new_with_mnemonic( "88200  Hertz" );
 	gtk_widget_show( CellHertz88200 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellHertz88200  );
-	CellHertz96000 = gtk_menu_item_new_with_mnemonic( _("96000  Hertz") );
+	CellHertz96000 = gtk_menu_item_new_with_mnemonic( "96000  Hertz" );
 	gtk_widget_show( CellHertz96000 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellHertz96000  );
 	CellSeparate = gtk_separator_menu_item_new(  );
 	gtk_widget_show( CellSeparate );
 	gtk_container_add( GTK_CONTAINER( Menu), CellSeparate );
-	CellHertzOriginal = gtk_menu_item_new_with_mnemonic( _("Valeur d'origine") );
+	CellHertzOriginal = gtk_menu_item_new_with_mnemonic( _("Original value") );
 	gtk_widget_show( CellHertzOriginal );
 	gtk_container_add( GTK_CONTAINER( Menu), CellHertzOriginal  );
 	
@@ -692,28 +692,27 @@ void popup_file_wav_quantification( DETAIL *detail)
 	GtkWidget *CellOriginal;
 	
 	Menu = gtk_menu_new(  );
-	
-	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	// gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
 		
-	CellWav8 = gtk_menu_item_new_with_mnemonic( _(" 8  bits") );
+	CellWav8 = gtk_menu_item_new_with_mnemonic( " 8  bits" );
 	gtk_widget_show( CellWav8 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellWav8  );
-	CellWav16 = gtk_menu_item_new_with_mnemonic( _("16  bits") );
+	CellWav16 = gtk_menu_item_new_with_mnemonic( "16  bits" );
 	gtk_widget_show( CellWav16 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellWav16  );
-	CellWav24 = gtk_menu_item_new_with_mnemonic( _("24  bits") );
+	CellWav24 = gtk_menu_item_new_with_mnemonic( "24  bits" );
 	gtk_widget_show( CellWav24 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellWav24  );
-	CellWav32 = gtk_menu_item_new_with_mnemonic( _("32  bits") );
+	CellWav32 = gtk_menu_item_new_with_mnemonic( "32  bits" );
 	gtk_widget_show( CellWav32 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellWav32  );
-	CellWav64 = gtk_menu_item_new_with_mnemonic( _("64  bits") );
+	CellWav64 = gtk_menu_item_new_with_mnemonic( "64  bits" );
 	gtk_widget_show( CellWav64 );
 	gtk_container_add( GTK_CONTAINER( Menu), CellWav64  );
 	CellSeparate = gtk_separator_menu_item_new(  );
 	gtk_widget_show( CellSeparate );
 	gtk_container_add( GTK_CONTAINER( Menu), CellSeparate );
-	CellOriginal = gtk_menu_item_new_with_mnemonic( _("Valeur d'origine") );
+	CellOriginal = gtk_menu_item_new_with_mnemonic( _("Original value") );
 	gtk_widget_show( CellOriginal );
 	gtk_container_add( GTK_CONTAINER( Menu), CellOriginal  );
 	
@@ -761,12 +760,13 @@ void popup_file_Split( void )
 	GtkWidget *SplitRemove;
 	
 	Menu = gtk_menu_new(  );
-	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
-	SplitNext = gtk_menu_item_new_with_mnemonic( _("Selecteur suivant") );
+	// gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	
+	SplitNext = gtk_menu_item_new_with_mnemonic( _("Next selector") );
 	gtk_widget_show( SplitNext );
 	gtk_container_add( GTK_CONTAINER( Menu), SplitNext );
 
-	SplitPrevious = gtk_menu_item_new_with_mnemonic( _("Selecteur precedant") );
+	SplitPrevious = gtk_menu_item_new_with_mnemonic( _("Previous selector") );
 	gtk_widget_show( SplitPrevious );
 	gtk_container_add( GTK_CONTAINER( Menu), SplitPrevious );
 	
@@ -774,7 +774,7 @@ void popup_file_Split( void )
 	gtk_widget_show( Separate );
 	gtk_container_add( GTK_CONTAINER( Menu), Separate );
 		
-	SplitRemove = gtk_menu_item_new_with_mnemonic( _("Supprimer la plage active") );
+	SplitRemove = gtk_menu_item_new_with_mnemonic( _("Delete the active range") );
 	gtk_widget_show( SplitRemove );
 	gtk_container_add( GTK_CONTAINER( Menu), SplitRemove );	
 	
@@ -845,12 +845,13 @@ void popup_flip( IMAGE *p_Image )
 	GtkWidget *ImageLast;
 
 	Menu = gtk_menu_new(  );
-	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
-	FlipHorizontal = gtk_menu_item_new_with_mnemonic( _("Retourner horizontalement") );
+	// gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	
+	FlipHorizontal = gtk_menu_item_new_with_mnemonic( _("Flip Horizontal") );
 	gtk_widget_show( FlipHorizontal );
 	gtk_container_add( GTK_CONTAINER( Menu), FlipHorizontal );
 	
-	FlipVertical = gtk_menu_item_new_with_mnemonic( _("Retourner verticalement") );
+	FlipVertical = gtk_menu_item_new_with_mnemonic( _("Flip Vertical") );
 	gtk_widget_show( FlipVertical );
 	gtk_container_add( GTK_CONTAINER( Menu), FlipVertical );
 	
@@ -858,19 +859,19 @@ void popup_flip( IMAGE *p_Image )
 	gtk_widget_show( Separate );
 	gtk_container_add( GTK_CONTAINER( Menu), Separate );
 		
-	ImageFisrt = gtk_menu_item_new_with_mnemonic( _("Image au premier plan") );
+	ImageFisrt = gtk_menu_item_new_with_mnemonic( _("Foreground image") );
 	gtk_widget_show( ImageFisrt );
 	gtk_container_add( GTK_CONTAINER( Menu), ImageFisrt );	
 	
-	ImageUp = gtk_menu_item_new_with_mnemonic( _("Image au dessus") );
+	ImageUp = gtk_menu_item_new_with_mnemonic( _("Image above") );
 	gtk_widget_show( ImageUp );
 	gtk_container_add( GTK_CONTAINER( Menu), ImageUp );	
 
-	ImageDown = gtk_menu_item_new_with_mnemonic( _("Image en dessous") );
+	ImageDown = gtk_menu_item_new_with_mnemonic( _("Image below") );
 	gtk_widget_show( ImageDown );
 	gtk_container_add( GTK_CONTAINER( Menu), ImageDown );	
 	
-	ImageLast = gtk_menu_item_new_with_mnemonic( _("Image au dernier plan") );
+	ImageLast = gtk_menu_item_new_with_mnemonic( _("Image to the background") );
 	gtk_widget_show( ImageLast );
 	gtk_container_add( GTK_CONTAINER( Menu), ImageLast );	
 	
@@ -878,7 +879,7 @@ void popup_flip( IMAGE *p_Image )
 	gtk_widget_show( Separate );
 	gtk_container_add( GTK_CONTAINER( Menu), Separate );
 		
-	RemoveImage = gtk_menu_item_new_with_mnemonic( _("Effacer l'image") );
+	RemoveImage = gtk_menu_item_new_with_mnemonic( _("Clear image") );
 	gtk_widget_show( RemoveImage );
 	gtk_container_add( GTK_CONTAINER( Menu), RemoveImage );	
 
@@ -914,8 +915,9 @@ void popup_viewport( GLIST_POCHETTE *gl )
 	GtkWidget *RemoveImage;
 	
 	Menu = gtk_menu_new(  );
-	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
-	RemoveImage = gtk_menu_item_new_with_mnemonic( _("Supprimer l'image de la liste") );
+	// gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	
+	RemoveImage = gtk_menu_item_new_with_mnemonic( _("Remove image from the list") );
 	gtk_widget_show( RemoveImage );
 	gtk_container_add( GTK_CONTAINER( Menu), RemoveImage );
 	
@@ -975,7 +977,7 @@ void popup_menu_cd( void )
 	gint		Choice;
 	
 	Menu = gtk_menu_new(  );
-	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	// gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
 	
 	for( Choice = 0; -1 != StructTagsFileMp3[ Choice ].num; Choice ++ ) {
 		
@@ -998,6 +1000,79 @@ void popup_menu_cd( void )
 }
 
 
+// 
+//
+// POPUP TAG FILE
+// 
+// 
+/*
+typedef struct {
+	gboolean	BoolFromPopup;
+	gint		num;
+	gchar		*name;
+} FILE_POPUP_GENRE;
+*/
+FILE_POPUP_GENRE FilePopupGenre = { FALSE, -1, NULL };
+
+void on_menu_popup_num_file_activate( GtkMenuItem *menuitem, gpointer user_data )
+{
+	gint	Choice = GPOINTER_TO_INT(user_data);
+	
+	FilePopupGenre.num           = Choice;
+	FilePopupGenre.BoolFromPopup = TRUE;
+	
+	PRINT_FUNC_LF();
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print( "\tPtrEntry = %s\n", FilePopupGenre.name );
+		g_print( "\tNumEntry = %d\n", Choice);
+	}
+
+	gtk_entry_set_text( GTK_ENTRY(GLADE_GET_OBJECT("entry_tag_genre_file")), FilePopupGenre.name );
+	// cd_expander_set_genre( CdPopupGenre.num, CdPopupGenre.name );
+	
+	FileTags_changed_all_tags( 0 ); // #define	TAG_GENRE	0
+	
+	FilePopupGenre.BoolFromPopup = FALSE;
+}
+void on_menu_popup_txt_file_activate( GtkMenuItem *menuitem, gpointer user_data )
+{
+	gchar	*Ptr = (gchar *)user_data;
+	
+	if( NULL != FilePopupGenre.name ) {
+		g_free( FilePopupGenre.name );
+		FilePopupGenre.name = NULL;
+	}
+	FilePopupGenre.name = g_strdup( Ptr );
+}
+void popup_menu_file( void )
+{
+	GtkWidget	*Menu;
+	GtkWidget	*RemoveImage;
+	gint		Choice;
+	
+	Menu = gtk_menu_new(  );
+	// gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	
+	for( Choice = 0; -1 != StructTagsFileMp3[ Choice ].num; Choice ++ ) {
+		
+		// StructTagsFileMp3[ i ].name
+		// StructTagsFileMp3[ i ].num
+		
+	// ********* gtk_combo_box_set_wrap_width (GTK_COMBO_BOX (widget), 4);
+		RemoveImage = gtk_menu_item_new_with_mnemonic( StructTagsFileMp3[ Choice ].name );
+		
+		gtk_widget_show( RemoveImage );
+		gtk_container_add( GTK_CONTAINER( Menu), RemoveImage );
+		
+		g_signal_connect(( gpointer) RemoveImage, "activate", G_CALLBACK(on_menu_popup_txt_file_activate), (gpointer)StructTagsFileMp3[ Choice ].name );
+		g_signal_connect(( gpointer) RemoveImage, "activate", G_CALLBACK(on_menu_popup_num_file_activate), GINT_TO_POINTER(StructTagsFileMp3[ Choice ].num));
+		
+		GLADE_HOOKUP_OBJECT( Menu, RemoveImage, "RemoveImage" );
+	}
+	GLADE_HOOKUP_OBJECT_NO_REF( Menu, Menu, "Menu" );
+
+	gtk_menu_popup( GTK_MENU( Menu), NULL, NULL, NULL, NULL, 3, 0 );
+}
 
 
 
@@ -1033,10 +1108,10 @@ gchar *VarOptionsFileMp3[] = {
 	" 32", " 40", " 48", " 56", " 64", " 80", " 96", "112", "128", "160", "192", "224", "256", "320", "preset insane",
 	// VBR
 	// 29 .. 43
-	"preset medium", "preset standard", "preset extreme", "preset fast standard", "preset fast extreme", gettext_noop("V0 [ meilleure qualite ]"), "V1", "V2", "V3", gettext_noop("V4 [ defaut ]"), "V5", "V6", "V7", "V8", gettext_noop("V9 [ moins bonne qualite ]"),
+	"preset medium", "preset standard", "preset extreme", "preset fast standard", "preset fast extreme", gettext_noop("V0 [ best quality ]"), "V1", "V2", "V3", gettext_noop("V4 [ default ]"), "V5", "V6", "V7", "V8", gettext_noop("V9 [ Lower quality ]"),
 	// VBR-NEW
 	// 44 .. 59
-	"NONE", "preset medium", "preset standard", "preset extreme", "preset fast standard", "preset fast extreme", "V0", "V1", "V2", "V3", gettext_noop("V4 [ defaut ]"), "V5", "V6", "V7", "V8", "V9",
+	"NONE", "preset medium", "preset standard", "preset extreme", "preset fast standard", "preset fast extreme", "V0", "V1", "V2", "V3", gettext_noop("V4 [ default ]"), "V5", "V6", "V7", "V8", "V9",
 	// MODE
 	// 60 .. 65
 	"Default", "Stereo", "Join Stereo", "Forced Join Stereo", "Duo Channels", "Mono"
@@ -1085,7 +1160,7 @@ void popup_file_mp3_type( DETAIL *detail, gint p_debit, gint p_mode )
 	Detail_VarOptionsFileOggMp3 = detail;
 	
 	Menu = gtk_menu_new(  );
-	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	// gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
 	
 	// ABR
 	Type = gtk_menu_item_new_with_mnemonic( "Abr" );
@@ -1216,11 +1291,11 @@ DOWNMIX:	Mono force / Stereo
 gchar *VarOptionsFileOgg[] = {
 	// 0 .. 22
 	" 45  kbit/s", " 64  kbit/s", " 80  kbit/s", " 96  kbit/s", "112  kbit/s", "128  kbit/s", "160  kbit/", "192  kbit/s", "224  kbit/s", "256  kbit/s", "320  kbit/s",
-	gettext_noop("Qualite -1 [ Moins bonne qualite ]"), gettext_noop("Qualite  0"), gettext_noop("Qualite  1"), gettext_noop("Qualite  2"),
-	gettext_noop("Qualite  3 [ Defaut ]"), gettext_noop("Qualite  4"), gettext_noop("Qualite  5"), gettext_noop("Qualite  6"), gettext_noop("Qualite  7"),
-	gettext_noop("Qualite  8"), gettext_noop("Qualite  9"), gettext_noop("Qualite  10 [ Meilleure qualite ]"),
+	gettext_noop("Quality -1 [ Lower quality ]"), gettext_noop("Quality  0"), gettext_noop("Quality  1"), gettext_noop("Quality  2"),
+	gettext_noop("Quality  3 [ Defaut ]"), gettext_noop("Quality  4"), gettext_noop("Quality  5"), gettext_noop("Quality  6"), gettext_noop("Quality  7"),
+	gettext_noop("Quality  8"), gettext_noop("Quality  9"), gettext_noop("Quality  10 [ Best Quality ]"),
 	// 23 .. 24
-	gettext_noop("Oui"), gettext_noop("Non"),
+	gettext_noop("Yes"), gettext_noop("No"),
 	// 25 .. 26
 	"Mono force", "Stereo"
 };
@@ -1277,7 +1352,7 @@ void popup_file_ogg_type( DETAIL *detail, gint p_debit, gint p_managed, gint p_d
 	Detail_VarOptionsFileOggMp3 = detail;
 	
 	Menu = gtk_menu_new(  );
-	gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
+	// gtk_widget_set_extension_events( Menu, GDK_EXTENSION_EVENTS_ALL );
 	
 	// DEBIT
 	Debit = gtk_menu_item_new_with_mnemonic( "Debit" );
