@@ -1,9 +1,9 @@
  /*
  *  file      : popup.h
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -49,16 +49,27 @@ void	popup_trash (void);
 void	popup_normalise_cd (void);
 void	popup_normalise_dvd (void);
 
+
+
 typedef struct {
 	gboolean	BoolFromPopup;
 	gint		num;
 	gchar		*name;
 } CD_POPUP_GENRE;
 extern CD_POPUP_GENRE CdPopupGenre ;
-
 void	popup_menu_cd( void );
 
 
+typedef struct {
+	gboolean	BoolFromPopup;
+	gint		num;
+	gchar		*name;
+} FILE_POPUP_GENRE;
+extern FILE_POPUP_GENRE FilePopupGenre ;
+void 	popup_menu_file( void );
+
+
+
 void	popup_file_mp3_type( DETAIL *detail, gint p_debit, gint p_mode );
 void	popup_file_ogg_type( DETAIL *detail, gint p_debit, gint p_managed, gint p_downmix );
 gchar	*popup_get_param_ogg( gint p_debit, gint p_managed, gint p_downmix );
