@@ -1,9 +1,9 @@
  /*
  *  file      : prg_init.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -354,37 +354,37 @@ void on_label_type_package_realize (GtkWidget *widget, gpointer user_data)
 	
 	if (libutils_find_file ("apt-get") == TRUE || libutils_find_file ("aptitude") == TRUE) {
 		if (widget != NULL) {
-			New_Str = g_strdup_printf (_(" <b>... les paquets: deb</b> "));
+			New_Str = g_strdup_printf (_(" <b>... Packets: deb</b> "));
 		}
 		var_options.Type_Package = _DEBIAN_;
 	}
 	else if (libutils_find_file ("slackpkg") == TRUE || libutils_find_file ("installpkg") == TRUE) {
 		if (widget != NULL) {
-			New_Str = g_strdup_printf (_(" <b>... les paquets: tgz</b> "));
+			New_Str = g_strdup_printf (_(" <b>... Packets: tgz</b> "));
 		}
 		var_options.Type_Package = _TGZ_;
 	}
 	else if (libutils_find_file ("pacman-g2") == TRUE) {
 		if (widget != NULL) {
-			New_Str = g_strdup_printf (_(" <b>... les paquets: fpm</b> "));
+			New_Str = g_strdup_printf (_(" <b>... Packets: fpm</b> "));
 		}
 		var_options.Type_Package = _FPM_;
 	}
 	else if (libutils_find_file ("rpm") == TRUE || libutils_find_file ("urpmi") == TRUE  || libutils_find_file ("zypper") == TRUE || libutils_find_file ("yum") == TRUE) {
 		if (widget != NULL) {
-			New_Str = g_strdup_printf (_(" <b>... les paquets: rpm</b> "));
+			New_Str = g_strdup_printf (_(" <b>... Packets: rpm</b> "));
 		}
 		var_options.Type_Package = _RPM_;
 	}
 	else if (libutils_find_file ("yaourt") == TRUE || libutils_find_file ("pacman") == TRUE) {
 		if (widget != NULL) {
-			New_Str = g_strdup_printf (_(" <b>... les paquets: pkg.tar.xz</b> "));
+			New_Str = g_strdup_printf (_(" <b>... Packets: pkg.tar.xz</b> "));
 		}
 		var_options.Type_Package = _ARCHLINUX_;
 	}
 	else {
 		if (widget != NULL) {
-			New_Str = g_strdup_printf (_(" <b>... les paquets: ?</b> "));
+			New_Str = g_strdup_printf (_(" <b>... Packets: ?</b> "));
 		}
 		var_options.Type_Package = _PACKAGE_NOT_FOUND_;
 	}
@@ -606,7 +606,7 @@ static void prginit_add_columns (GtkTreeView *treeview)
 	// PRGEXT_NAME
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.0, NULL);
-	column = gtk_tree_view_column_new_with_attributes (_("Nom"),
+	column = gtk_tree_view_column_new_with_attributes (_("Name"),
 						     renderer,
 						     "markup", PRGEXT_NAME,
 						     NULL);
@@ -634,7 +634,7 @@ static void prginit_add_columns (GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set (renderer, "xalign", 0.0, NULL);
 	column = gtk_tree_view_column_new_with_attributes (
-							_("Paquet"),
+							_("Packets"),
 							renderer,
 							"markup", PRGEXT_PAQUAGE,
 							NULL);
@@ -681,7 +681,7 @@ void on_scrolledwindow_applications_externes_realize (GtkWidget *widget, gpointe
 				    );
 	var_prgextern.Adr_Tree_Model = model = GTK_TREE_MODEL (store);
 	treeview = gtk_tree_view_new_with_model (model);
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
+	// gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);
 	g_object_unref (model);
 	gtk_container_add (GTK_CONTAINER (widget), treeview);
 	prginit_add_columns (GTK_TREE_VIEW (treeview));
