@@ -1,9 +1,9 @@
  /*
  *  file      : replaygain.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -294,7 +294,7 @@ void replaygain_set_list( RPG_TYPE rpg_type, ETAT_REPLAYGAIN rpg_action)
 		rpg.bool_etat = TRUE;
 		PtrTabArgs [ pos++ ] = NULL;
 		conv_to_convert( PtrTabArgs, FALSE, REPLAYGAIN, rpg.MessUser );
-		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+		PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 		
 		rpg.bool_compteur = FALSE;
 
@@ -368,7 +368,7 @@ static gint replaygain_timeout (gpointer data)
 		} else if( rpg.type_replaygain ==  _APPLY_REPLAYGAIN_ ) {
 			fileaction_set_end (TYPE_REPLAYGAINAPPLY );
 		}
-		gtk_timeout_remove (rpg.handler_timeout );
+		g_source_remove (rpg.handler_timeout );
 	}
 	
 	return (TRUE );
@@ -478,9 +478,14 @@ void replaygain_action( TYPE_REPLAYGAIN type_replaygain)
 	}
 
 	conv_reset_struct( WindScan_close_request );
-	WindScan_open( "ReplayGain", WINDSCAN_PULSE );
+	// WindScan_open( "ReplayGain", WINDSCAN_PULSE );
+	wind_scan_init(
+		WindMain,
+		"ReplayGain",
+		WINDSCAN_PULSE 
+		);
 	WindScan_set_label( "<b><i>ReplayGain ...</i></b>" );
-	rpg.handler_timeout = gtk_timeout_add( 100, replaygain_timeout, 0 );
+	rpg.handler_timeout = g_timeout_add( 100, replaygain_timeout, 0 );
 	pthread_create( &rpg.nmr_tid, NULL ,(void *)replaygain_thread, (void *)NULL );
 }
 
