@@ -311,7 +311,7 @@ GList *scan_scan_drives_cd_dvd (void)
 		g_print ("%s::%s(line=%d) \n", __FILE__, __FUNCTION__, __LINE__);
 	}
 	
-	if( TRUE == libutils_test_dir_exist( "/dev" )) {
+	if( TRUE == g_file_test( "/dev", G_FILE_TEST_IS_DIR )) {
 		for (pass = 0, Lcurentry = listesearchdrives; Lcurentry->detectline; pass++, Lcurentry++) {
 
 			/* Entree en test ? */
