@@ -1,9 +1,9 @@
  /*
  *  file      : split_conv.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -125,6 +125,8 @@ static void SplitConv_thread (void *arg)
 	gboolean	BoolPassSox = FALSE;
 	gchar		**PtrTabArgs = NULL;
 	
+printf("---------------------------- SplitConv_thread( \n" );
+
 	conv.bool_thread_conv = TRUE;
 	
 	if (FILE_IS_WAV == VarSplitConv.TypeFileIs) {
@@ -142,7 +144,7 @@ static void SplitConv_thread (void *arg)
 		PtrTabArgs [ pos++ ] = g_strdup ("44100");
 		PtrTabArgs [ pos++ ] = NULL;
 		conv_to_convert( PtrTabArgs, FALSE, MPLAYER_WAV_TO_WAV, "MPLAYER_WAV_TO_WAV");
-		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+		PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_FLAC == VarSplitConv.TypeFileIs) {
@@ -157,7 +159,7 @@ static void SplitConv_thread (void *arg)
 		param_filelc.PtrStrBitrate        = NULL;
 		PtrTabArgs = filelc_get_command_line (&param_filelc);
 		conv_to_convert( PtrTabArgs, FALSE, FLAC_FLAC_TO_WAV, "FLAC_FLAC_TO_WAV");
-		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+		PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_APE == VarSplitConv.TypeFileIs) {
@@ -172,7 +174,7 @@ static void SplitConv_thread (void *arg)
 		param_filelc.PtrStrBitrate        = NULL;
 		PtrTabArgs = filelc_get_command_line (&param_filelc);
 		conv_to_convert( PtrTabArgs, FALSE, MAC_APE_TO_WAV, "MAC_APE_TO_WAV");
-		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+		PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_WAVPACK == VarSplitConv.TypeFileIs) {
@@ -190,7 +192,7 @@ static void SplitConv_thread (void *arg)
 		PtrTabArgs [ pos++ ] = g_strdup_printf ("pcm:file=%s", SPLIT_FILE_TMP_WAV_SOX);
 		PtrTabArgs [ pos++ ] = NULL;
 		conv_to_convert( PtrTabArgs, FALSE, MPLAYER_OGG_TO_WAV, "MPLAYER_OGG_TO_WAV");
-		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+		PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_M4A == VarSplitConv.TypeFileIs) {
@@ -210,7 +212,7 @@ static void SplitConv_thread (void *arg)
 		PtrTabArgs [ pos++ ] = g_strdup_printf ("pcm:file=%s", SPLIT_FILE_TMP_WAV_SOX);
 		PtrTabArgs [ pos++ ] = NULL;
 		conv_to_convert( PtrTabArgs, FALSE, MPLAYER_MP3_TO_WAV, "MPLAYER_MP3_TO_WAV");
-		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+		PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_WMA == VarSplitConv.TypeFileIs) {
@@ -230,7 +232,7 @@ static void SplitConv_thread (void *arg)
 		PtrTabArgs [ pos++ ] = g_strdup ("44100");
 		PtrTabArgs [ pos++ ] = NULL;
 		conv_to_convert( PtrTabArgs, FALSE, MPLAYER_WMA_TO_WAV, "MPLAYER_WMA_TO_WAV");
-		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+		PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 		BoolPassSox = TRUE;
 	}
 	else if (FILE_IS_SHN == VarSplitConv.TypeFileIs) {
@@ -246,7 +248,7 @@ static void SplitConv_thread (void *arg)
 	if (TRUE == BoolPassSox) {
 		PtrTabArgs = conv_with_sox_get_param (SPLIT_FILE_TMP_WAV_SOX, SPLIT_FILE_TMP_WAV, "44100", "2", "16");
 		conv_to_convert( PtrTabArgs, FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
-		PtrTabArgs = filelc_RevoveTab( PtrTabArgs );
+		PtrTabArgs = filelc_RemoveTab( PtrTabArgs );
 	}
 	
 	PRINT("FIN THREAD SPLITCONV");
@@ -295,10 +297,11 @@ static gint SplitConv_timeout (gpointer data)
 	else if (TRUE == conv.bool_thread_conv) {
 	}
 	else if (FALSE == conv.bool_thread_conv) {
+printf("---------------------------- FIN SplitConv_timeout( \n" );
 		PRINT("FIN TIMEOUT SPLITCONV");
 		if( TRUE == OptionsCommandLine.BoolVerboseMode )
 			g_print ("\n");
-		gtk_timeout_remove (conv.handler_timeout_conv);
+		g_source_remove (conv.handler_timeout_conv);
 		// WindScan_close ();
 		while (gtk_events_pending()) gtk_main_iteration();
 		if (NULL != VarSplitConv.DestPathnameFile) {
@@ -308,12 +311,12 @@ static gint SplitConv_timeout (gpointer data)
 			else {
 				WindScan_close ();
 				if( FALSE == WindScan_close_request()) {
-					wininfo_create (
+					wind_info_init (
 						WindMain,
-						_("Erreur SOX"),
-						_("Le programme SOX de votre distribution"),
+						_("SOX Error"),
+						_("The SOX program on your distribution"),
 						"\n",
-						_("a generer une erreur pendant la conversion."),
+						_("has generated an error during conversion."),
 						"");
 				}
 			}
@@ -325,12 +328,12 @@ static gint SplitConv_timeout (gpointer data)
 			else {
 				WindScan_close ();
 				if( FALSE == WindScan_close_request()) {
-					wininfo_create (
+					wind_info_init (
 						WindMain,
-						_("Erreur SOX"),
-						_("Le programme SOX de votre distribution"),
+						_("SOX Error"),
+						_("The SOX program on your distribution"),
 						"\n",
-						_("a generer une erreur pendant la conversion."),
+						_("has generated an error during conversion."),
 						"");
 				}
 			}
@@ -341,12 +344,14 @@ static gint SplitConv_timeout (gpointer data)
 }
 // 
 // 
-void SplitConv_to (gchar *p_PathNameFile)
+void SplitConv_to( gchar *p_PathNameFile )
 {
 	gint		Channels;
 	gint		Hertz;
 	gint		Bits;
 	pthread_t	nmr_tid;
+	
+printf("---------------------------- SplitConv_to( %s\n", p_PathNameFile );
  	
 	VarSplitConv.TypeFileIs = GetInfo_file_is (p_PathNameFile);
 	
@@ -402,11 +407,21 @@ void SplitConv_to (gchar *p_PathNameFile)
 		conv.total_convert = 2;
 	}
 	if (FILE_IS_NONE != VarSplitConv.TypeFileIs) {
-		WindScan_open ("SOX files", WINDSCAN_PULSE);
+		// WindScan_open ("SOX files", WINDSCAN_PULSE);
+		wind_scan_init(
+			WindMain,
+			"SOX files",
+			WINDSCAN_PULSE
+			);
 		WindScan_set_label ("<b><i>SOX files ...</i></b>");
 	}
 	else {
-		WindScan_open ("Analyse du fichier", WINDSCAN_PULSE);
+		// WindScan_open ("Analyse du fichier", WINDSCAN_PULSE);
+		wind_scan_init(
+			WindMain,
+			"Analyse du fichier",
+			WINDSCAN_PULSE
+			);
 		WindScan_set_label ("<b><i>Analyse du fichier ...</i></b>");
 	}
 
@@ -414,7 +429,7 @@ void SplitConv_to (gchar *p_PathNameFile)
 	PRINT("DEBUT TIMEOUT SPLITCONV");
 	PRINT("DEBUT THREAD SPLITCONV");
  	pthread_create (&nmr_tid, NULL ,(void *)SplitConv_thread, (void *)NULL);
-	conv.handler_timeout_conv = gtk_timeout_add (20, SplitConv_timeout, 0);
+	conv.handler_timeout_conv = g_timeout_add (20, SplitConv_timeout, 0);
 }
 
 
