@@ -59,7 +59,7 @@ gint SplitSpectre_get_with (void)
 	GtkAllocation	allocation;
 	
 	gtk_widget_get_allocation( VarSplit.AdrWidgetSpectre, &allocation );
-	return( allocation.width * Adjust.mul );
+	return( (allocation.width -1) * Adjust.mul );
 }
 // AFFICHAGE IMAGE CHRONO
 // 
@@ -921,7 +921,7 @@ TAB_COLOR tab_color[ 4 ] =
 	// LIGNE SELECTEUR ACTIF DEBUT
 	if (SelBegin >= save_begin && SelBegin < Len) {
 		cairo_set_source_rgb( p_cr, 244. / 255., 162. / 255., 87. / 255. );
-		cairo_move_to( p_cr, SelBegin  -save_begin, 0.0 );
+		cairo_move_to( p_cr, SelBegin - save_begin, 0.0 );
 		cairo_rel_line_to( p_cr, 0.0, allocation.height );
 		cairo_stroke ( p_cr );
 	}
@@ -938,7 +938,9 @@ TAB_COLOR tab_color[ 4 ] =
 	// AFFICHE LE CURSEUR AUDIO
 	if (VarSplit.PercentActivePlay >= 0.0) {
 		MarkerOld = (gint)(((gdouble)SplitSpectre_get_with() * VarSplit.PercentActivePlay) / 100.0);
-		if (MarkerOld >= save_begin && MarkerOld < Len) {
+		if( MarkerOld < save_begin ) MarkerOld = save_begin + 1;
+		if( MarkerOld > Len-4 ) MarkerOld = Len - 4;
+		if (MarkerOld >= save_begin && MarkerOld < Len ) {
 			cairo_set_source_rgb( p_cr, 1.0, 0.0, 0.0 );
 			cairo_move_to( p_cr, MarkerOld - save_begin, 0.0 );
 			cairo_rel_line_to( p_cr, 0.0, allocation.height );
