@@ -1,9 +1,9 @@
  /*
  *  file      : statusbar.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -70,7 +70,7 @@ static gint StatusBar_timeout( gpointer data )
 	
 	if( VarStatusBar.stop.tv_sec - VarStatusBar.start.tv_sec > 3 ) {
 		
-		gtk_timeout_remove( VarStatusBar.handler_timeout_conv );
+		g_source_remove( VarStatusBar.handler_timeout_conv );
 		
 		if( _STATUSBAR_ERR_ == VarStatusBar.StatusMess ) {
 			g_free( StatusBar [ VarStatusBar.NoteBook_which ] . MessError );	StatusBar [ VarStatusBar.NoteBook_which ] . MessError = NULL;
@@ -93,7 +93,7 @@ void StatusBar_timer( gint p_which, STATUS_BAR_MESS p_StatusMess )
 		VarStatusBar.StatusMess          = p_StatusMess;
 		VarStatusBar.bool_timer_activate = TRUE;
 		gettimeofday( &VarStatusBar.start, NULL );
-		VarStatusBar.handler_timeout_conv = gtk_timeout_add( 2, StatusBar_timeout, 0 );
+		VarStatusBar.handler_timeout_conv = g_timeout_add( 2, StatusBar_timeout, 0 );
 	}
 }
 // 
