@@ -1,9 +1,9 @@
  /*
  *  file      : tags.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -402,8 +402,7 @@ void tags_set_elements_combobox (GtkWidget *widget)
 	gint i;
 	
 	for (i=0; StructTagsFileMp3[ i ].num != -1; i++)
-		gtk_combo_box_append_text (GTK_COMBO_BOX (widget), StructTagsFileMp3[ i ].name);
-	
+		gtk_combo_box_text_append_text( GTK_COMBO_BOX_TEXT(widget), StructTagsFileMp3[ i ].name);
 }
 // 
 // 
