@@ -1,9 +1,9 @@
  /*
  *  file    : tags_wav.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -356,14 +356,14 @@ gboolean tagswav_read_file (gchar *wave_file, WAVE *WaveHeader)
 // 
 INFO_WAV *tagswav_remove_info (INFO_WAV *info)
 {
-	if (info) {
-		if (NULL != info->time)		{ g_free (info->time);		info->time = NULL;	}
-		if (NULL != info->hertz)	{ g_free (info->hertz);		info->hertz = NULL;	}
-		if (NULL != info->voie)		{ g_free (info->voie);		info->voie = NULL;	}
-		if (NULL != info->bits)		{ g_free (info->bits);		info->bits = NULL;	}
-		if (NULL != info->NewHertz)	{ g_free (info->NewHertz);	info->NewHertz = NULL;	}
-		if (NULL != info->NewVoie)	{ g_free (info->NewVoie);	info->NewVoie = NULL;	}
-		if (NULL != info->NewBits)	{ g_free (info->NewBits);	info->NewBits = NULL;	}
+	if( NULL != info ) {
+		if( NULL != info->time )		{ g_free( info->time );		info->time = NULL;		}
+		if( NULL != info->hertz )		{ g_free( info->hertz );	info->hertz = NULL;		}
+		if( NULL != info->voie )		{ g_free( info->voie );		info->voie = NULL;		}
+		if( NULL != info->bits )		{ g_free( info->bits );		info->bits = NULL;		}
+		if( NULL != info->NewHertz )	{ g_free( info->NewHertz );	info->NewHertz = NULL;	}
+		if( NULL != info->NewVoie )		{ g_free( info->NewVoie );	info->NewVoie = NULL;	}
+		if( NULL != info->NewBits )		{ g_free( info->NewBits );	info->NewBits = NULL;	}
 
 		info->tags = (TAGS *)tags_remove (info->tags);
 
