@@ -1,9 +1,9 @@
  /*
  *  file      : wind_about.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -31,6 +31,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <stdlib.h>
 
 #ifdef ENABLE_STATIC_LIBRARY
 	#include "../lib/lib.h"
@@ -43,16 +44,8 @@
 
 
 
-
-typedef struct {
-
-	GtkWidget	*AdrWin;
-	gboolean	IsShow;
-
-} VAR_WINABOUT;
-
-VAR_WINABOUT	VarWinAbout = { NULL, FALSE };
-
+GtkBuilder	*GtkBuilderProjet_wind_about = NULL;
+GtkWidget	*WindMain_wind_about = NULL;
 
 
 
@@ -60,24 +53,27 @@ VAR_WINABOUT	VarWinAbout = { NULL, FALSE };
 // 
 gboolean on_wind_about_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
-	gtk_widget_hide (VarWinAbout.AdrWin);
-	VarWinAbout.IsShow = FALSE;
+	gtk_widget_destroy( WindMain_wind_about );
+	WindMain_wind_about = NULL;
+	GtkBuilderProjet_wind_about = NULL;
 	return (TRUE);
 }
 // 
 // 
 gboolean on_wind_about_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
-	gtk_widget_hide (VarWinAbout.AdrWin);
-	VarWinAbout.IsShow = FALSE;
+	gtk_widget_destroy( WindMain_wind_about );
+	WindMain_wind_about = NULL;
+	GtkBuilderProjet_wind_about = NULL;
 	return (TRUE);
 }
 // 
 // 
 void on_button_ok_about_clicked (GtkButton *button, gpointer user_data)
 {
-	VarWinAbout.IsShow = FALSE;
-	gtk_widget_hide (VarWinAbout.AdrWin);
+	gtk_widget_destroy( WindMain_wind_about );
+	WindMain_wind_about = NULL;
+	GtkBuilderProjet_wind_about = NULL;
 }
 // 
 // 
@@ -90,26 +86,24 @@ void on_button_contrib_about_clicked (GtkButton *button, gpointer user_data)
 	#define MAX_TYPE_BUTTON_PAGE_WEB 21
 	TYPE_BUTTON TypeButton [ MAX_TYPE_BUTTON_PAGE_WEB ] = {
 	{"button_pagexcfa_about",		"http://www.xcfa.tuxfamily.org"},
-	// {"button01_contrib_about",		"http://www.road2mayotte.org/index.html"},
-	{"button01_contrib_about",		"http://www.road2mayotte.org/blook/"},
-	{"button02_contrib_about",		"http://e17blog.tuxfamily.org/index.php"},
+	{"button01_contrib_about",		"http://www.road2mayotte.org/blook/"},						/* TODO */
+	{"button02_contrib_about",		"http://e17blog.tuxfamily.org/index.php"},					/* TODO ok */
 	{"button03_contrib_about",		"http://ubunteros.tuxfamily.org/spip.php?page=plan"},
 	{"button04_contrib_about",		"http://www.jesuislibre.org"},
-	{"button05_contrib_about",		"http://audiobezon.dlinkddns.com/"},
+	{"button05_contrib_about",		"http://audiobezon.dlinkddns.com/"},						/* TODO ok */
 	{"button06_contrib_about",		"http://www.tuxfamily.org"},
 	{"button07_contrib_about",		"http://www.framasoft.net/article4492.html"},
 	{"button08_contrib_about",		"http://ekd.tuxfamily.org"},
-	{"button09_contrib_about",		"http://defis-libristes.tuxfamily.org/viewforum.php?id=2"},
+	{"button09_contrib_about",		"http://defis-libristes.tuxfamily.org/viewforum.php?id=2"},	/* TODO */
 	{"button10_contrib_about",		"http://doc.ubuntu-fr.org/xcfa"},
 	{"button11_contrib_about",		"http://unm.arcis.free.fr/spip.php?article109"},
 	{"button12_contrib_about",		"http://ubunteros.tuxfamily.org/spip.php?article168"},
 	{"button13_contrib_about",		"http://ubunteros.tuxfamily.org/spip.php?article159"},
 	{"button14_contrib_about",		"http://ubunteros.tuxfamily.org/spip.php?article30"},
-	// {"button15_contrib_about",		"http://lalinuxerie.free.fr/"},
 	{"button15_contrib_about",		"http://linuxerie.midiblogs.com/"},
-	{"button16_contrib_about",		"http://www.debian-multimedia.org/"},
+	{"button16_contrib_about",		"http://www.deb-multimedia.org/"},
 	{"button17_contrib_about",		"http://frugalware.org/"},
-	{"button20_contrib_about",		"http://opera-info.de/forum/thread.php?threadid=20506"},
+	{"button20_contrib_about",		"http://opera-info.de/forum/thread.php?threadid=20506"},	/* TODO ok*/
 	{"button21_contrib_about",		"http://linuxforen.de/forums/showthread.php?p=1693658"},
 	{"button22_contrib_about",		"http://www.alessiotreglia.com/"}
 	};
@@ -117,7 +111,7 @@ void on_button_contrib_about_clicked (GtkButton *button, gpointer user_data)
 	gint cpt;
 
 	for (cpt = 0; cpt < MAX_TYPE_BUTTON_PAGE_WEB; cpt ++) {
-		if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (GLADE_GET_OBJECT(TypeButton [ cpt ].NameWidget)))) {
+		if (GTK_BUTTON (button) == GTK_BUTTON (GTK_WIDGET (gtk_builder_get_object( GtkBuilderProjet_wind_about, TypeButton [ cpt ].NameWidget)))) {
 			web_goto_url (TypeButton [ cpt ].Url);
 			break;
 		}
@@ -127,7 +121,7 @@ void on_button_contrib_about_clicked (GtkButton *button, gpointer user_data)
 // 
 void on_label_button_pagexcfa_about_realize (GtkWidget *widget, gpointer user_data)
 {
-	gtk_label_set_markup (GTK_LABEL (widget), _("<span foreground=\"#0000FF\">  Xcfa sur le web</span>"));
+	gtk_label_set_markup (GTK_LABEL (widget), _("<span foreground=\"#0000FF\">  Xcfa on the web</span>"));
 }
 // 
 // 
@@ -137,7 +131,7 @@ void on_textview_label_license_about_realize (GtkWidget *widget, gpointer user_d
 	gtk_text_view_set_justification (GTK_TEXT_VIEW (widget), GTK_JUSTIFY_CENTER);
 	gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (widget), FALSE);
 	gtk_text_buffer_set_text (gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget)),
-	"\n\nCopyright (C) 2003 - 2013\n\n\n"
+	"\n\nCopyright (C) 2003 - 2015\n\n\n"
 	"XCFA is free software; you can redistribute it and/or modify\n"
 	"it under the terms of the GNU General Public License as published by\n"
 	"the Free Software Foundation; either version 3 of the License, or\n"
@@ -221,7 +215,7 @@ void on_label_about_machine_realize (GtkWidget *widget, gpointer user_data)
 void on_label_author_about_realize (GtkWidget *widget, gpointer user_data)
 {
 	gtk_label_set_justify (GTK_LABEL(widget), GTK_JUSTIFY_CENTER);
-	gtk_label_set_markup (GTK_LABEL(widget), "\nCopyright © 2003-2013  -  Bulin Claude  -  fr\n");
+	gtk_label_set_markup (GTK_LABEL(widget), "\nCopyright © 2003-2015  -  Bulin Claude  -  fr\n");
 }
 // 
 // 
@@ -269,23 +263,31 @@ void on_image_about_realize (GtkWidget *widget, gpointer user_data)
 }
 // 
 // 
-void WinAbout_open (gchar *title)
+gboolean wind_about_init( GtkWidget *FromWindMain )
 {
-	if (TRUE == VarWinAbout.IsShow) {
-		gdk_window_raise (VarWinAbout.AdrWin->window);
+	gchar	*PackageVersion = NULL;
+	
+	if( NULL == (GtkBuilderProjet_wind_about = Builder_open( "xcfa_win_about.glade", GtkBuilderProjet_wind_about ))) {
+		return( EXIT_FAILURE );
 	}
-	else {		
-		if (NULL == VarWinAbout.AdrWin) {
-			VarWinAbout.AdrWin = GTK_WIDGET (GLADE_GET_OBJECT("wind_about"));
-			gtk_builder_connect_signals (GtkXcfaProjet, NULL);
-		}
-		gtk_window_set_transient_for (GTK_WINDOW(VarWinAbout.AdrWin), GTK_WINDOW(WindMain));
-		gtk_window_set_modal (GTK_WINDOW (VarWinAbout.AdrWin), TRUE);
-		libutils_set_default_icone_to_win (VarWinAbout.AdrWin);
+	// Add language support from glade file
+	gtk_builder_set_translation_domain(  GtkBuilderProjet_wind_about, "wind_about" );
+	gtk_builder_connect_signals( GtkBuilderProjet_wind_about, NULL );
 
-		gtk_widget_show (VarWinAbout.AdrWin);
+	WindMain_wind_about = GTK_WIDGET( gtk_builder_get_object( GtkBuilderProjet_wind_about, "wind_about" ));
+	if( NULL != FromWindMain ) {
+		gtk_window_set_transient_for (GTK_WINDOW(WindMain_wind_about), GTK_WINDOW(FromWindMain));
+		gtk_window_set_modal (GTK_WINDOW(WindMain_wind_about), TRUE);
 	}
-	VarWinAbout.IsShow = TRUE;
-	if (NULL != title) gtk_window_set_title (GTK_WINDOW (VarWinAbout.AdrWin), title);
+	libutils_set_default_icone_to_win( WindMain_wind_about );
+
+	PackageVersion = g_strdup_printf( "%s  -  %s", PACKAGE_NAME, VERSION );
+	gtk_window_set_title( GTK_WINDOW( WindMain_wind_about ), PackageVersion );
+	g_free( PackageVersion );
+	PackageVersion = NULL;
+
+	gtk_widget_show_all( WindMain_wind_about );
+
+	return( TRUE );
 }
 
