@@ -1,9 +1,9 @@
  /*
  *  file      : wind_about.h
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -27,7 +27,7 @@
 #ifndef win_about_h
 #define win_about_h 1
 
-void WinAbout_open (gchar *title);
+gboolean wind_about_init( GtkWidget *FromWindMain );
 
 #endif
 
