@@ -1,9 +1,9 @@
  /*
  *  file      : win_info.h
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -29,7 +29,8 @@
 #define win_info_h 1
 
 
-void wininfo_create( GtkWidget *p_WindMain, gchar *title, ... );
+// void wininfo_create( GtkWidget *p_WindMain, gchar *title, ... );
+gboolean wind_info_init( GtkWidget *FromWindMain, gchar *title, ...  );
 
 
 #endif
