@@ -1,9 +1,9 @@
  /*
  *  file      : win_reader.c
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -45,12 +45,10 @@
 
 typedef struct {
 
-	GtkWidget	*AdrWin;
-	GtkWidget	*AdrScale;
-	GtkObject	*AdrAdjust;
-	GtkWidget	*AdrHscale;
-	gboolean	IsShow;
-	gboolean	BoolValueChange;
+	GtkWidget		*AdrScale;
+	GtkAdjustment	*AdrAdjust;
+	GtkWidget		*AdrHscale;
+	gboolean		BoolValueChange;
 	
 } VAR_WINDREADER;
 
@@ -58,20 +56,18 @@ VAR_WINDREADER VarWindReader = {
 	NULL,
 	NULL,
 	NULL,
-	NULL,
-	FALSE,
 	FALSE
 };
 
 
+GtkBuilder	*GtkBuilderProjet_wind_reader = NULL;
+GtkWidget	*WindMain_wind_reader = NULL;
 
 
 
 void WinReader_set_value (gdouble p_value)
 {
-	if (TRUE == VarWindReader.IsShow) {
-		gtk_adjustment_set_value (GTK_ADJUSTMENT (VarWindReader.AdrAdjust), p_value);
-	}
+	gtk_adjustment_set_value (GTK_ADJUSTMENT (VarWindReader.AdrAdjust), p_value);
 }
 // HSCALE VALUR-CHANGE
 // 
@@ -107,12 +103,20 @@ gboolean WinReader_event (GtkWidget *treeview, GdkEvent *event, gpointer user_da
 // 
 void on_hbox_WindReader_realize (GtkWidget *widget, gpointer user_data)
 {
-	VarWindReader.AdrAdjust = gtk_adjustment_new (0, 0, 100.0, 0.001, 1, 0);
-	VarWindReader.AdrHscale = gtk_hscale_new (GTK_ADJUSTMENT (VarWindReader.AdrAdjust));
+	VarWindReader.AdrAdjust = gtk_adjustment_new(
+									0.0,	// gdouble value,
+									0.0,	// gdouble lower,
+									100.0,	// gdouble upper,
+									0.001,	// gdouble step_increment,
+									1.0,	// gdouble page_increment,
+									0.0		// gdouble page_size
+									);
+	// VarWindReader.AdrAdjust = gtk_adjustment_new (0, 0, 100.0, 0.001, 1, 0);
+	VarWindReader.AdrHscale = gtk_scale_new( GTK_ORIENTATION_HORIZONTAL, GTK_ADJUSTMENT(VarWindReader.AdrAdjust) );
 	gtk_widget_show (VarWindReader.AdrHscale);
 	gtk_scale_set_draw_value (GTK_SCALE (VarWindReader.AdrHscale), FALSE);
 	gtk_box_pack_start (GTK_BOX (widget), VarWindReader.AdrHscale, TRUE, TRUE, 0);
-	GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
+	// GTK_WIDGET_UNSET_FLAGS (widget, GTK_CAN_FOCUS);
 	gtk_scale_set_value_pos (GTK_SCALE (VarWindReader.AdrHscale), GTK_POS_LEFT);
 	g_signal_connect ((gpointer) VarWindReader.AdrHscale, "change_value", G_CALLBACK (WinReader_value_change), NULL);
 	g_signal_connect ((gpointer) VarWindReader.AdrHscale, "event",G_CALLBACK (WinReader_event), NULL);
@@ -122,8 +126,9 @@ void on_hbox_WindReader_realize (GtkWidget *widget, gpointer user_data)
 gboolean on_WindReader_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 	mplayer_fifo_quit ();
-	VarWindReader.IsShow = FALSE;
-	gtk_widget_hide (VarWindReader.AdrWin);
+	gtk_widget_destroy( WindMain_wind_reader );
+	WindMain_wind_reader = NULL;
+	GtkBuilderProjet_wind_reader = NULL;
 	return TRUE;
 }
 // DESTROY EVENT
@@ -131,8 +136,9 @@ gboolean on_WindReader_delete_event (GtkWidget *widget, GdkEvent *event, gpointe
 gboolean on_WindReader_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 	mplayer_fifo_quit ();
-	VarWindReader.IsShow = FALSE;
-	gtk_widget_hide (VarWindReader.AdrWin);
+	gtk_widget_destroy( WindMain_wind_reader );
+	WindMain_wind_reader = NULL;
+	GtkBuilderProjet_wind_reader = NULL;
 	return TRUE;
 }
 // PAUSE
@@ -163,77 +169,98 @@ void on_button_quitter_WindReader_clicked (GtkButton *button, gpointer user_data
 	VarMplayer.BoolIsPause = FALSE;
 	mplayer_fifo_seek (VarMplayer.PercentTempsActuel);
 	mplayer_fifo_quit ();
-	VarWindReader.IsShow = FALSE;
-	gtk_widget_hide (VarWindReader.AdrWin);
-}
-// WIN-READER OPEN
-// 
-void WinReader_open (gchar *title)
-{
-	if (TRUE == VarWindReader.IsShow) {
-		gdk_window_raise (VarWindReader.AdrWin->window);
-	}
-	else {		
-		if (NULL == VarWindReader.AdrWin) {
-			VarWindReader.AdrWin = GTK_WIDGET (GLADE_GET_OBJECT("WindReader"));
-			gtk_builder_connect_signals (GtkXcfaProjet, NULL);
-		}
-		gtk_window_set_transient_for (GTK_WINDOW(VarWindReader.AdrWin), GTK_WINDOW(WindMain));
-		gtk_window_set_modal (GTK_WINDOW (VarWindReader.AdrWin), TRUE);
-		libutils_set_default_icone_to_win (VarWindReader.AdrWin);
-
-		gtk_widget_show (VarWindReader.AdrWin);
-	}
-	VarWindReader.IsShow = TRUE;
-	VarWindReader.BoolValueChange = FALSE;
-	if (NULL != title) gtk_window_set_title (GTK_WINDOW (VarWindReader.AdrWin), title);
-	
-	if (LIST_MPLAYER_FROM_DVD == VarMplayer.ListPlayFrom) {
-		gtk_widget_hide (GTK_WIDGET (GLADE_GET_OBJECT("hbox_WindReader")));
-	}
-	else {
-		gtk_widget_show (GTK_WIDGET (GLADE_GET_OBJECT("hbox_WindReader")));
-	}
+	gtk_widget_destroy( WindMain_wind_reader );
+	WindMain_wind_reader = NULL;
+	GtkBuilderProjet_wind_reader = NULL;
 }
 // WIN-READER SET-TITLE
 // 
 void WinReader_set_title (gchar *title)
 {
-	if (TRUE == VarWindReader.IsShow && NULL != title) gtk_window_set_title (GTK_WINDOW (VarWindReader.AdrWin), title);
+	if (NULL != title) gtk_window_set_title (GTK_WINDOW (WindMain_wind_reader), title);
 }
 // WIN-READER SHOW-PAUSE & HIDE-LECTURE
 // 
 void WinReader_set_pause (void)
 {
-	if (TRUE == VarWindReader.IsShow) {
-		gtk_widget_hide (GTK_WIDGET (GLADE_GET_OBJECT("button_lecture_WindReader")));
-		gtk_widget_show (GTK_WIDGET (GLADE_GET_OBJECT("button_pause_WindReader")));
-	}
+	gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object( GtkBuilderProjet_wind_reader, "button_lecture_WindReader")));
+	gtk_widget_show (GTK_WIDGET (gtk_builder_get_object( GtkBuilderProjet_wind_reader, "button_pause_WindReader")));
 }
 // WIN-READER HIDE-PAUSE & SHOW-LECTURE
 // 
 void WinReader_set_lecture (void)
 {
-	if (TRUE == VarWindReader.IsShow)  {
-		gtk_widget_hide (GTK_WIDGET (GLADE_GET_OBJECT("button_pause_WindReader")));
-		gtk_widget_show (GTK_WIDGET (GLADE_GET_OBJECT("button_lecture_WindReader")));
-	}
+
+	gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object( GtkBuilderProjet_wind_reader, "button_pause_WindReader")));
+	gtk_widget_show (GTK_WIDGET (gtk_builder_get_object( GtkBuilderProjet_wind_reader, "button_lecture_WindReader")));
+
 }
 // WIN-READER CLOSE
 // 
 void WinReader_close (void)
 {
-	if (TRUE == VarWindReader.IsShow) {
-		WinReader_set_lecture ();
-		VarWindReader.IsShow = FALSE;
-		gtk_widget_hide (VarWindReader.AdrWin);
-	}
+	WinReader_set_lecture ();
+	gtk_widget_destroy( WindMain_wind_reader );
+	WindMain_wind_reader = NULL;
+	GtkBuilderProjet_wind_reader = NULL;
 }
 // WIN-READER IS OK
 // 
 gboolean WinReader_is_close (void)
 {
-	return (VarWindReader.IsShow ? FALSE : TRUE);
+	return (WindMain_wind_reader ? FALSE : TRUE);
+}
+// WIN-READER OPEN
+// 
+gboolean wind_reader_init( GtkWidget *FromWindMain )
+{
+	gchar	*PackageVersion = NULL;
+	// GtkWidget	*button_quitter_WindReader = NULL;
+	// GtkWidget	*button_lecture_WindReader = NULL;
+	// GtkWidget	*button_pause_WindReader = NULL;
+	// GtkWidget	*hbox_WindReader = NULL;
+
+	if( NULL == (GtkBuilderProjet_wind_reader = Builder_open( "xcfa_win_reader.glade", GtkBuilderProjet_wind_reader ))) {
+		return( EXIT_FAILURE );
+	}
+	// Add language support from glade file
+	gtk_builder_set_translation_domain(  GtkBuilderProjet_wind_reader, "WindReader" );
+	gtk_builder_connect_signals( GtkBuilderProjet_wind_reader, NULL );
+
+	WindMain_wind_reader = GTK_WIDGET( gtk_builder_get_object( GtkBuilderProjet_wind_reader, "WindReader" ));
+	// button_quitter_WindReader=GTK_WIDGET( gtk_builder_get_object( GtkBuilderProjet_wind_reader, "button_quitter_WindReader" ));
+	// button_lecture_WindReader=GTK_WIDGET( gtk_builder_get_object( GtkBuilderProjet_wind_reader, "button_lecture_WindReader" ));
+	// button_pause_WindReader=GTK_WIDGET( gtk_builder_get_object( GtkBuilderProjet_wind_reader, "button_pause_WindReader" ));
+	// hbox_WindReader=GTK_WIDGET( gtk_builder_get_object( GtkBuilderProjet_wind_reader, "hbox_WindReader" ));
+
+	if( NULL != FromWindMain ) {
+		gtk_window_set_transient_for (GTK_WINDOW(WindMain_wind_reader), GTK_WINDOW(FromWindMain));
+		gtk_window_set_modal (GTK_WINDOW(WindMain_wind_reader), TRUE);
+	}
+	// resize window
+	// gtk_window_resize(GTK_WINDOW(WindMain_wind_reader), Config.WinWidth, Config.WinHeight);
+	// place the window
+	// gtk_window_move(GTK_WINDOW(WindMain_wind_reader), Config.WinPos_X, Config.WinPos_Y);
+	// icon apply
+	libutils_set_default_icone_to_win( WindMain_wind_reader );
+
+	PackageVersion = g_strdup_printf( "%s  -  %s", PACKAGE_NAME, VERSION );
+	gtk_window_set_title( GTK_WINDOW( WindMain_wind_reader ), PackageVersion );
+	g_free( PackageVersion );
+	PackageVersion = NULL;
+
+	// place your initialization code here
+
+	gtk_widget_show_all( WindMain_wind_reader );
+	
+	VarWindReader.BoolValueChange = FALSE;
+	
+	if (LIST_MPLAYER_FROM_DVD == VarMplayer.ListPlayFrom)
+			gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object( GtkBuilderProjet_wind_reader, "hbox_WindReader")));
+	else	gtk_widget_show (GTK_WIDGET (gtk_builder_get_object( GtkBuilderProjet_wind_reader, "hbox_WindReader")));
+
+
+	return( TRUE );
 }
 
 
