@@ -1,9 +1,9 @@
  /*
  *  file      : win_reader.h
  *  project   : xcfa
- *  with      : Gtk-2
+ *  with      : Gtk-3
  *
- *  copyright : (C) 2003 - 2013 by Claude Bulin
+ *  copyright : (C) 2003 - 2015 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -27,7 +27,8 @@
 #ifndef win_reader_h
 #define win_reader_h 1
 
-void		WinReader_open (gchar *title);
+gboolean 	wind_reader_init( GtkWidget *FromWindMain );
+// void		WinReader_open (gchar *title);
 void		WinReader_set_pause (void);
 void		WinReader_set_lecture (void);
 void		WinReader_close (void);
